# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.account_tier import AccountTier
from mixpeek.models.base_rate_limits import BaseRateLimits
from mixpeek.models.organization_infrastructure import OrganizationInfrastructure
from typing import Optional, Set
from typing_extensions import Self

class OrganizationAdminUpdateRequest(BaseModel):
    """
    Admin-only update payload for organization.  Security: This model is ONLY used by private admin endpoints that require MIXPEEK_PRIVATE_TOKEN authentication. Regular users cannot access or modify these fields, especially infrastructure configuration.
    """ # noqa: E501
    account_type: Optional[AccountTier] = Field(default=None, description="Update organization billing tier.")
    rate_limits: Optional[BaseRateLimits] = Field(default=None, description="Override rate limits for the organization.")
    infrastructure: Optional[OrganizationInfrastructure] = Field(default=None, description="🔒 ADMIN ONLY: Configure dedicated infrastructure (Qdrant/Ray). This field is ONLY accessible via private admin endpoints with MIXPEEK_PRIVATE_TOKEN. NOT exposed in public API responses. NOT modifiable by organization users. Used for ENTERPRISE customers with dedicated infrastructure.")
    __properties: ClassVar[List[str]] = ["account_type", "rate_limits", "infrastructure"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrganizationAdminUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of rate_limits
        if self.rate_limits:
            _dict['rate_limits'] = self.rate_limits.to_dict()
        # override the default output from pydantic by calling `to_dict()` of infrastructure
        if self.infrastructure:
            _dict['infrastructure'] = self.infrastructure.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrganizationAdminUpdateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "account_type": obj.get("account_type"),
            "rate_limits": BaseRateLimits.from_dict(obj["rate_limits"]) if obj.get("rate_limits") is not None else None,
            "infrastructure": OrganizationInfrastructure.from_dict(obj["infrastructure"]) if obj.get("infrastructure") is not None else None
        })
        return _obj


