# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.agent_config import AgentConfig
from mixpeek.models.session_quotas import SessionQuotas
from typing import Optional, Set
from typing_extensions import Self

class CreateSessionRequest(BaseModel):
    """
    Request payload for creating a new agent session.  Attributes:     agent_config: Agent configuration (model, temperature, tools, etc.)     quotas: Optional session quotas and rate limits     user_id: Optional user identifier     user_memory: Optional initial user memory/preferences     metadata: Optional session metadata  Example:     ```python     request = CreateSessionRequest(         agent_config=AgentConfig(             model=\"claude-3-5-sonnet-20241022\",             temperature=0.7,             available_tools=[\"search_retrievers\", \"execute_retriever\"]         ),         quotas=SessionQuotas(             max_messages=100,             max_tokens_total=100000         ),         user_id=\"user_123\",         user_memory={\"preferences\": {\"language\": \"en\"}}     )     ```
    """ # noqa: E501
    agent_config: AgentConfig = Field(description="Agent configuration (REQUIRED)")
    quotas: Optional[SessionQuotas] = Field(default=None, description="Session quotas and rate limits (OPTIONAL)")
    user_id: Optional[StrictStr] = Field(default=None, description="User identifier (OPTIONAL)")
    user_memory: Optional[Dict[str, Any]] = Field(default=None, description="Initial user memory/preferences (OPTIONAL)")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Session metadata (OPTIONAL)")
    enable_memory: Optional[StrictBool] = Field(default=True, description="Enable semantic memory for conversation context (OPTIONAL, default: True)")
    __properties: ClassVar[List[str]] = ["agent_config", "quotas", "user_id", "user_memory", "metadata", "enable_memory"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateSessionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of agent_config
        if self.agent_config:
            _dict['agent_config'] = self.agent_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of quotas
        if self.quotas:
            _dict['quotas'] = self.quotas.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateSessionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "agent_config": AgentConfig.from_dict(obj["agent_config"]) if obj.get("agent_config") is not None else None,
            "quotas": SessionQuotas.from_dict(obj["quotas"]) if obj.get("quotas") is not None else None,
            "user_id": obj.get("user_id"),
            "user_memory": obj.get("user_memory"),
            "metadata": obj.get("metadata"),
            "enable_memory": obj.get("enable_memory") if obj.get("enable_memory") is not None else True
        })
        return _obj


