# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.internal_payload_model import InternalPayloadModel

class TestInternalPayloadModel(unittest.TestCase):
    """InternalPayloadModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InternalPayloadModel:
        """Test InternalPayloadModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InternalPayloadModel`
        """
        model = InternalPayloadModel()
        if include_optional:
            return InternalPayloadModel(
                internal_id = '',
                namespace_id = '',
                document_id = '',
                collection_id = '',
                created_at = '',
                updated_at = '',
                lineage = {
                    'key' : null
                    },
                processing = {
                    'key' : null
                    },
                source_blobs = [
                    None
                    ],
                document_blobs = [
                    None
                    ],
                source_details = [
                    None
                    ],
                modality = '',
                metadata = mixpeek.models.metadata.Metadata(),
                mime_type = '',
                size_bytes = 56,
                content_hash = ''
            )
        else:
            return InternalPayloadModel(
        )
        """

    def testInternalPayloadModel(self):
        """Test InternalPayloadModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
