# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class StepKeySource(str, Enum):
    """
    Defines how to extract the step key from documents for sequence analysis.  The step key identifies which stage/state a document is in for transition analytics.  Examples:     ASSIGNMENT_LABEL: Use the taxonomy's assigned label (e.g., \"inquiry\", \"proposal\")     ASSIGNMENT_NODE_ID: Use the taxonomy node ID (e.g., \"node_sales_inquiry\")     FIELD_PATH: Use a custom document field (e.g., \"metadata.workflow_stage\")
    """

    """
    allowed enum values
    """
    ASSIGNMENT_LABEL = 'assignment_label'
    ASSIGNMENT_NODE_ID = 'assignment_node_id'
    FIELD_PATH = 'field_path'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of StepKeySource from a JSON string"""
        return cls(json.loads(json_str))


