# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.retriever_model_output import RetrieverModelOutput

class TestRetrieverModelOutput(unittest.TestCase):
    """RetrieverModelOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RetrieverModelOutput:
        """Test RetrieverModelOutput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RetrieverModelOutput`
        """
        model = RetrieverModelOutput()
        if include_optional:
            return RetrieverModelOutput(
                retriever_id = '',
                retriever_name = '0',
                description = '',
                collection_ids = [
                    ''
                    ],
                stages = [
                    mixpeek.models.stage_config.StageConfig(
                        stage_name = '0', 
                        stage_type = 'filter', 
                        config = mixpeek.models.config.Config(), 
                        batch_size = '', 
                        description = '', )
                    ],
                input_schema = {
                    'key' : {
                        'key' : null
                        }
                    },
                budget_limits = mixpeek.models.budget_limits.BudgetLimits(
                    max_credits = 0.0, 
                    max_time_ms = 0.0, ),
                feature_dependencies = [
                    mixpeek.models.feature_address.FeatureAddress(
                        scheme = 'mixpeek', 
                        extractor = '', 
                        version = '', 
                        output = '', )
                    ],
                tags = [
                    ''
                    ],
                display_config = mixpeek.models.display_config.Display Config(),
                version = 1.0,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by = '',
                updated_by = '',
                is_published = True
            )
        else:
            return RetrieverModelOutput(
                retriever_name = '0',
                stages = [
                    mixpeek.models.stage_config.StageConfig(
                        stage_name = '0', 
                        stage_type = 'filter', 
                        config = mixpeek.models.config.Config(), 
                        batch_size = '', 
                        description = '', )
                    ],
        )
        """

    def testRetrieverModelOutput(self):
        """Test RetrieverModelOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
