# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.bucket_batches_api import BucketBatchesApi


class TestBucketBatchesApi(unittest.TestCase):
    """BucketBatchesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BucketBatchesApi()

    def tearDown(self) -> None:
        pass

    def test_add_objects_to_batch_buckets_batches(self) -> None:
        """Test case for add_objects_to_batch_buckets_batches

        Add Objects to Batch
        """
        pass

    def test_cancel_batch_buckets_batches(self) -> None:
        """Test case for cancel_batch_buckets_batches

        Cancel Batch
        """
        pass

    def test_create_batch_buckets_batches(self) -> None:
        """Test case for create_batch_buckets_batches

        Create Batch
        """
        pass

    def test_delete_batch_buckets_batches(self) -> None:
        """Test case for delete_batch_buckets_batches

        Delete Batch
        """
        pass

    def test_get_batch_buckets_batches(self) -> None:
        """Test case for get_batch_buckets_batches

        Get Batch Configuration
        """
        pass

    def test_get_batch_logs_buckets_batches(self) -> None:
        """Test case for get_batch_logs_buckets_batches

        Get Ray Job Logs for Batch
        """
        pass

    def test_get_failed_documents_buckets_batches_batch(self) -> None:
        """Test case for get_failed_documents_buckets_batches_batch

        Get Failed Documents for Batch
        """
        pass

    def test_list_batches_buckets(self) -> None:
        """Test case for list_batches_buckets

        List Batches
        """
        pass

    def test_patch_batch_buckets_batches(self) -> None:
        """Test case for patch_batch_buckets_batches

        Partially Update Batch
        """
        pass

    def test_retry_batch_buckets_batches(self) -> None:
        """Test case for retry_batch_buckets_batches

        Retry Failed Documents
        """
        pass

    def test_retry_qdrant_write_buckets_batches_batch_id_tiers_num(self) -> None:
        """Test case for retry_qdrant_write_buckets_batches_batch_id_tiers_num

        Retry Qdrant Write from S3
        """
        pass

    def test_submit_batch_buckets_batches(self) -> None:
        """Test case for submit_batch_buckets_batches

        Submit Batch for Processing
        """
        pass


if __name__ == '__main__':
    unittest.main()
