# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.organizations_api import OrganizationsApi


class TestOrganizationsApi(unittest.TestCase):
    """OrganizationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationsApi()

    def tearDown(self) -> None:
        pass

    def test_add_credits_organizations(self) -> None:
        """Test case for add_credits_organizations

        Add Credits
        """
        pass

    def test_get_organization(self) -> None:
        """Test case for get_organization

        Get Organization
        """
        pass

    def test_update_organization(self) -> None:
        """Test case for update_organization

        Update Organization
        """
        pass


if __name__ == '__main__':
    unittest.main()
