# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.resource_result import ResourceResult
from typing import Optional, Set
from typing_extensions import Self

class ApplyResult(BaseModel):
    """
    Result of applying a manifest.
    """ # noqa: E501
    success: StrictBool = Field(description="Whether all resources were created successfully")
    resources: Optional[List[ResourceResult]] = Field(default=None, description="Results for each resource")
    created_count: Optional[StrictInt] = Field(default=0, description="Number of resources created")
    failed_count: Optional[StrictInt] = Field(default=0, description="Number of resources that failed")
    skipped_count: Optional[StrictInt] = Field(default=0, description="Number of resources skipped")
    errors: Optional[List[StrictStr]] = Field(default=None, description="Error messages")
    rollback_performed: Optional[StrictBool] = Field(default=False, description="Whether rollback was performed due to failure")
    dry_run: Optional[StrictBool] = Field(default=False, description="Whether this was a dry run (no changes made)")
    __properties: ClassVar[List[str]] = ["success", "resources", "created_count", "failed_count", "skipped_count", "errors", "rollback_performed", "dry_run"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApplyResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in resources (list)
        _items = []
        if self.resources:
            for _item_resources in self.resources:
                if _item_resources:
                    _items.append(_item_resources.to_dict())
            _dict['resources'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApplyResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "success": obj.get("success"),
            "resources": [ResourceResult.from_dict(_item) for _item in obj["resources"]] if obj.get("resources") is not None else None,
            "created_count": obj.get("created_count") if obj.get("created_count") is not None else 0,
            "failed_count": obj.get("failed_count") if obj.get("failed_count") is not None else 0,
            "skipped_count": obj.get("skipped_count") if obj.get("skipped_count") is not None else 0,
            "errors": obj.get("errors"),
            "rollback_performed": obj.get("rollback_performed") if obj.get("rollback_performed") is not None else False,
            "dry_run": obj.get("dry_run") if obj.get("dry_run") is not None else False
        })
        return _obj


