# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_params_api_call import StageParamsApiCall

class TestStageParamsApiCall(unittest.TestCase):
    """StageParamsApiCall unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StageParamsApiCall:
        """Test StageParamsApiCall
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StageParamsApiCall`
        """
        model = StageParamsApiCall()
        if include_optional:
            return StageParamsApiCall(
                url = 'https://httpbin.org/get',
                allowed_domains = [
                    ''
                    ],
                method = 'GET',
                auth = mixpeek.models.auth_config.AuthConfig(
                    type = null, 
                    secret_ref = '', 
                    location = '', 
                    key = '', ),
                headers = {
                    'key' : ''
                    },
                body = mixpeek.models.body.Body(),
                output_field = 'metadata.api_response',
                timeout = 1,
                max_response_size = 1024,
                rate_limit = mixpeek.models.rate_limit_config.RateLimitConfig(
                    enabled = True, 
                    tier = null, 
                    requests_per_minute = 1.0, 
                    requests_per_hour = 1.0, 
                    requests_per_day = 1.0, 
                    max_results_per_query = 1.0, 
                    enable_ip_limits = True, 
                    max_requests_per_ip_hour = 1.0, ),
                response_path = 'null',
                when = {
                    'key' : null
                    },
                on_error = 'skip'
            )
        else:
            return StageParamsApiCall(
        )
        """

    def testStageParamsApiCall(self):
        """Test StageParamsApiCall"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
