# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.flat_taxonomy_config_output import FlatTaxonomyConfigOutput

class TestFlatTaxonomyConfigOutput(unittest.TestCase):
    """FlatTaxonomyConfigOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlatTaxonomyConfigOutput:
        """Test FlatTaxonomyConfigOutput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlatTaxonomyConfigOutput`
        """
        model = FlatTaxonomyConfigOutput()
        if include_optional:
            return FlatTaxonomyConfigOutput(
                taxonomy_type = 'flat',
                retriever_id = '',
                input_mappings = [
                    mixpeek.models.input_mapping.InputMapping(
                        input_key = '', 
                        source_type = 'payload', 
                        path = '', 
                        override = null, )
                    ],
                source_collection = mixpeek.models.source_collection.SourceCollection(
                    collection_id = '', 
                    enrichment_fields = [
                        mixpeek.models.enrichment_field.EnrichmentField(
                            field_path = '', 
                            target_field = '', 
                            merge_mode = null, )
                        ], ),
                step_analytics = mixpeek.models.step_analytics_config.StepAnalyticsConfig(
                    timestamp_field = '', 
                    sequence_id_field = '', 
                    step_key_source = null, 
                    step_key_field_path = '', 
                    covariates = [
                        mixpeek.models.covariate_config.CovariateConfig(
                            field_path = '', 
                            covariate_type = null, 
                            name = '0', 
                            binning_strategy = 'quartiles', 
                            clustering_method = 'kmeans', 
                            n_clusters = 2.0, )
                        ], 
                    max_sequence_duration_days = 1.0, )
            )
        else:
            return FlatTaxonomyConfigOutput(
                retriever_id = '',
                input_mappings = [
                    mixpeek.models.input_mapping.InputMapping(
                        input_key = '', 
                        source_type = 'payload', 
                        path = '', 
                        override = null, )
                    ],
                source_collection = mixpeek.models.source_collection.SourceCollection(
                    collection_id = '', 
                    enrichment_fields = [
                        mixpeek.models.enrichment_field.EnrichmentField(
                            field_path = '', 
                            target_field = '', 
                            merge_mode = null, )
                        ], ),
        )
        """

    def testFlatTaxonomyConfigOutput(self):
        """Test FlatTaxonomyConfigOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
