# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from mixpeek.models.interaction_type import InteractionType
from typing import Optional, Set
from typing_extensions import Self

class PublicInteractionRequest(BaseModel):
    """
    Request to track a single interaction from public retriever.  Simplified wrapper around SearchInteraction for public API use.
    """ # noqa: E501
    document_id: StrictStr = Field(description="ID of the document that was interacted with (from search results)")
    interaction_type: Annotated[List[InteractionType], Field(min_length=1)] = Field(description="Type(s) of interaction that occurred")
    position: Annotated[int, Field(strict=True, ge=0)] = Field(description="Position in search results (0-indexed)")
    execution_id: Optional[StrictStr] = Field(default=None, description="ID of the retriever execution that generated these results. HIGHLY RECOMMENDED for analytics.")
    query_snapshot: Optional[Dict[str, Any]] = Field(default=None, description="Snapshot of the query that generated these results. HIGHLY RECOMMENDED for training optimization.")
    document_score: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Initial retrieval score of this document")
    result_set_size: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Total number of results shown")
    session_id: Optional[StrictStr] = Field(default=None, description="Session identifier for tracking user journey")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Additional context about the interaction")
    __properties: ClassVar[List[str]] = ["document_id", "interaction_type", "position", "execution_id", "query_snapshot", "document_score", "result_set_size", "session_id", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PublicInteractionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PublicInteractionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "document_id": obj.get("document_id"),
            "interaction_type": obj.get("interaction_type"),
            "position": obj.get("position"),
            "execution_id": obj.get("execution_id"),
            "query_snapshot": obj.get("query_snapshot"),
            "document_score": obj.get("document_score"),
            "result_set_size": obj.get("result_set_size"),
            "session_id": obj.get("session_id"),
            "metadata": obj.get("metadata")
        })
        return _obj


