# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.public_interaction_batch_request import PublicInteractionBatchRequest

class TestPublicInteractionBatchRequest(unittest.TestCase):
    """PublicInteractionBatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PublicInteractionBatchRequest:
        """Test PublicInteractionBatchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PublicInteractionBatchRequest`
        """
        model = PublicInteractionBatchRequest()
        if include_optional:
            return PublicInteractionBatchRequest(
                interactions = [
                    mixpeek.models.public_interaction_request.PublicInteractionRequest(
                        document_id = '', 
                        interaction_type = [
                            'view'
                            ], 
                        position = 0.0, 
                        execution_id = '', 
                        query_snapshot = mixpeek.models.query_snapshot.Query Snapshot(), 
                        document_score = 1.337, 
                        result_set_size = 1.0, 
                        session_id = '', 
                        metadata = mixpeek.models.metadata.Metadata(), )
                    ]
            )
        else:
            return PublicInteractionBatchRequest(
                interactions = [
                    mixpeek.models.public_interaction_request.PublicInteractionRequest(
                        document_id = '', 
                        interaction_type = [
                            'view'
                            ], 
                        position = 0.0, 
                        execution_id = '', 
                        query_snapshot = mixpeek.models.query_snapshot.Query Snapshot(), 
                        document_score = 1.337, 
                        result_set_size = 1.0, 
                        session_id = '', 
                        metadata = mixpeek.models.metadata.Metadata(), )
                    ],
        )
        """

    def testPublicInteractionBatchRequest(self):
        """Test PublicInteractionBatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
