# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.document_create_request import DocumentCreateRequest

class TestDocumentCreateRequest(unittest.TestCase):
    """DocumentCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DocumentCreateRequest:
        """Test DocumentCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DocumentCreateRequest`
        """
        model = DocumentCreateRequest()
        if include_optional:
            return DocumentCreateRequest(
                collection_id = 'collection_123',
                root_object_id = '',
                root_bucket_id = '',
                source_type = 'bucket',
                source_collection_id = '',
                source_document_id = '',
                source_object_id = '',
                lineage_path = '',
                lineage_chain = [
                    mixpeek.models.lineage_step.LineageStep(
                        collection_id = '', 
                        feature_extractor_id = '', 
                        document_id = '', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                document_schema_version = '',
                metadata = mixpeek.models.metadata.Metadata(),
                features = [
                    {
                        'key' : null
                        }
                    ]
            )
        else:
            return DocumentCreateRequest(
                collection_id = 'collection_123',
        )
        """

    def testDocumentCreateRequest(self):
        """Test DocumentCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
