# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.alerts_api import AlertsApi


class TestAlertsApi(unittest.TestCase):
    """AlertsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AlertsApi()

    def tearDown(self) -> None:
        pass

    def test_create_alert(self) -> None:
        """Test case for create_alert

        Create Alert
        """
        pass

    def test_create_alert_0(self) -> None:
        """Test case for create_alert_0

        Create Alert
        """
        pass

    def test_delete_alert(self) -> None:
        """Test case for delete_alert

        Delete Alert
        """
        pass

    def test_delete_alert_0(self) -> None:
        """Test case for delete_alert_0

        Delete Alert
        """
        pass

    def test_get_alert(self) -> None:
        """Test case for get_alert

        Get Alert
        """
        pass

    def test_get_alert_0(self) -> None:
        """Test case for get_alert_0

        Get Alert
        """
        pass

    def test_list_alert_executions(self) -> None:
        """Test case for list_alert_executions

        List Alert Executions
        """
        pass

    def test_list_alert_executions_0(self) -> None:
        """Test case for list_alert_executions_0

        List Alert Executions
        """
        pass

    def test_list_alerts(self) -> None:
        """Test case for list_alerts

        List Alerts
        """
        pass

    def test_list_alerts_0(self) -> None:
        """Test case for list_alerts_0

        List Alerts
        """
        pass

    def test_list_all_executions_alerts(self) -> None:
        """Test case for list_all_executions_alerts

        List All Executions
        """
        pass

    def test_list_all_executions_alerts_0(self) -> None:
        """Test case for list_all_executions_alerts_0

        List All Executions
        """
        pass

    def test_patch_alert(self) -> None:
        """Test case for patch_alert

        Update Alert
        """
        pass

    def test_patch_alert_0(self) -> None:
        """Test case for patch_alert_0

        Update Alert
        """
        pass


if __name__ == '__main__':
    unittest.main()
