# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.agent_sessions_api import AgentSessionsApi


class TestAgentSessionsApi(unittest.TestCase):
    """AgentSessionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AgentSessionsApi()

    def tearDown(self) -> None:
        pass

    def test_create_session_agents(self) -> None:
        """Test case for create_session_agents

        Create Session
        """
        pass

    def test_detect_intent_agents_sessions(self) -> None:
        """Test case for detect_intent_agents_sessions

        Detect Intent
        """
        pass

    def test_get_history_agents_sessions(self) -> None:
        """Test case for get_history_agents_sessions

        Get History
        """
        pass

    def test_get_session_agents(self) -> None:
        """Test case for get_session_agents

        Get Session
        """
        pass

    def test_list_sessions_agents(self) -> None:
        """Test case for list_sessions_agents

        List Sessions
        """
        pass

    def test_list_tools_agents_sessions(self) -> None:
        """Test case for list_tools_agents_sessions

        List Tools
        """
        pass

    def test_patch_session_agents(self) -> None:
        """Test case for patch_session_agents

        Patch Session
        """
        pass

    def test_respond_to_confirmation_agents_sessions(self) -> None:
        """Test case for respond_to_confirmation_agents_sessions

        Respond To Confirmation
        """
        pass

    def test_send_message_agents_sessions(self) -> None:
        """Test case for send_message_agents_sessions

        Send Message
        """
        pass

    def test_submit_feedback_agents_sessions(self) -> None:
        """Test case for submit_feedback_agents_sessions

        Submit Feedback
        """
        pass

    def test_terminate_session_agents(self) -> None:
        """Test case for terminate_session_agents

        Terminate Session
        """
        pass


if __name__ == '__main__':
    unittest.main()
