# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.blob_model import BlobModel
from mixpeek.models.source_details import SourceDetails
from mixpeek.models.task_status_enum import TaskStatusEnum
from typing import Optional, Set
from typing_extensions import Self

class ObjectResponse(BaseModel):
    """
    Response model for bucket objects.
    """ # noqa: E501
    object_id: Optional[StrictStr] = Field(default=None, description="Unique identifier for the object")
    bucket_id: StrictStr = Field(description="ID of the bucket this object belongs to")
    key_prefix: Optional[StrictStr] = Field(default=None, description="Storage key/path of the object, this will be used to retrieve the object from the storage. It is similar to a file path. If not provided, it will be placed in the root of the bucket.")
    blobs: Optional[List[BlobModel]] = Field(default=None, description="List of blobs contained in this object")
    source_details: Optional[List[SourceDetails]] = Field(default=None, description="Lineage/source details for this object; used for downstream references.")
    status: Optional[TaskStatusEnum] = Field(default=None, description="The current status of the object.")
    error: Optional[StrictStr] = Field(default=None, description="The error message if the object failed to process.")
    created_at: Optional[datetime] = Field(default=None, description="Timestamp when the object was created. Automatically populated by the system.")
    updated_at: Optional[datetime] = Field(default=None, description="Timestamp when the object was last updated. Automatically populated by the system.")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["object_id", "bucket_id", "key_prefix", "blobs", "source_details", "status", "error", "created_at", "updated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ObjectResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in blobs (list)
        _items = []
        if self.blobs:
            for _item_blobs in self.blobs:
                if _item_blobs:
                    _items.append(_item_blobs.to_dict())
            _dict['blobs'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in source_details (list)
        _items = []
        if self.source_details:
            for _item_source_details in self.source_details:
                if _item_source_details:
                    _items.append(_item_source_details.to_dict())
            _dict['source_details'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ObjectResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object_id": obj.get("object_id"),
            "bucket_id": obj.get("bucket_id"),
            "key_prefix": obj.get("key_prefix"),
            "blobs": [BlobModel.from_dict(_item) for _item in obj["blobs"]] if obj.get("blobs") is not None else None,
            "source_details": [SourceDetails.from_dict(_item) for _item in obj["source_details"]] if obj.get("source_details") is not None else None,
            "status": obj.get("status"),
            "error": obj.get("error"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


