# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.public_retriever_template_response import PublicRetrieverTemplateResponse

class TestPublicRetrieverTemplateResponse(unittest.TestCase):
    """PublicRetrieverTemplateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PublicRetrieverTemplateResponse:
        """Test PublicRetrieverTemplateResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PublicRetrieverTemplateResponse`
        """
        model = PublicRetrieverTemplateResponse()
        if include_optional:
            return PublicRetrieverTemplateResponse(
                retriever_name = '',
                description = '',
                collection_identifiers = [
                    ''
                    ],
                stages = [
                    None
                    ],
                input_schema = {
                    'key' : {
                        'key' : null
                        }
                    },
                budget_limits = mixpeek.models.budget_limits.Budget Limits(),
                tags = [
                    ''
                    ],
                display_config = {
                    'key' : null
                    },
                source_public_name = '',
                source_public_url = '',
                feature_extractors = [
                    None
                    ]
            )
        else:
            return PublicRetrieverTemplateResponse(
                retriever_name = '',
                collection_identifiers = [
                    ''
                    ],
                stages = [
                    None
                    ],
                input_schema = {
                    'key' : {
                        'key' : null
                        }
                    },
                budget_limits = mixpeek.models.budget_limits.Budget Limits(),
                source_public_name = '',
                source_public_url = '',
        )
        """

    def testPublicRetrieverTemplateResponse(self):
        """Test PublicRetrieverTemplateResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
