# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.webhook_event_type import WebhookEventType

class TestWebhookEventType(unittest.TestCase):
    """WebhookEventType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWebhookEventType(self):
        """Test WebhookEventType"""
        # inst = WebhookEventType()

if __name__ == '__main__':
    unittest.main()
