# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.collection_export_response import CollectionExportResponse

class TestCollectionExportResponse(unittest.TestCase):
    """CollectionExportResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CollectionExportResponse:
        """Test CollectionExportResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CollectionExportResponse`
        """
        model = CollectionExportResponse()
        if include_optional:
            return CollectionExportResponse(
                download_url = '',
                s3_path = '',
                format = 'json',
                document_count = 0.0,
                file_size_bytes = 0.0,
                exported_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                vectors_download_url = '',
                vectors_s3_path = ''
            )
        else:
            return CollectionExportResponse(
                download_url = '',
                s3_path = '',
                format = 'json',
                document_count = 0.0,
                file_size_bytes = 0.0,
                exported_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testCollectionExportResponse(self):
        """Test CollectionExportResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
