# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class HDBSCANParams(BaseModel):
    """
    Parameters for HDBSCAN clustering algorithm.
    """ # noqa: E501
    min_cluster_size: Optional[Annotated[int, Field(strict=True, ge=2)]] = Field(default=5, description="Minimum number of samples in a cluster")
    min_samples: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Number of samples in a neighborhood for a point to be considered a core point. Defaults to min_cluster_size if None")
    cluster_selection_epsilon: Optional[Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]] = Field(default=0.0, description="A distance threshold for cluster selection. Clusters below this value will be merged")
    max_cluster_size: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Maximum number of samples in a cluster. Clusters above this size will be split")
    metric: Optional[StrictStr] = Field(default='euclidean', description="Metric to use for distance computation")
    alpha: Optional[Union[StrictFloat, StrictInt]] = Field(default=1.0, description="A distance scaling parameter")
    cluster_selection_method: Optional[StrictStr] = Field(default='eom', description="Method to select clusters from the condensed tree ('eom' or 'leaf')")
    allow_single_cluster: Optional[StrictBool] = Field(default=False, description="Allow HDBSCAN to find only a single cluster")
    prediction_data: Optional[StrictBool] = Field(default=False, description="Whether to generate extra data for predicting cluster membership")
    match_reference_implementation: Optional[StrictBool] = Field(default=False, description="Whether to match the reference implementation exactly")
    __properties: ClassVar[List[str]] = ["min_cluster_size", "min_samples", "cluster_selection_epsilon", "max_cluster_size", "metric", "alpha", "cluster_selection_method", "allow_single_cluster", "prediction_data", "match_reference_implementation"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of HDBSCANParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of HDBSCANParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "min_cluster_size": obj.get("min_cluster_size") if obj.get("min_cluster_size") is not None else 5,
            "min_samples": obj.get("min_samples"),
            "cluster_selection_epsilon": obj.get("cluster_selection_epsilon") if obj.get("cluster_selection_epsilon") is not None else 0.0,
            "max_cluster_size": obj.get("max_cluster_size"),
            "metric": obj.get("metric") if obj.get("metric") is not None else 'euclidean',
            "alpha": obj.get("alpha") if obj.get("alpha") is not None else 1.0,
            "cluster_selection_method": obj.get("cluster_selection_method") if obj.get("cluster_selection_method") is not None else 'eom',
            "allow_single_cluster": obj.get("allow_single_cluster") if obj.get("allow_single_cluster") is not None else False,
            "prediction_data": obj.get("prediction_data") if obj.get("prediction_data") is not None else False,
            "match_reference_implementation": obj.get("match_reference_implementation") if obj.get("match_reference_implementation") is not None else False
        })
        return _obj


