# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.theme_config import ThemeConfig

class TestThemeConfig(unittest.TestCase):
    """ThemeConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ThemeConfig:
        """Test ThemeConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ThemeConfig`
        """
        model = ThemeConfig()
        if include_optional:
            return ThemeConfig(
                primary_color = '#007AFF',
                secondary_color = '',
                font_family = 'system-ui, -apple-system, sans-serif',
                background_color = '#FFFFFF',
                text_color = '#374151',
                heading_font_family = '',
                surface_color = '',
                muted_color = '',
                border_color = '',
                border_radius = '12px',
                card_style = 'elevated',
                card_hover_effect = 'lift'
            )
        else:
            return ThemeConfig(
        )
        """

    def testThemeConfig(self):
        """Test ThemeConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
