# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.plugins_api import PluginsApi


class TestPluginsApi(unittest.TestCase):
    """PluginsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PluginsApi()

    def tearDown(self) -> None:
        pass

    def test_confirm_upload_plugins(self) -> None:
        """Test case for confirm_upload_plugins

        Confirm plugin upload
        """
        pass

    def test_delete_plugin(self) -> None:
        """Test case for delete_plugin

        Delete a plugin
        """
        pass

    def test_generate_upload_url_plugins(self) -> None:
        """Test case for generate_upload_url_plugins

        Generate presigned URL for plugin upload
        """
        pass

    def test_get_plugin(self) -> None:
        """Test case for get_plugin

        Get plugin details
        """
        pass

    def test_list_plugins(self) -> None:
        """Test case for list_plugins

        List plugins in organization
        """
        pass


if __name__ == '__main__':
    unittest.main()
