# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.create_object_request import CreateObjectRequest

class TestCreateObjectRequest(unittest.TestCase):
    """CreateObjectRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateObjectRequest:
        """Test CreateObjectRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateObjectRequest`
        """
        model = CreateObjectRequest()
        if include_optional:
            return CreateObjectRequest(
                key_prefix = '/contract-2024',
                blobs = [{data={num_pages=5, title=Service Agreement 2024}, key_prefix=/content.pdf, metadata={author=John Doe, department=Legal}, property=content, type=PDF}],
                skip_duplicates = True,
                canonicalize_source = True,
                force_remirror = True
            )
        else:
            return CreateObjectRequest(
        )
        """

    def testCreateObjectRequest(self):
        """Test CreateObjectRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
