# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.create_objects_batch_request import CreateObjectsBatchRequest

class TestCreateObjectsBatchRequest(unittest.TestCase):
    """CreateObjectsBatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateObjectsBatchRequest:
        """Test CreateObjectsBatchRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateObjectsBatchRequest`
        """
        model = CreateObjectsBatchRequest()
        if include_optional:
            return CreateObjectsBatchRequest(
                objects = [
                    {blobs=[{data={num_pages=5, title=Service Agreement 2024}, key_prefix=/contract-2024/content.pdf, metadata={author=John Doe, department=Legal}, property=content, type=json}, {data={filename=https://example.com/images/smartphone-x1.jpg, mime_type=image/jpeg}, key_prefix=/contract-2024/thumbnail.jpg, metadata={height=300, width=200}, property=thumbnail, type=image}], key_prefix=/documents, metadata={category=contracts, status=draft, year=2024}}
                    ]
            )
        else:
            return CreateObjectsBatchRequest(
                objects = [
                    {blobs=[{data={num_pages=5, title=Service Agreement 2024}, key_prefix=/contract-2024/content.pdf, metadata={author=John Doe, department=Legal}, property=content, type=json}, {data={filename=https://example.com/images/smartphone-x1.jpg, mime_type=image/jpeg}, key_prefix=/contract-2024/thumbnail.jpg, metadata={height=300, width=200}, property=thumbnail, type=image}], key_prefix=/documents, metadata={category=contracts, status=draft, year=2024}}
                    ],
        )
        """

    def testCreateObjectsBatchRequest(self):
        """Test CreateObjectsBatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
