# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.spending_caps_response import SpendingCapsResponse

class TestSpendingCapsResponse(unittest.TestCase):
    """SpendingCapsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpendingCapsResponse:
        """Test SpendingCapsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpendingCapsResponse`
        """
        model = SpendingCapsResponse()
        if include_optional:
            return SpendingCapsResponse(
                monthly_spending_budget = 56,
                monthly_spending_budget_usd = 1.337,
                spending_alert_thresholds = [
                    56
                    ],
                spending_alerts_enabled = True,
                spending_alerts_sent = [
                    56
                    ],
                hard_spending_cap = 56,
                hard_spending_cap_usd = 1.337,
                hard_cap_enabled = True,
                current_spending_cents = 56,
                current_spending_usd = 1.337,
                budget_percentage_used = 1.337
            )
        else:
            return SpendingCapsResponse(
                current_spending_cents = 56,
                current_spending_usd = 1.337,
        )
        """

    def testSpendingCapsResponse(self):
        """Test SpendingCapsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
