# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.models_api import ModelsApi


class TestModelsApi(unittest.TestCase):
    """ModelsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ModelsApi()

    def tearDown(self) -> None:
        pass

    def test_confirm_upload_models(self) -> None:
        """Test case for confirm_upload_models

        Confirm model upload
        """
        pass

    def test_delete_model(self) -> None:
        """Test case for delete_model

        Delete model
        """
        pass

    def test_generate_upload_url_models(self) -> None:
        """Test case for generate_upload_url_models

        Generate presigned URL for model upload
        """
        pass

    def test_get_model(self) -> None:
        """Test case for get_model

        Get model details
        """
        pass

    def test_list_models(self) -> None:
        """Test case for list_models

        List organization models
        """
        pass


if __name__ == '__main__':
    unittest.main()
