# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.analytics_buckets_api import AnalyticsBucketsApi


class TestAnalyticsBucketsApi(unittest.TestCase):
    """AnalyticsBucketsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AnalyticsBucketsApi()

    def tearDown(self) -> None:
        pass

    def test_get_bucket_health_analytics(self) -> None:
        """Test case for get_bucket_health_analytics

        Get Bucket Health
        """
        pass

    def test_get_bucket_storage_analytics(self) -> None:
        """Test case for get_bucket_storage_analytics

        Get Bucket Storage
        """
        pass

    def test_get_bucket_usage_analytics(self) -> None:
        """Test case for get_bucket_usage_analytics

        Get Bucket Usage
        """
        pass

    def test_get_sync_comparison_analytics_buckets(self) -> None:
        """Test case for get_sync_comparison_analytics_buckets

        Get Sync Comparison
        """
        pass

    def test_get_sync_performance_analytics_buckets(self) -> None:
        """Test case for get_sync_performance_analytics_buckets

        Get Sync Performance
        """
        pass

    def test_get_upload_performance_analytics_buckets(self) -> None:
        """Test case for get_upload_performance_analytics_buckets

        Get Upload Performance
        """
        pass


if __name__ == '__main__':
    unittest.main()
