# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.organization_users_api import OrganizationUsersApi


class TestOrganizationUsersApi(unittest.TestCase):
    """OrganizationUsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationUsersApi()

    def tearDown(self) -> None:
        pass

    def test_create_user_organizations(self) -> None:
        """Test case for create_user_organizations

        Create User
        """
        pass

    def test_delete_user_organizations_email(self) -> None:
        """Test case for delete_user_organizations_email

        Delete User
        """
        pass

    def test_get_user_organizations_email(self) -> None:
        """Test case for get_user_organizations_email

        Get User
        """
        pass

    def test_list_users_organizations(self) -> None:
        """Test case for list_users_organizations

        List Users
        """
        pass

    def test_update_user_organizations_email(self) -> None:
        """Test case for update_user_organizations_email

        Update User
        """
        pass


if __name__ == '__main__':
    unittest.main()
