# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.namespace_infrastructure import NamespaceInfrastructure

class TestNamespaceInfrastructure(unittest.TestCase):
    """NamespaceInfrastructure unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NamespaceInfrastructure:
        """Test NamespaceInfrastructure
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NamespaceInfrastructure`
        """
        model = NamespaceInfrastructure()
        if include_optional:
            return NamespaceInfrastructure(
                ray_cluster_id = 'ray_HqXzyCBw3_uufVPIPFhB9JcGRYnua_cdyyvLY8IzLpul9',
                ray_head_node_url = '',
                ray_dashboard_url = '',
                qdrant_url = '',
                qdrant_api_key = '',
                qdrant_collection = '012',
                compute_tier = 'shared',
                max_concurrent_jobs = 1.0,
                autoscaling_enabled = True,
                min_workers = 0.0,
                max_workers = 1.0,
                gpu_type = '',
                gpus_per_worker = 0.0,
                s3_plugin_bucket = 'mixpeek-plugins',
                s3_plugin_prefix = '',
                max_custom_plugins = 0.0,
                max_custom_models = 0.0
            )
        else:
            return NamespaceInfrastructure(
                qdrant_collection = '012',
        )
        """

    def testNamespaceInfrastructure(self):
        """Test NamespaceInfrastructure"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
