# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.logical_operator6 import LogicalOperator6

class TestLogicalOperator6(unittest.TestCase):
    """LogicalOperator6 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LogicalOperator6:
        """Test LogicalOperator6
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LogicalOperator6`
        """
        model = LogicalOperator6()
        if include_optional:
            return LogicalOperator6(
                var_and = [{field=name, operator=eq, value=John}, {field=age, operator=gte, value=30}],
                var_or = [{field=status, operator=eq, value=active}, {field=role, operator=eq, value=admin}],
                var_not = [{field=department, operator=eq, value=HR}, {field=location, operator=eq, value=remote}],
                case_sensitive = True
            )
        else:
            return LogicalOperator6(
        )
        """

    def testLogicalOperator6(self):
        """Test LogicalOperator6"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
