# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.postgre_sql_config import PostgreSQLConfig

class TestPostgreSQLConfig(unittest.TestCase):
    """PostgreSQLConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PostgreSQLConfig:
        """Test PostgreSQLConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PostgreSQLConfig`
        """
        model = PostgreSQLConfig()
        if include_optional:
            return PostgreSQLConfig(
                provider_type = 'postgresql',
                credentials = mixpeek.models.postgre_sql_credentials.PostgreSQLCredentials(
                    type = 'username_password', 
                    username = '', 
                    password = '', ),
                host = '',
                port = 1.0,
                database = '',
                var_schema = 'public',
                ssl_mode = 'prefer',
                incremental_column = '',
                primary_key_columns = [
                    ''
                    ],
                query_timeout_seconds = 1.0,
                fetch_size = 100.0
            )
        else:
            return PostgreSQLConfig(
                credentials = mixpeek.models.postgre_sql_credentials.PostgreSQLCredentials(
                    type = 'username_password', 
                    username = '', 
                    password = '', ),
                host = '',
                database = '',
        )
        """

    def testPostgreSQLConfig(self):
        """Test PostgreSQLConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
