# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.field_usage_response import FieldUsageResponse

class TestFieldUsageResponse(unittest.TestCase):
    """FieldUsageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FieldUsageResponse:
        """Test FieldUsageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FieldUsageResponse`
        """
        model = FieldUsageResponse()
        if include_optional:
            return FieldUsageResponse(
                namespace_id = '',
                period = '',
                fields = [
                    mixpeek.models.field_usage_stat.FieldUsageStat(
                        field_name = '', 
                        query_count = 56, 
                        unique_queries = 56, 
                        is_indexed = True, 
                        is_protected = True, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, 
                        first_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total_fields = 56,
                indexed_fields = 56,
                unindexed_fields = 56
            )
        else:
            return FieldUsageResponse(
                namespace_id = '',
                period = '',
                fields = [
                    mixpeek.models.field_usage_stat.FieldUsageStat(
                        field_name = '', 
                        query_count = 56, 
                        unique_queries = 56, 
                        is_indexed = True, 
                        is_protected = True, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, 
                        first_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total_fields = 56,
                indexed_fields = 56,
                unindexed_fields = 56,
        )
        """

    def testFieldUsageResponse(self):
        """Test FieldUsageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
