# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.webhooks_api import WebhooksApi


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebhooksApi()

    def tearDown(self) -> None:
        pass

    def test_create_webhook_organizations(self) -> None:
        """Test case for create_webhook_organizations

        Create Webhook
        """
        pass

    def test_delete_webhook_organizations(self) -> None:
        """Test case for delete_webhook_organizations

        Delete Webhook
        """
        pass

    def test_get_webhook_organizations(self) -> None:
        """Test case for get_webhook_organizations

        Get Webhook
        """
        pass

    def test_list_webhooks_organizations(self) -> None:
        """Test case for list_webhooks_organizations

        List Webhooks
        """
        pass

    def test_update_webhook_organizations(self) -> None:
        """Test case for update_webhook_organizations

        Update Webhook
        """
        pass


if __name__ == '__main__':
    unittest.main()
