# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.input_rendering_config_output import InputRenderingConfigOutput

class TestInputRenderingConfigOutput(unittest.TestCase):
    """InputRenderingConfigOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InputRenderingConfigOutput:
        """Test InputRenderingConfigOutput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InputRenderingConfigOutput`
        """
        model = InputRenderingConfigOutput()
        if include_optional:
            return InputRenderingConfigOutput(
                field_name = '',
                field_schema = {
                    'key' : null
                    },
                input_type = 'text',
                label = '',
                placeholder = '',
                helper_text = '',
                suggestions = [
                    ''
                    ],
                required = True,
                order = 0.0
            )
        else:
            return InputRenderingConfigOutput(
                field_name = '',
                field_schema = {
                    'key' : null
                    },
                label = '',
        )
        """

    def testInputRenderingConfigOutput(self):
        """Test InputRenderingConfigOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
