# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.shared_collection_features_extractors_models_feature_extractor_config_output import SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput

class TestSharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput(unittest.TestCase):
    """SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput:
        """Test SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput`
        """
        model = SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput()
        if include_optional:
            return SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput(
                feature_extractor_name = '',
                version = '',
                params = mixpeek.models.params.Params(),
                parameters = None,
                input_mappings = None,
                field_passthrough = [
                    mixpeek.models.field_passthrough.FieldPassthrough(
                        source_path = '', 
                        target_path = '', 
                        default = null, 
                        required = True, )
                    ],
                include_all_source_fields = True,
                feature_extractor_id = ''
            )
        else:
            return SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput(
                feature_extractor_name = '',
                version = '',
                feature_extractor_id = '',
        )
        """

    def testSharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput(self):
        """Test SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
