# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.google_drive_service_account_credentials import GoogleDriveServiceAccountCredentials

class TestGoogleDriveServiceAccountCredentials(unittest.TestCase):
    """GoogleDriveServiceAccountCredentials unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleDriveServiceAccountCredentials:
        """Test GoogleDriveServiceAccountCredentials
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleDriveServiceAccountCredentials`
        """
        model = GoogleDriveServiceAccountCredentials()
        if include_optional:
            return GoogleDriveServiceAccountCredentials(
                type = 'service_account',
                project_id = '',
                private_key_id = '',
                private_key = '',
                client_email = '',
                client_id = ''
            )
        else:
            return GoogleDriveServiceAccountCredentials(
                project_id = '',
                private_key_id = '',
                private_key = '',
                client_email = '',
                client_id = '',
        )
        """

    def testGoogleDriveServiceAccountCredentials(self):
        """Test GoogleDriveServiceAccountCredentials"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
