# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_params_summarize import StageParamsSummarize

class TestStageParamsSummarize(unittest.TestCase):
    """StageParamsSummarize unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StageParamsSummarize:
        """Test StageParamsSummarize
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StageParamsSummarize`
        """
        model = StageParamsSummarize()
        if include_optional:
            return StageParamsSummarize(
                prompt = 'Summarize the following {{DOC_COUNT}} documents concisely:

{{DOCUMENTS}}',
                provider = 'openai',
                model_name = 'null',
                inference_name = '',
                document_template = '[{{INDEX}}] {{DOC.content}}
',
                content_field = 'content',
                group_by = 'null',
                output_field = 'summary',
                include_sources = True,
                include_metadata = True,
                max_input_tokens = 100,
                truncation_strategy = 'drop_last',
                temperature = 0.0,
                max_output_tokens = 10,
                output_schema = mixpeek.models.output_schema.Output Schema()
            )
        else:
            return StageParamsSummarize(
        )
        """

    def testStageParamsSummarize(self):
        """Test StageParamsSummarize"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
