# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_namespaces_response import ListNamespacesResponse

class TestListNamespacesResponse(unittest.TestCase):
    """ListNamespacesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListNamespacesResponse:
        """Test ListNamespacesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListNamespacesResponse`
        """
        model = ListNamespacesResponse()
        if include_optional:
            return ListNamespacesResponse(
                results = [
                    mixpeek.models.namespace_model.NamespaceModel(
                        namespace_id = '', 
                        namespace_name = 'spotify_playlists_dev', 
                        infrastructure = mixpeek.models.namespace_infrastructure.NamespaceInfrastructure(
                            ray_cluster_id = 'ray_HqXzyCBw3_uufVPIPFhB9JcGRYnua_cdyyvLY8IzLpul9', 
                            ray_head_node_url = '', 
                            ray_dashboard_url = '', 
                            qdrant_url = '', 
                            qdrant_api_key = '', 
                            qdrant_collection = '012', 
                            compute_tier = null, 
                            max_concurrent_jobs = 1.0, 
                            autoscaling_enabled = True, 
                            min_workers = 0.0, 
                            max_workers = 1.0, 
                            gpu_type = '', 
                            gpus_per_worker = 0.0, 
                            s3_plugin_bucket = 'mixpeek-plugins', 
                            s3_plugin_prefix = '', 
                            max_custom_plugins = 0.0, 
                            max_custom_models = 0.0, ), 
                        cluster_id = '', 
                        description = '', 
                        feature_extractors = [
                            mixpeek.models.base_feature_extractor_model.BaseFeatureExtractorModel(
                                feature_extractor_name = '', 
                                version = '', 
                                params = mixpeek.models.params.Params(), 
                                feature_extractor_id = '', )
                            ], 
                        payload_indexes = [
                            mixpeek.models.payload_index_config.PayloadIndexConfig(
                                field_name = '0', 
                                type = null, 
                                field_schema = null, 
                                is_protected = True, )
                            ], 
                        document_count = 56, 
                        bucket_count = 56, 
                        collection_count = 56, 
                        object_count = 56, 
                        auto_create_indexes = True, 
                        vector_inference_map = {
                            'key' : ''
                            }, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total_count = 56,
                stats = mixpeek.models.namespace_list_stats.NamespaceListStats(
                    total_feature_extractors = 56, 
                    total_payload_indexes = 56, 
                    total_documents = 56, 
                    total_buckets = 56, 
                    total_collections = 56, 
                    total_objects = 56, 
                    avg_feature_extractors_per_namespace = 1.337, 
                    avg_payload_indexes_per_namespace = 1.337, 
                    avg_documents_per_namespace = 1.337, 
                    avg_buckets_per_namespace = 1.337, 
                    avg_collections_per_namespace = 1.337, 
                    avg_objects_per_namespace = 1.337, )
            )
        else:
            return ListNamespacesResponse(
                results = [
                    mixpeek.models.namespace_model.NamespaceModel(
                        namespace_id = '', 
                        namespace_name = 'spotify_playlists_dev', 
                        infrastructure = mixpeek.models.namespace_infrastructure.NamespaceInfrastructure(
                            ray_cluster_id = 'ray_HqXzyCBw3_uufVPIPFhB9JcGRYnua_cdyyvLY8IzLpul9', 
                            ray_head_node_url = '', 
                            ray_dashboard_url = '', 
                            qdrant_url = '', 
                            qdrant_api_key = '', 
                            qdrant_collection = '012', 
                            compute_tier = null, 
                            max_concurrent_jobs = 1.0, 
                            autoscaling_enabled = True, 
                            min_workers = 0.0, 
                            max_workers = 1.0, 
                            gpu_type = '', 
                            gpus_per_worker = 0.0, 
                            s3_plugin_bucket = 'mixpeek-plugins', 
                            s3_plugin_prefix = '', 
                            max_custom_plugins = 0.0, 
                            max_custom_models = 0.0, ), 
                        cluster_id = '', 
                        description = '', 
                        feature_extractors = [
                            mixpeek.models.base_feature_extractor_model.BaseFeatureExtractorModel(
                                feature_extractor_name = '', 
                                version = '', 
                                params = mixpeek.models.params.Params(), 
                                feature_extractor_id = '', )
                            ], 
                        payload_indexes = [
                            mixpeek.models.payload_index_config.PayloadIndexConfig(
                                field_name = '0', 
                                type = null, 
                                field_schema = null, 
                                is_protected = True, )
                            ], 
                        document_count = 56, 
                        bucket_count = 56, 
                        collection_count = 56, 
                        object_count = 56, 
                        auto_create_indexes = True, 
                        vector_inference_map = {
                            'key' : ''
                            }, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total_count = 56,
        )
        """

    def testListNamespacesResponse(self):
        """Test ListNamespacesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
