# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_collections_response import ListCollectionsResponse

class TestListCollectionsResponse(unittest.TestCase):
    """ListCollectionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListCollectionsResponse:
        """Test ListCollectionsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListCollectionsResponse`
        """
        model = ListCollectionsResponse()
        if include_optional:
            return ListCollectionsResponse(
                results = [
                    mixpeek.models.collection_response.CollectionResponse(
                        collection_id = '', 
                        collection_name = '012', 
                        description = '', 
                        input_schema = null, 
                        output_schema = null, 
                        feature_extractor = null, 
                        source = null, 
                        source_bucket_schemas = {
                            'key' : {
                                'key' : null
                                }
                            }, 
                        source_lineage = [
                            mixpeek.models.single_lineage_entry.SingleLineageEntry(
                                source_config = null, 
                                feature_extractor = null, 
                                output_schema = null, )
                            ], 
                        vector_indexes = [
                            null
                            ], 
                        payload_indexes = [
                            null
                            ], 
                        enabled = True, 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        document_count = 56, 
                        schema_version = 56, 
                        last_schema_sync = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        schema_sync_enabled = True, 
                        taxonomy_applications = [
                            {
                                'key' : null
                                }
                            ], 
                        cluster_applications = [
                            mixpeek.models.cluster_application_config.ClusterApplicationConfig(
                                cluster_id = '', 
                                auto_execute_on_batch = True, 
                                min_document_threshold = 56, 
                                cooldown_seconds = 56, 
                                execution_phase = 1.0, 
                                priority = 0.0, )
                            ], 
                        alert_applications = [
                            {
                                'key' : null
                                }
                            ], 
                        taxonomy_count = 56, 
                        retriever_count = 56, )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total_count = 56,
                stats = mixpeek.models.collection_list_stats.CollectionListStats(
                    total_documents = 56, 
                    avg_documents_per_collection = 1.337, 
                    collections_with_taxonomies = 56, 
                    total_feature_extractors = 56, 
                    total_taxonomies = 56, 
                    total_retrievers = 56, )
            )
        else:
            return ListCollectionsResponse(
                results = [
                    mixpeek.models.collection_response.CollectionResponse(
                        collection_id = '', 
                        collection_name = '012', 
                        description = '', 
                        input_schema = null, 
                        output_schema = null, 
                        feature_extractor = null, 
                        source = null, 
                        source_bucket_schemas = {
                            'key' : {
                                'key' : null
                                }
                            }, 
                        source_lineage = [
                            mixpeek.models.single_lineage_entry.SingleLineageEntry(
                                source_config = null, 
                                feature_extractor = null, 
                                output_schema = null, )
                            ], 
                        vector_indexes = [
                            null
                            ], 
                        payload_indexes = [
                            null
                            ], 
                        enabled = True, 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        document_count = 56, 
                        schema_version = 56, 
                        last_schema_sync = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        schema_sync_enabled = True, 
                        taxonomy_applications = [
                            {
                                'key' : null
                                }
                            ], 
                        cluster_applications = [
                            mixpeek.models.cluster_application_config.ClusterApplicationConfig(
                                cluster_id = '', 
                                auto_execute_on_batch = True, 
                                min_document_threshold = 56, 
                                cooldown_seconds = 56, 
                                execution_phase = 1.0, 
                                priority = 0.0, )
                            ], 
                        alert_applications = [
                            {
                                'key' : null
                                }
                            ], 
                        taxonomy_count = 56, 
                        retriever_count = 56, )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total_count = 56,
        )
        """

    def testListCollectionsResponse(self):
        """Test ListCollectionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
