# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.migration_progress import MigrationProgress

class TestMigrationProgress(unittest.TestCase):
    """MigrationProgress unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MigrationProgress:
        """Test MigrationProgress
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MigrationProgress`
        """
        model = MigrationProgress()
        if include_optional:
            return MigrationProgress(
                overall_status = 'draft',
                overall_progress_percent = 0.0,
                current_stage = 'namespace_setup',
                stages = [
                    mixpeek.models.stage_progress.StageProgress(
                        stage = null, 
                        status = null, 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        progress_percent = 0.0, 
                        items_total = 0.0, 
                        items_completed = 0.0, 
                        items_failed = 0.0, 
                        error_message = '', )
                    ],
                resources = [
                    mixpeek.models.resource_progress.ResourceProgress(
                        resource_id = '', 
                        resource_type = null, 
                        status = null, 
                        progress_percent = 0.0, 
                        error_message = '', )
                    ],
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                estimated_completion = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return MigrationProgress(
                overall_status = 'draft',
        )
        """

    def testMigrationProgress(self):
        """Test MigrationProgress"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
