# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.trigger_tier_request import TriggerTierRequest

class TestTriggerTierRequest(unittest.TestCase):
    """TriggerTierRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TriggerTierRequest:
        """Test TriggerTierRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TriggerTierRequest`
        """
        model = TriggerTierRequest()
        if include_optional:
            return TriggerTierRequest(
                internal_id = '',
                namespace_id = '',
                ray_job_id = '',
                completed_tier = 56,
                start_time_ms = 56,
                end_time_ms = 56,
                status = '',
                error = ''
            )
        else:
            return TriggerTierRequest(
                internal_id = '',
                namespace_id = '',
                ray_job_id = '',
                completed_tier = 56,
        )
        """

    def testTriggerTierRequest(self):
        """Test TriggerTierRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
