# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.organization_connections_api import OrganizationConnectionsApi


class TestOrganizationConnectionsApi(unittest.TestCase):
    """OrganizationConnectionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationConnectionsApi()

    def tearDown(self) -> None:
        pass

    def test_create_storage_connection_organizations(self) -> None:
        """Test case for create_storage_connection_organizations

        Create Storage Connection
        """
        pass

    def test_delete_storage_connection_organizations(self) -> None:
        """Test case for delete_storage_connection_organizations

        Delete Storage Connection
        """
        pass

    def test_get_storage_connection_organizations(self) -> None:
        """Test case for get_storage_connection_organizations

        Get Storage Connection
        """
        pass

    def test_list_google_drive_files_organizations_connections(self) -> None:
        """Test case for list_google_drive_files_organizations_connections

        List Google Drive Files
        """
        pass

    def test_list_google_drive_folders_organizations_connections(self) -> None:
        """Test case for list_google_drive_folders_organizations_connections

        List Google Drive Folders
        """
        pass

    def test_list_storage_connections_organizations(self) -> None:
        """Test case for list_storage_connections_organizations

        List Storage Connections
        """
        pass

    def test_test_storage_connection_organizations(self) -> None:
        """Test case for test_storage_connection_organizations

        Test Storage Connection
        """
        pass

    def test_update_storage_connection_organizations(self) -> None:
        """Test case for update_storage_connection_organizations

        Update Storage Connection
        """
        pass


if __name__ == '__main__':
    unittest.main()
