# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.cluster_executions_api import ClusterExecutionsApi


class TestClusterExecutionsApi(unittest.TestCase):
    """ClusterExecutionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ClusterExecutionsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_execution_clusters_id_run(self) -> None:
        """Test case for cancel_execution_clusters_id_run

        Cancel Execution
        """
        pass

    def test_get_cluster_execution(self) -> None:
        """Test case for get_cluster_execution

        Get Latest Cluster Execution
        """
        pass

    def test_get_cluster_execution_by_run(self) -> None:
        """Test case for get_cluster_execution_by_run

        Get Specific Cluster Execution
        """
        pass

    def test_list_cluster_executions(self) -> None:
        """Test case for list_cluster_executions

        List Cluster Execution History
        """
        pass


if __name__ == '__main__':
    unittest.main()
