# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.shared_clusters_triggers_models_create_trigger_request import SharedClustersTriggersModelsCreateTriggerRequest

class TestSharedClustersTriggersModelsCreateTriggerRequest(unittest.TestCase):
    """SharedClustersTriggersModelsCreateTriggerRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SharedClustersTriggersModelsCreateTriggerRequest:
        """Test SharedClustersTriggersModelsCreateTriggerRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SharedClustersTriggersModelsCreateTriggerRequest`
        """
        model = SharedClustersTriggersModelsCreateTriggerRequest()
        if include_optional:
            return SharedClustersTriggersModelsCreateTriggerRequest(
                cluster_id = '',
                execution_config = mixpeek.models.trigger_execution_config.TriggerExecutionConfig(
                    collection_ids = [
                        ''
                        ], 
                    config = mixpeek.models.config.Config(), ),
                trigger_type = 'cron',
                schedule_config = mixpeek.models.schedule_config.Schedule Config(),
                description = '',
                status = 'active'
            )
        else:
            return SharedClustersTriggersModelsCreateTriggerRequest(
                trigger_type = 'cron',
                schedule_config = mixpeek.models.schedule_config.Schedule Config(),
        )
        """

    def testSharedClustersTriggersModelsCreateTriggerRequest(self):
        """Test SharedClustersTriggersModelsCreateTriggerRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
