# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_objects_response import ListObjectsResponse

class TestListObjectsResponse(unittest.TestCase):
    """ListObjectsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListObjectsResponse:
        """Test ListObjectsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListObjectsResponse`
        """
        model = ListObjectsResponse()
        if include_optional:
            return ListObjectsResponse(
                results = [
                    {
                        'key' : null
                        }
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                stats = mixpeek.models.object_list_stats.ObjectListStats(
                    total_objects = 56, 
                    total_blobs = 56, 
                    avg_blobs_per_object = 1.337, 
                    objects_by_status = mixpeek.models.objects_by_status.Objects By Status(), )
            )
        else:
            return ListObjectsResponse(
                results = [
                    {
                        'key' : null
                        }
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
        )
        """

    def testListObjectsResponse(self):
        """Test ListObjectsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
