# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.public_retriever_config_response import PublicRetrieverConfigResponse

class TestPublicRetrieverConfigResponse(unittest.TestCase):
    """PublicRetrieverConfigResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PublicRetrieverConfigResponse:
        """Test PublicRetrieverConfigResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PublicRetrieverConfigResponse`
        """
        model = PublicRetrieverConfigResponse()
        if include_optional:
            return PublicRetrieverConfigResponse(
                public_name = '',
                public_api_key = '',
                display_config = {
                    'key' : null
                    },
                password_protected = True,
                retriever_metadata = mixpeek.models.retriever_metadata.RetrieverMetadata(
                    stages = [
                        None
                        ], 
                    collections = [
                        None
                        ], 
                    capabilities = mixpeek.models.capabilities.Capabilities(), )
            )
        else:
            return PublicRetrieverConfigResponse(
                public_name = '',
                public_api_key = '',
                display_config = {
                    'key' : null
                    },
                password_protected = True,
        )
        """

    def testPublicRetrieverConfigResponse(self):
        """Test PublicRetrieverConfigResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
