# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.dataset_list_response import DatasetListResponse

class TestDatasetListResponse(unittest.TestCase):
    """DatasetListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DatasetListResponse:
        """Test DatasetListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DatasetListResponse`
        """
        model = DatasetListResponse()
        if include_optional:
            return DatasetListResponse(
                datasets = [
                    mixpeek.models.evaluation_dataset.EvaluationDataset(
                        dataset_id = '', 
                        dataset_name = '', 
                        description = '', 
                        queries = [
                            mixpeek.models.ground_truth_query.GroundTruthQuery(
                                query_id = '', 
                                query_input = mixpeek.models.query_input.Query Input(), 
                                relevant_documents = [
                                    ''
                                    ], 
                                relevance_scores = {
                                    'key' : 56
                                    }, )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        namespace_id = '', 
                        internal_id = '', 
                        query_count = 56, 
                        metadata = mixpeek.models.metadata.Metadata(), )
                    ],
                total = 56,
                page = 56,
                page_size = 56
            )
        else:
            return DatasetListResponse(
                datasets = [
                    mixpeek.models.evaluation_dataset.EvaluationDataset(
                        dataset_id = '', 
                        dataset_name = '', 
                        description = '', 
                        queries = [
                            mixpeek.models.ground_truth_query.GroundTruthQuery(
                                query_id = '', 
                                query_input = mixpeek.models.query_input.Query Input(), 
                                relevant_documents = [
                                    ''
                                    ], 
                                relevance_scores = {
                                    'key' : 56
                                    }, )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        namespace_id = '', 
                        internal_id = '', 
                        query_count = 56, 
                        metadata = mixpeek.models.metadata.Metadata(), )
                    ],
                total = 56,
                page = 56,
                page_size = 56,
        )
        """

    def testDatasetListResponse(self):
        """Test DatasetListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
