# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DateTruncUnit(str, Enum):
    """
    Date truncation units for time-based grouping.  Used to group data by time periods.  Values:     YEAR: Group by year     MONTH: Group by month     WEEK: Group by week     DAY: Group by day     HOUR: Group by hour     MINUTE: Group by minute     SECOND: Group by second  Examples:     - Use DAY to group video uploads by day     - Use MONTH to analyze monthly trends
    """

    """
    allowed enum values
    """
    YEAR = 'year'
    MONTH = 'month'
    WEEK = 'week'
    DAY = 'day'
    HOUR = 'hour'
    MINUTE = 'minute'
    SECOND = 'second'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DateTruncUnit from a JSON string"""
        return cls(json.loads(json_str))


