# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.raw_inference_request import RawInferenceRequest

class TestRawInferenceRequest(unittest.TestCase):
    """RawInferenceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RawInferenceRequest:
        """Test RawInferenceRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RawInferenceRequest`
        """
        model = RawInferenceRequest()
        if include_optional:
            return RawInferenceRequest(
                provider = '',
                model = '',
                inference_name = '',
                feature_uri = '',
                inputs = mixpeek.models.inputs.Inputs(),
                parameters = mixpeek.models.parameters.Parameters(),
                enable_semantic_cache = True,
                cache_delta = 0.0
            )
        else:
            return RawInferenceRequest(
                inputs = mixpeek.models.inputs.Inputs(),
        )
        """

    def testRawInferenceRequest(self):
        """Test RawInferenceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
