# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.update_object_request import UpdateObjectRequest

class TestUpdateObjectRequest(unittest.TestCase):
    """UpdateObjectRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateObjectRequest:
        """Test UpdateObjectRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateObjectRequest`
        """
        model = UpdateObjectRequest()
        if include_optional:
            return UpdateObjectRequest(
                key_prefix = '',
                blobs = [
                    mixpeek.models.create_blob_request.CreateBlobRequest(
                        property = '0', 
                        key_prefix = '', 
                        type = null, 
                        data = null, 
                        upload_id = 'upl_z', 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        canonicalize_source = True, 
                        force_remirror = True, )
                    ],
                metadata = mixpeek.models.metadata.Metadata(),
                skip_duplicates = True
            )
        else:
            return UpdateObjectRequest(
        )
        """

    def testUpdateObjectRequest(self):
        """Test UpdateObjectRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
