# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.confirm_payment_method_response import ConfirmPaymentMethodResponse

class TestConfirmPaymentMethodResponse(unittest.TestCase):
    """ConfirmPaymentMethodResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConfirmPaymentMethodResponse:
        """Test ConfirmPaymentMethodResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConfirmPaymentMethodResponse`
        """
        model = ConfirmPaymentMethodResponse()
        if include_optional:
            return ConfirmPaymentMethodResponse(
                success = True,
                payment_method = mixpeek.models.payment_method_info.PaymentMethodInfo(
                    payment_method_id = '', 
                    type = '', 
                    card_last4 = '', 
                    card_brand = '', ),
                auto_billing_enabled = True,
                billing_period_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return ConfirmPaymentMethodResponse(
                payment_method = mixpeek.models.payment_method_info.PaymentMethodInfo(
                    payment_method_id = '', 
                    type = '', 
                    card_last4 = '', 
                    card_brand = '', ),
                auto_billing_enabled = True,
                billing_period_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testConfirmPaymentMethodResponse(self):
        """Test ConfirmPaymentMethodResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
