# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.notification_priority import NotificationPriority
from mixpeek.models.notification_type import NotificationType
from typing import Optional, Set
from typing_extensions import Self

class Notification(BaseModel):
    """
    Model for a notification instance.
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="Unique ID")
    type: NotificationType = Field(description="Notification type")
    priority: NotificationPriority = Field(description="Priority level")
    title: StrictStr = Field(description="Notification title")
    content: StrictStr = Field(description="Notification content")
    created_at: Optional[datetime] = Field(default=None, description="Creation timestamp")
    organization_id: StrictStr = Field(description="Organization ID")
    user_id: Optional[StrictStr] = Field(default=None, description="User ID (if applicable)")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Additional metadata")
    delivery_status: Optional[Dict[str, StrictStr]] = Field(default=None, description="Delivery status by channel")
    read: Optional[StrictBool] = Field(default=False, description="Whether the notification has been read")
    read_at: Optional[datetime] = Field(default=None, description="When the notification was read")
    __properties: ClassVar[List[str]] = ["id", "type", "priority", "title", "content", "created_at", "organization_id", "user_id", "metadata", "delivery_status", "read", "read_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Notification from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Notification from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "type": obj.get("type"),
            "priority": obj.get("priority"),
            "title": obj.get("title"),
            "content": obj.get("content"),
            "created_at": obj.get("created_at"),
            "organization_id": obj.get("organization_id"),
            "user_id": obj.get("user_id"),
            "metadata": obj.get("metadata"),
            "delivery_status": obj.get("delivery_status"),
            "read": obj.get("read") if obj.get("read") is not None else False,
            "read_at": obj.get("read_at")
        })
        return _obj


