# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from mixpeek.models.input_mapping_source import InputMappingSource
from typing import Optional, Set
from typing_extensions import Self

class AlertInputMapping(BaseModel):
    """
    Maps a retriever input to a document field or constant.  Input mappings define how to construct retriever inputs from the ingested document. This allows the same alert to be used with different collections that have different field structures.  Examples:     # Map document embedding to retriever query     {         \"input_key\": \"query_embedding\",         \"source\": {\"source_type\": \"document_field\", \"path\": \"features.video_embedding\"}     }      # Use constant collection for search target     {         \"input_key\": \"collection_id\",         \"source\": {\"source_type\": \"constant\", \"value\": \"col_known_incidents\"}     }  Attributes:     input_key: The retriever input parameter name     source: Where to get the value from
    """ # noqa: E501
    input_key: StrictStr = Field(description="The retriever input parameter name")
    source: InputMappingSource = Field(description="Where to get the value from")
    __properties: ClassVar[List[str]] = ["input_key", "source"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AlertInputMapping from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AlertInputMapping from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "input_key": obj.get("input_key"),
            "source": InputMappingSource.from_dict(obj["source"]) if obj.get("source") is not None else None
        })
        return _obj


