# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FilterOperator1(str, Enum):
    """
    Supported filter operators across database implementations.
    """

    """
    allowed enum values
    """
    EQ = 'eq'
    NE = 'ne'
    GT = 'gt'
    LT = 'lt'
    GTE = 'gte'
    LTE = 'lte'
    IN = 'in'
    NIN = 'nin'
    CONTAINS = 'contains'
    STARTS_WITH = 'starts_with'
    ENDS_WITH = 'ends_with'
    REGEX = 'regex'
    EXISTS = 'exists'
    IS_NULL = 'is_null'
    TEXT = 'text'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FilterOperator1 from a JSON string"""
        return cls(json.loads(json_str))


