# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ResourceResultStatus(str, Enum):
    """
    Status of a resource creation attempt.
    """

    """
    allowed enum values
    """
    CREATED = 'created'
    SKIPPED = 'skipped'
    FAILED = 'failed'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ResourceResultStatus from a JSON string"""
        return cls(json.loads(json_str))


