# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.provider_config import ProviderConfig

class TestProviderConfig(unittest.TestCase):
    """ProviderConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProviderConfig:
        """Test ProviderConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProviderConfig`
        """
        model = ProviderConfig()
        if include_optional:
            return ProviderConfig(
                provider_type = 'postgresql',
                credentials = mixpeek.models.postgre_sql_credentials.PostgreSQLCredentials(
                    type = 'username_password', 
                    username = '', 
                    password = '', ),
                shared_drive_id = '',
                impersonate_user = '',
                region = 'auto',
                endpoint_url = 'https://fly.storage.tigris.dev',
                use_ssl = True,
                verify_ssl = True,
                account = '',
                warehouse = '',
                database = '',
                var_schema = 'public',
                role = '',
                incremental_column = '',
                primary_key_columns = [
                    ''
                    ],
                query_timeout_seconds = 1.0,
                fetch_size = 100.0,
                site_id = '',
                drive_id = '',
                folder_path = '',
                host = '',
                port = 1.0,
                ssl_mode = 'prefer'
            )
        else:
            return ProviderConfig(
                credentials = mixpeek.models.postgre_sql_credentials.PostgreSQLCredentials(
                    type = 'username_password', 
                    username = '', 
                    password = '', ),
                region = 'auto',
                account = '',
                warehouse = '',
                database = '',
                host = '',
        )
        """

    def testProviderConfig(self):
        """Test ProviderConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
