# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_sessions_response import ListSessionsResponse

class TestListSessionsResponse(unittest.TestCase):
    """ListSessionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListSessionsResponse:
        """Test ListSessionsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListSessionsResponse`
        """
        model = ListSessionsResponse()
        if include_optional:
            return ListSessionsResponse(
                results = [
                    mixpeek.models.get_session_response.GetSessionResponse(
                        session_id = '', 
                        namespace_id = '', 
                        internal_id = '', 
                        user_id = '', 
                        session_name = '', 
                        agent_config = null, 
                        user_memory = mixpeek.models.user_memory.User Memory(), 
                        status = null, 
                        message_count = 56, 
                        stats = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_activity_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total = 56,
                pagination = mixpeek.models.pagination.Pagination()
            )
        else:
            return ListSessionsResponse(
                results = [
                    mixpeek.models.get_session_response.GetSessionResponse(
                        session_id = '', 
                        namespace_id = '', 
                        internal_id = '', 
                        user_id = '', 
                        session_name = '', 
                        agent_config = null, 
                        user_memory = mixpeek.models.user_memory.User Memory(), 
                        status = null, 
                        message_count = 56, 
                        stats = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_activity_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total = 56,
                pagination = mixpeek.models.pagination.Pagination(),
        )
        """

    def testListSessionsResponse(self):
        """Test ListSessionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
