# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.batch_upload_response import BatchUploadResponse

class TestBatchUploadResponse(unittest.TestCase):
    """BatchUploadResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BatchUploadResponse:
        """Test BatchUploadResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BatchUploadResponse`
        """
        model = BatchUploadResponse()
        if include_optional:
            return BatchUploadResponse(
                uploads = [
                    mixpeek.models.upload_response.UploadResponse(
                        upload_id = '', 
                        bucket_id = '', 
                        filename = '', 
                        content_type = '', 
                        file_size_bytes = 56, 
                        presigned_url = '0', 
                        presigned_url_expiration = 56, 
                        s3_key = '', 
                        status = null, 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        create_object_on_confirm = True, 
                        object_metadata = mixpeek.models.object_metadata.Object Metadata(), 
                        blob_property = '', 
                        blob_type = '', 
                        file_hash = '', 
                        skip_duplicates = True, 
                        is_duplicate = True, 
                        duplicate_of_upload_id = '', 
                        skipped_unique_key = True, 
                        existing_object_id = '', 
                        message = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        etag = '', 
                        object_id = '', 
                        task_id = '', )
                    ],
                total = 56
            )
        else:
            return BatchUploadResponse(
                uploads = [
                    mixpeek.models.upload_response.UploadResponse(
                        upload_id = '', 
                        bucket_id = '', 
                        filename = '', 
                        content_type = '', 
                        file_size_bytes = 56, 
                        presigned_url = '0', 
                        presigned_url_expiration = 56, 
                        s3_key = '', 
                        status = null, 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        create_object_on_confirm = True, 
                        object_metadata = mixpeek.models.object_metadata.Object Metadata(), 
                        blob_property = '', 
                        blob_type = '', 
                        file_hash = '', 
                        skip_duplicates = True, 
                        is_duplicate = True, 
                        duplicate_of_upload_id = '', 
                        skipped_unique_key = True, 
                        existing_object_id = '', 
                        message = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        etag = '', 
                        object_id = '', 
                        task_id = '', )
                    ],
                total = 56,
        )
        """

    def testBatchUploadResponse(self):
        """Test BatchUploadResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
