# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.feature_model import FeatureModel

class TestFeatureModel(unittest.TestCase):
    """FeatureModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FeatureModel:
        """Test FeatureModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FeatureModel`
        """
        model = FeatureModel()
        if include_optional:
            return FeatureModel(
                feature_extractor_id = '',
                payload = mixpeek.models.payload.Payload(),
                vectors = None
            )
        else:
            return FeatureModel(
                feature_extractor_id = '',
        )
        """

    def testFeatureModel(self):
        """Test FeatureModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
