# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.cluster_execution_result import ClusterExecutionResult

class TestClusterExecutionResult(unittest.TestCase):
    """ClusterExecutionResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClusterExecutionResult:
        """Test ClusterExecutionResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClusterExecutionResult`
        """
        model = ClusterExecutionResult()
        if include_optional:
            return ClusterExecutionResult(
                run_id = 'run_C',
                cluster_id = 'clust_C',
                status = 'pending',
                num_clusters = 0.0,
                num_points = 0.0,
                metrics = mixpeek.models.cluster_execution_metrics.ClusterExecutionMetrics(
                    silhouette_score = -1.0, 
                    davies_bouldin_index = 0.0, 
                    calinski_harabasz_score = 0.0, ),
                centroids = [
                    mixpeek.models.cluster_execution_centroid.ClusterExecutionCentroid(
                        cluster_id = 'cl_4', 
                        num_members = 0.0, 
                        label = '', 
                        summary = '', 
                        keywords = [
                            ''
                            ], )
                    ],
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                error_message = '',
                llm_labeling_errors = [
                    ''
                    ]
            )
        else:
            return ClusterExecutionResult(
                run_id = 'run_C',
                cluster_id = 'clust_C',
                status = 'pending',
                num_clusters = 0.0,
                num_points = 0.0,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testClusterExecutionResult(self):
        """Test ClusterExecutionResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
