# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.adhoc_execution_detail import AdhocExecutionDetail

class TestAdhocExecutionDetail(unittest.TestCase):
    """AdhocExecutionDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdhocExecutionDetail:
        """Test AdhocExecutionDetail
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdhocExecutionDetail`
        """
        model = AdhocExecutionDetail()
        if include_optional:
            return AdhocExecutionDetail(
                execution_id = '',
                execution_mode = '',
                status = '',
                timestamp = None,
                duration_ms = 0.0,
                credits_used = 0.0,
                total_processed = 0.0,
                total_returned = 0.0,
                cache_hit_rate = 0.0,
                query_summary = '',
                stages_completed = 0.0,
                total_stages = 0.0,
                collection_ids = [
                    ''
                    ],
                inputs = '',
                inputs_hash = ''
            )
        else:
            return AdhocExecutionDetail(
                execution_id = '',
                execution_mode = '',
                status = '',
                timestamp = None,
                duration_ms = 0.0,
                credits_used = 0.0,
                total_processed = 0.0,
                total_returned = 0.0,
                stages_completed = 0.0,
                total_stages = 0.0,
        )
        """

    def testAdhocExecutionDetail(self):
        """Test AdhocExecutionDetail"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
