# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List
from mixpeek.models.configs import Configs
from mixpeek.models.notification_channel import NotificationChannel
from typing import Optional, Set
from typing_extensions import Self

class WebhookChannelOutput(BaseModel):
    """
    Notification channel configuration for webhook delivery.  Defines how and where webhook event notifications should be delivered. Each webhook can have multiple channels configured for redundancy or different notification audiences.  Supported Channels:     - EMAIL: Send notifications via email to specified recipients     - SLACK: Post messages to Slack channels or direct messages     - WEBHOOK: HTTP POST to external endpoints (standard webhooks)  Use Cases:     - Route critical alerts to Slack and email simultaneously     - Send audit trail events to external webhook endpoints     - Notify team members via email for object lifecycle events     - Post cluster completion status to Slack channels  Requirements:     - Channel type must match the config type (discriminated union)     - Each config must have valid credentials/endpoints configured     - Channel configs are validated at webhook creation time
    """ # noqa: E501
    channel: NotificationChannel = Field(description="REQUIRED. The notification channel type for delivery. Determines which delivery mechanism is used (email, Slack, webhook). Must match the type of the configs field.")
    configs: Configs
    __properties: ClassVar[List[str]] = ["channel", "configs"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WebhookChannelOutput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of configs
        if self.configs:
            _dict['configs'] = self.configs.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WebhookChannelOutput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "channel": obj.get("channel"),
            "configs": Configs.from_dict(obj["configs"]) if obj.get("configs") is not None else None
        })
        return _obj


