# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.filter_condition import FilterCondition

class TestFilterCondition(unittest.TestCase):
    """FilterCondition unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FilterCondition:
        """Test FilterCondition
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FilterCondition`
        """
        model = FilterCondition()
        if include_optional:
            return FilterCondition(
                var_field = '',
                operator = 'eq',
                value = mixpeek.models.dynamic_value.DynamicValue(
                    type = 'dynamic', 
                    field = '', )
            )
        else:
            return FilterCondition(
                var_field = '',
                value = mixpeek.models.dynamic_value.DynamicValue(
                    type = 'dynamic', 
                    field = '', ),
        )
        """

    def testFilterCondition(self):
        """Test FilterCondition"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
