# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.hdbscan_parameters import HdbscanParameters

class TestHdbscanParameters(unittest.TestCase):
    """HdbscanParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HdbscanParameters:
        """Test HdbscanParameters
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `HdbscanParameters`
        """
        model = HdbscanParameters()
        if include_optional:
            return HdbscanParameters(
                min_cluster_size = 2.0,
                min_samples = 1.0,
                cluster_selection_epsilon = 0.0,
                max_cluster_size = 1.0,
                metric = 'euclidean',
                alpha = 1.337,
                cluster_selection_method = 'eom',
                allow_single_cluster = True,
                prediction_data = True,
                match_reference_implementation = True
            )
        else:
            return HdbscanParameters(
        )
        """

    def testHdbscanParameters(self):
        """Test HdbscanParameters"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
