# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.audit_event_list_response import AuditEventListResponse

class TestAuditEventListResponse(unittest.TestCase):
    """AuditEventListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuditEventListResponse:
        """Test AuditEventListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuditEventListResponse`
        """
        model = AuditEventListResponse()
        if include_optional:
            return AuditEventListResponse(
                results = [
                    mixpeek.models.audit_event_response.AuditEventResponse(
                        audit_id = '', 
                        timestamp = null, 
                        resource_type = '', 
                        resource_id = '', 
                        action = '', 
                        actor_id = '', 
                        actor_type = 'user', 
                        status = 'success', 
                        changes = null, 
                        ip_address = '', 
                        user_agent = '', )
                    ],
                total = 56,
                skip = 56,
                limit = 56
            )
        else:
            return AuditEventListResponse(
                results = [
                    mixpeek.models.audit_event_response.AuditEventResponse(
                        audit_id = '', 
                        timestamp = null, 
                        resource_type = '', 
                        resource_id = '', 
                        action = '', 
                        actor_id = '', 
                        actor_type = 'user', 
                        status = 'success', 
                        changes = null, 
                        ip_address = '', 
                        user_agent = '', )
                    ],
                total = 56,
                skip = 56,
                limit = 56,
        )
        """

    def testAuditEventListResponse(self):
        """Test AuditEventListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
