# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.vector_index import VectorIndex

class TestVectorIndex(unittest.TestCase):
    """VectorIndex unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VectorIndex:
        """Test VectorIndex
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VectorIndex`
        """
        model = VectorIndex()
        if include_optional:
            return VectorIndex(
                name = '',
                description = '0123456789',
                dimensions = 1.0,
                type = 'dense',
                distance = 'cosine',
                datatype = 'float32',
                on_disk = True,
                supported_inputs = [
                    'string'
                    ],
                inference_name = '',
                inference_service_id = '',
                purpose = 'text',
                vector_name_override = ''
            )
        else:
            return VectorIndex(
                description = '0123456789',
                type = 'dense',
        )
        """

    def testVectorIndex(self):
        """Test VectorIndex"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
