# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.collections_api import CollectionsApi


class TestCollectionsApi(unittest.TestCase):
    """CollectionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CollectionsApi()

    def tearDown(self) -> None:
        pass

    def test_clone_collection(self) -> None:
        """Test case for clone_collection

        Clone Collection
        """
        pass

    def test_create_collection(self) -> None:
        """Test case for create_collection

        Create Collection
        """
        pass

    def test_delete_collection(self) -> None:
        """Test case for delete_collection

        Delete Collection
        """
        pass

    def test_describe_collection_features(self) -> None:
        """Test case for describe_collection_features

        Describe collection features
        """
        pass

    def test_export_collection(self) -> None:
        """Test case for export_collection

        Export Collection
        """
        pass

    def test_get_collection(self) -> None:
        """Test case for get_collection

        Get Collection
        """
        pass

    def test_list_collections(self) -> None:
        """Test case for list_collections

        List Collections
        """
        pass

    def test_trigger_collection(self) -> None:
        """Test case for trigger_collection

        Trigger Collection Processing
        """
        pass

    def test_update_collection(self) -> None:
        """Test case for update_collection

        Update Collection
        """
        pass


if __name__ == '__main__':
    unittest.main()
