# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_cluster_executions_response import ListClusterExecutionsResponse

class TestListClusterExecutionsResponse(unittest.TestCase):
    """ListClusterExecutionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListClusterExecutionsResponse:
        """Test ListClusterExecutionsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListClusterExecutionsResponse`
        """
        model = ListClusterExecutionsResponse()
        if include_optional:
            return ListClusterExecutionsResponse(
                results = [
                    mixpeek.models.cluster_execution_result.ClusterExecutionResult(
                        run_id = 'run_C', 
                        cluster_id = 'clust_C', 
                        status = 'pending', 
                        num_clusters = 0.0, 
                        num_points = 0.0, 
                        metrics = mixpeek.models.cluster_execution_metrics.ClusterExecutionMetrics(
                            silhouette_score = -1.0, 
                            davies_bouldin_index = 0.0, 
                            calinski_harabasz_score = 0.0, ), 
                        centroids = [
                            mixpeek.models.cluster_execution_centroid.ClusterExecutionCentroid(
                                cluster_id = 'cl_4', 
                                num_members = 0.0, 
                                label = '', 
                                summary = '', 
                                keywords = [
                                    ''
                                    ], )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_message = '', 
                        llm_labeling_errors = [
                            ''
                            ], )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total_count = 0.0,
                stats = mixpeek.models.cluster_execution_list_stats.ClusterExecutionListStats(
                    total_executions = 0.0, 
                    executions_by_status = {
                        'key' : 56
                        }, 
                    avg_execution_time_ms = 0.0, 
                    total_documents_clustered = 0.0, 
                    avg_num_clusters = 0.0, )
            )
        else:
            return ListClusterExecutionsResponse(
                results = [
                    mixpeek.models.cluster_execution_result.ClusterExecutionResult(
                        run_id = 'run_C', 
                        cluster_id = 'clust_C', 
                        status = 'pending', 
                        num_clusters = 0.0, 
                        num_points = 0.0, 
                        metrics = mixpeek.models.cluster_execution_metrics.ClusterExecutionMetrics(
                            silhouette_score = -1.0, 
                            davies_bouldin_index = 0.0, 
                            calinski_harabasz_score = 0.0, ), 
                        centroids = [
                            mixpeek.models.cluster_execution_centroid.ClusterExecutionCentroid(
                                cluster_id = 'cl_4', 
                                num_members = 0.0, 
                                label = '', 
                                summary = '', 
                                keywords = [
                                    ''
                                    ], )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_message = '', 
                        llm_labeling_errors = [
                            ''
                            ], )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total_count = 0.0,
        )
        """

    def testListClusterExecutionsResponse(self):
        """Test ListClusterExecutionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
