# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_params_code_execution import StageParamsCodeExecution

class TestStageParamsCodeExecution(unittest.TestCase):
    """StageParamsCodeExecution unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StageParamsCodeExecution:
        """Test StageParamsCodeExecution
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StageParamsCodeExecution`
        """
        model = StageParamsCodeExecution()
        if include_optional:
            return StageParamsCodeExecution(
                code = 'result = [{'word_count': len(d.get('content', '').split())} for d in docs]',
                language = 'python',
                output_field = 'metadata.computed',
                result_variable = 'result',
                timeout_ms = 100,
                max_output_size = 1024,
                env = {
                    'key' : ''
                    },
                on_error = 'skip'
            )
        else:
            return StageParamsCodeExecution(
        )
        """

    def testStageParamsCodeExecution(self):
        """Test StageParamsCodeExecution"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
