# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_executions_response import ListExecutionsResponse

class TestListExecutionsResponse(unittest.TestCase):
    """ListExecutionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListExecutionsResponse:
        """Test ListExecutionsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListExecutionsResponse`
        """
        model = ListExecutionsResponse()
        if include_optional:
            return ListExecutionsResponse(
                results = [
                    mixpeek.models.retriever_execution_summary.RetrieverExecutionSummary(
                        execution_id = '', 
                        status = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        duration_ms = 0.0, 
                        credits_used = 0.0, 
                        total_processed = 0.0, 
                        total_returned = 0.0, 
                        cache_hit_rate = 0.0, 
                        inputs_hash = '', 
                        query_summary = '', )
                    ],
                pagination = mixpeek.models.pagination_metadata.PaginationMetadata(
                    total = 0.0, 
                    limit = 0.0, 
                    offset = 0.0, 
                    has_next = True, )
            )
        else:
            return ListExecutionsResponse(
                pagination = mixpeek.models.pagination_metadata.PaginationMetadata(
                    total = 0.0, 
                    limit = 0.0, 
                    offset = 0.0, 
                    has_next = True, ),
        )
        """

    def testListExecutionsResponse(self):
        """Test ListExecutionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
