# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.optics_params import OPTICSParams

class TestOPTICSParams(unittest.TestCase):
    """OPTICSParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OPTICSParams:
        """Test OPTICSParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OPTICSParams`
        """
        model = OPTICSParams()
        if include_optional:
            return OPTICSParams(
                min_samples = 2.0,
                max_eps = 1.337,
                metric = 'minkowski',
                p = 1.337,
                metric_params = mixpeek.models.metric_params.Metric Params(),
                cluster_method = 'xi',
                eps = 1.337,
                xi = 0.0,
                predecessor_correction = True,
                min_cluster_size = 1.337,
                algorithm = 'auto',
                leaf_size = 1.0,
                n_jobs = 56
            )
        else:
            return OPTICSParams(
        )
        """

    def testOPTICSParams(self):
        """Test OPTICSParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
