# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.analytics_collections_api import AnalyticsCollectionsApi


class TestAnalyticsCollectionsApi(unittest.TestCase):
    """AnalyticsCollectionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AnalyticsCollectionsApi()

    def tearDown(self) -> None:
        pass

    def test_get_collection_overview_analytics(self) -> None:
        """Test case for get_collection_overview_analytics

        Get Collection Overview
        """
        pass

    def test_get_document_growth_analytics(self) -> None:
        """Test case for get_document_growth_analytics

        Get Document Growth
        """
        pass

    def test_get_extractor_performance_analytics(self) -> None:
        """Test case for get_extractor_performance_analytics

        Get Extractor Performance
        """
        pass

    def test_get_failure_analysis_analytics(self) -> None:
        """Test case for get_failure_analysis_analytics

        Get Failure Analysis
        """
        pass

    def test_get_latency_metrics_analytics(self) -> None:
        """Test case for get_latency_metrics_analytics

        Get Latency Metrics
        """
        pass


if __name__ == '__main__':
    unittest.main()
