# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NotificationType(str, Enum):
    """
    Enum for notification types.
    """

    """
    allowed enum values
    """
    PIPELINE_SUCCESS = 'pipeline_success'
    PIPELINE_FAILURE = 'pipeline_failure'
    FEATURE_EXTRACTION_SUCCESS = 'feature_extraction_success'
    FEATURE_EXTRACTION_FAILURE = 'feature_extraction_failure'
    SYSTEM_ALERT = 'system_alert'
    BILLING_ALERT = 'billing_alert'
    QUOTA_ALERT = 'quota_alert'
    AUDIT_ALERT = 'audit_alert'
    MAINTENANCE_ALERT = 'maintenance_alert'
    CUSTOM = 'custom'
    ONBOARDING_NUDGE = 'onboarding_nudge'
    ENGAGEMENT_NUDGE = 'engagement_nudge'
    FEATURE_TIP = 'feature_tip'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NotificationType from a JSON string"""
        return cls(json.loads(json_str))


