# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_documents_response import ListDocumentsResponse

class TestListDocumentsResponse(unittest.TestCase):
    """ListDocumentsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListDocumentsResponse:
        """Test ListDocumentsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListDocumentsResponse`
        """
        model = ListDocumentsResponse()
        if include_optional:
            return ListDocumentsResponse(
                results = [
                    {
                        'key' : null
                        }
                    ],
                groups = [
                    mixpeek.models.document_group.DocumentGroup(
                        group_key = null, 
                        documents = [
                            {
                                'key' : null
                                }
                            ], 
                        count = 56, )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                stats = mixpeek.models.document_list_stats.DocumentListStats(
                    total_documents = 56, 
                    avg_blobs_per_document = 1.337, 
                    total_groups = 56, 
                    avg_documents_per_group = 1.337, ),
                group_by_field = ''
            )
        else:
            return ListDocumentsResponse(
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
        )
        """

    def testListDocumentsResponse(self):
        """Test ListDocumentsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
