# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.collection_export_request import CollectionExportRequest

class TestCollectionExportRequest(unittest.TestCase):
    """CollectionExportRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CollectionExportRequest:
        """Test CollectionExportRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CollectionExportRequest`
        """
        model = CollectionExportRequest()
        if include_optional:
            return CollectionExportRequest(
                format = 'json',
                include_vectors = True,
                select_fields = [
                    ''
                    ],
                filters = {
                    'key' : null
                    },
                sample_size = 1.0
            )
        else:
            return CollectionExportRequest(
        )
        """

    def testCollectionExportRequest(self):
        """Test CollectionExportRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
