# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.organization_model import OrganizationModel

class TestOrganizationModel(unittest.TestCase):
    """OrganizationModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationModel:
        """Test OrganizationModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationModel`
        """
        model = OrganizationModel()
        if include_optional:
            return OrganizationModel(
                internal_id = '',
                organization_id = '',
                organization_name = '',
                logo_url = '',
                account_type = 'free',
                credit_count = 56,
                free_tier_usage_limit = 56,
                metadata = mixpeek.models.metadata.Metadata(),
                billing_email = '',
                stripe_customer_id = '',
                default_payment_method_id = '',
                auto_billing_enabled = True,
                billing_cycle_start = 1.0,
                current_month_usage = 56,
                last_invoice_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                billing_period_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                monthly_spending_budget = 56,
                spending_alert_thresholds = [
                    56
                    ],
                spending_alerts_enabled = True,
                spending_alerts_sent = [
                    56
                    ],
                hard_spending_cap = 56,
                hard_cap_enabled = True,
                rate_limits = mixpeek.models.base_rate_limits.BaseRateLimits(
                    metadata = 1.0, 
                    data = 1.0, 
                    search = 1.0, 
                    upload = 1.0, 
                    compute = 1.0, ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                users = [
                    None
                    ],
                infrastructure = mixpeek.models.organization_infrastructure.OrganizationInfrastructure(
                    qdrant_url = '', 
                    qdrant_api_key = '', 
                    ray_head_node_url = '', 
                    ray_dashboard_url = '', 
                    compute_tier = null, ),
                max_dedicated_clusters = 0.0,
                dedicated_cluster_ids = [
                    ''
                    ],
                secrets = {
                    'key' : ''
                    },
                audit_settings = mixpeek.models.audit_settings.AuditSettings(
                    read_auditing_enabled = True, )
            )
        else:
            return OrganizationModel(
                organization_name = '',
        )
        """

    def testOrganizationModel(self):
        """Test OrganizationModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
