# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.health_check_response import HealthCheckResponse

class TestHealthCheckResponse(unittest.TestCase):
    """HealthCheckResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HealthCheckResponse:
        """Test HealthCheckResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `HealthCheckResponse`
        """
        model = HealthCheckResponse()
        if include_optional:
            return HealthCheckResponse(
                status = 'OK',
                data = mixpeek.models.health_service_status.HealthServiceStatus(
                    cache = True, 
                    metadata = True, 
                    vector_store = True, 
                    object_storage = True, 
                    task_queue = True, 
                    inference = True, 
                    analytics = True, ),
                errors = mixpeek.models.health_service_errors.HealthServiceErrors(
                    cache = '', 
                    metadata = '', 
                    vector_store = '', 
                    object_storage = '', 
                    task_queue = '', 
                    inference = '', 
                    analytics = '', ),
                meta = mixpeek.models.meta.Meta()
            )
        else:
            return HealthCheckResponse(
                status = 'OK',
                data = mixpeek.models.health_service_status.HealthServiceStatus(
                    cache = True, 
                    metadata = True, 
                    vector_store = True, 
                    object_storage = True, 
                    task_queue = True, 
                    inference = True, 
                    analytics = True, ),
        )
        """

    def testHealthCheckResponse(self):
        """Test HealthCheckResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
