# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MessageHistoryItem(BaseModel):
    """
    Single message in conversation history.  Attributes:     message_id: Message identifier     role: Message role (user, assistant, tool)     content: Message text content     content_type: Content type (text, tool_call, tool_result)     tool_name: Tool name (if tool message)     tool_inputs: Tool inputs (if tool call)     tool_outputs: Tool outputs (if tool result)     tool_status: Tool execution status (if tool message)     timestamp: Message timestamp
    """ # noqa: E501
    message_id: StrictStr = Field(description="Message identifier")
    role: StrictStr = Field(description="Message role")
    content: StrictStr = Field(description="Message content")
    content_type: StrictStr = Field(description="Content type")
    tool_name: Optional[StrictStr] = Field(default=None, description="Tool name (if tool message)")
    tool_inputs: Optional[StrictStr] = Field(default=None, description="Tool inputs (if tool call)")
    tool_outputs: Optional[StrictStr] = Field(default=None, description="Tool outputs (if tool result)")
    tool_status: Optional[StrictStr] = Field(default=None, description="Tool status (if tool message)")
    timestamp: datetime = Field(description="Message timestamp")
    __properties: ClassVar[List[str]] = ["message_id", "role", "content", "content_type", "tool_name", "tool_inputs", "tool_outputs", "tool_status", "timestamp"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MessageHistoryItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MessageHistoryItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "message_id": obj.get("message_id"),
            "role": obj.get("role"),
            "content": obj.get("content"),
            "content_type": obj.get("content_type"),
            "tool_name": obj.get("tool_name"),
            "tool_inputs": obj.get("tool_inputs"),
            "tool_outputs": obj.get("tool_outputs"),
            "tool_status": obj.get("tool_status"),
            "timestamp": obj.get("timestamp")
        })
        return _obj


