# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.agent_config import AgentConfig

class TestAgentConfig(unittest.TestCase):
    """AgentConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AgentConfig:
        """Test AgentConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AgentConfig`
        """
        model = AgentConfig()
        if include_optional:
            return AgentConfig(
                model = 'gemini-2.0-flash',
                temperature = 0.0,
                max_tokens = 1.0,
                system_prompt = 'You are a helpful AI assistant with access to Mixpeek's data infrastructure.',
                available_tools = [
                    ''
                    ]
            )
        else:
            return AgentConfig(
        )
        """

    def testAgentConfig(self):
        """Test AgentConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
