# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List
from mixpeek.models.bucket_schema_output import BucketSchemaOutput
from mixpeek.models.shared_collection_features_extractors_models_feature_extractor_config_output import SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput
from mixpeek.models.source_config_output import SourceConfigOutput
from typing import Optional, Set
from typing_extensions import Self

class SingleLineageEntry(BaseModel):
    """
    Single entry in the lineage chain of a collection.  Each lineage entry represents one processing stage with one feature extractor.
    """ # noqa: E501
    source_config: SourceConfigOutput = Field(description="Configuration of the source for this lineage entry")
    feature_extractor: SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput = Field(description="Single feature extractor applied at this stage")
    output_schema: BucketSchemaOutput = Field(description="Output schema produced by this processing stage")
    __properties: ClassVar[List[str]] = ["source_config", "feature_extractor", "output_schema"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SingleLineageEntry from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source_config
        if self.source_config:
            _dict['source_config'] = self.source_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of feature_extractor
        if self.feature_extractor:
            _dict['feature_extractor'] = self.feature_extractor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of output_schema
        if self.output_schema:
            _dict['output_schema'] = self.output_schema.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SingleLineageEntry from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "source_config": SourceConfigOutput.from_dict(obj["source_config"]) if obj.get("source_config") is not None else None,
            "feature_extractor": SharedCollectionFeaturesExtractorsModelsFeatureExtractorConfigOutput.from_dict(obj["feature_extractor"]) if obj.get("feature_extractor") is not None else None,
            "output_schema": BucketSchemaOutput.from_dict(obj["output_schema"]) if obj.get("output_schema") is not None else None
        })
        return _obj


