# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.update_spending_caps_request import UpdateSpendingCapsRequest

class TestUpdateSpendingCapsRequest(unittest.TestCase):
    """UpdateSpendingCapsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateSpendingCapsRequest:
        """Test UpdateSpendingCapsRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateSpendingCapsRequest`
        """
        model = UpdateSpendingCapsRequest()
        if include_optional:
            return UpdateSpendingCapsRequest(
                monthly_spending_budget = 0.0,
                spending_alert_thresholds = [
                    56
                    ],
                spending_alerts_enabled = True,
                hard_spending_cap = 0.0,
                hard_cap_enabled = True
            )
        else:
            return UpdateSpendingCapsRequest(
        )
        """

    def testUpdateSpendingCapsRequest(self):
        """Test UpdateSpendingCapsRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
