# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.namespaces_api import NamespacesApi


class TestNamespacesApi(unittest.TestCase):
    """NamespacesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NamespacesApi()

    def tearDown(self) -> None:
        pass

    def test_create_namespace(self) -> None:
        """Test case for create_namespace

        Create Namespace
        """
        pass

    def test_delete_namespace(self) -> None:
        """Test case for delete_namespace

        Delete Namespace
        """
        pass

    def test_get_namespace(self) -> None:
        """Test case for get_namespace

        Get Namespace
        """
        pass

    def test_list_namespaces(self) -> None:
        """Test case for list_namespaces

        List Namespaces
        """
        pass

    def test_patch_namespace(self) -> None:
        """Test case for patch_namespace

        Partially Update Namespace
        """
        pass

    def test_update_namespace(self) -> None:
        """Test case for update_namespace

        Update Namespace
        """
        pass


if __name__ == '__main__':
    unittest.main()
