# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.organization_billing_api import OrganizationBillingApi


class TestOrganizationBillingApi(unittest.TestCase):
    """OrganizationBillingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationBillingApi()

    def tearDown(self) -> None:
        pass

    def test_confirm_payment_method_organizations_billing(self) -> None:
        """Test case for confirm_payment_method_organizations_billing

        Confirm Payment Method
        """
        pass

    def test_disable_auto_billing_organizations(self) -> None:
        """Test case for disable_auto_billing_organizations

        Disable Auto Billing
        """
        pass

    def test_enable_auto_billing_organizations(self) -> None:
        """Test case for enable_auto_billing_organizations

        Enable Auto Billing
        """
        pass

    def test_get_credit_balance_organizations_billing(self) -> None:
        """Test case for get_credit_balance_organizations_billing

        Get Credit Balance
        """
        pass

    def test_get_current_usage_organizations_billing(self) -> None:
        """Test case for get_current_usage_organizations_billing

        Get Current Usage
        """
        pass

    def test_get_payment_method_organizations_billing(self) -> None:
        """Test case for get_payment_method_organizations_billing

        Get Payment Method
        """
        pass

    def test_get_spending_caps_organizations_billing(self) -> None:
        """Test case for get_spending_caps_organizations_billing

        Get Spending Caps
        """
        pass

    def test_get_usage_breakdown_organizations_billing(self) -> None:
        """Test case for get_usage_breakdown_organizations_billing

        Get Usage Breakdown
        """
        pass

    def test_list_invoices_organizations_billing(self) -> None:
        """Test case for list_invoices_organizations_billing

        List Invoices
        """
        pass

    def test_setup_payment_method_organizations_billing(self) -> None:
        """Test case for setup_payment_method_organizations_billing

        Setup Payment Method
        """
        pass

    def test_update_spending_caps_organizations_billing(self) -> None:
        """Test case for update_spending_caps_organizations_billing

        Update Spending Caps
        """
        pass


if __name__ == '__main__':
    unittest.main()
