# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.unified_extractor_list_response import UnifiedExtractorListResponse

class TestUnifiedExtractorListResponse(unittest.TestCase):
    """UnifiedExtractorListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UnifiedExtractorListResponse:
        """Test UnifiedExtractorListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UnifiedExtractorListResponse`
        """
        model = UnifiedExtractorListResponse()
        if include_optional:
            return UnifiedExtractorListResponse(
                success = True,
                extractors = [
                    mixpeek.models.unified_extractor_response.UnifiedExtractorResponse(
                        feature_extractor_name = '', 
                        version = '', 
                        feature_extractor_id = '', 
                        source = null, 
                        description = '', 
                        icon = 'box', 
                        input_schema = mixpeek.models.input_schema.Input Schema(), 
                        output_schema = mixpeek.models.output_schema.Output Schema(), 
                        parameter_schema = mixpeek.models.parameter_schema.Parameter Schema(), 
                        supported_input_types = [
                            ''
                            ], 
                        max_inputs = {
                            'key' : 56
                            }, 
                        default_parameters = mixpeek.models.default_parameters.Default Parameters(), 
                        costs = mixpeek.models.costs_info.CostsInfo(
                            tier = 1.0, 
                            tier_label = '', 
                            rates = [
                                mixpeek.models.cost_rate.CostRate(
                                    unit = null, 
                                    credits_per_unit = 1.0, 
                                    description = '', )
                                ], ), 
                        required_vector_indexes = [
                            mixpeek.models.vector_index_definition.VectorIndexDefinition(
                                feature_uri = '', 
                                name = '0', 
                                description = '0123456789', 
                                type = 'single', 
                                index = null, )
                            ], 
                        required_payload_indexes = [
                            mixpeek.models.payload_index_config.PayloadIndexConfig(
                                field_name = '0', 
                                type = null, 
                                field_schema = null, 
                                is_protected = True, )
                            ], 
                        position_fields = [
                            ''
                            ], 
                        feature_uri = '', 
                        plugin_id = '', 
                        deployed = True, 
                        validation_status = 'pending', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total = 56,
                namespace_id = '',
                builtin_count = 56,
                custom_count = 56
            )
        else:
            return UnifiedExtractorListResponse(
                extractors = [
                    mixpeek.models.unified_extractor_response.UnifiedExtractorResponse(
                        feature_extractor_name = '', 
                        version = '', 
                        feature_extractor_id = '', 
                        source = null, 
                        description = '', 
                        icon = 'box', 
                        input_schema = mixpeek.models.input_schema.Input Schema(), 
                        output_schema = mixpeek.models.output_schema.Output Schema(), 
                        parameter_schema = mixpeek.models.parameter_schema.Parameter Schema(), 
                        supported_input_types = [
                            ''
                            ], 
                        max_inputs = {
                            'key' : 56
                            }, 
                        default_parameters = mixpeek.models.default_parameters.Default Parameters(), 
                        costs = mixpeek.models.costs_info.CostsInfo(
                            tier = 1.0, 
                            tier_label = '', 
                            rates = [
                                mixpeek.models.cost_rate.CostRate(
                                    unit = null, 
                                    credits_per_unit = 1.0, 
                                    description = '', )
                                ], ), 
                        required_vector_indexes = [
                            mixpeek.models.vector_index_definition.VectorIndexDefinition(
                                feature_uri = '', 
                                name = '0', 
                                description = '0123456789', 
                                type = 'single', 
                                index = null, )
                            ], 
                        required_payload_indexes = [
                            mixpeek.models.payload_index_config.PayloadIndexConfig(
                                field_name = '0', 
                                type = null, 
                                field_schema = null, 
                                is_protected = True, )
                            ], 
                        position_fields = [
                            ''
                            ], 
                        feature_uri = '', 
                        plugin_id = '', 
                        deployed = True, 
                        validation_status = 'pending', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total = 56,
                namespace_id = '',
                builtin_count = 56,
                custom_count = 56,
        )
        """

    def testUnifiedExtractorListResponse(self):
        """Test UnifiedExtractorListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
