# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.intent_classification import IntentClassification

class TestIntentClassification(unittest.TestCase):
    """IntentClassification unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IntentClassification:
        """Test IntentClassification
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IntentClassification`
        """
        model = IntentClassification()
        if include_optional:
            return IntentClassification(
                intent = 'ambiguous',
                confidence = 0.0,
                reasoning = '',
                suitable_collections = [
                    mixpeek.models.suitable_collection.SuitableCollection(
                        collection_id = '', 
                        collection_name = '', 
                        feature_extractor = '', 
                        capabilities = [
                            ''
                            ], 
                        match_score = 0.0, )
                    ],
                recommended_action = '',
                clarification_needed = True,
                clarification_options = [
                    mixpeek.models.clarification_option.ClarificationOption(
                        label = '', 
                        description = '', 
                        action = '', )
                    ],
                keywords_found = {
                    'key' : [
                        ''
                        ]
                    }
            )
        else:
            return IntentClassification(
                intent = 'ambiguous',
                confidence = 0.0,
                reasoning = '',
                recommended_action = '',
                clarification_needed = True,
        )
        """

    def testIntentClassification(self):
        """Test IntentClassification"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
