# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ThemeConfig(BaseModel):
    """
    Theme configuration for public retriever UI.  Defines colors, fonts, and visual styling for the public search interface.
    """ # noqa: E501
    primary_color: Optional[StrictStr] = Field(default='#007AFF', description="Primary brand color (hex code)")
    secondary_color: Optional[StrictStr] = Field(default=None, description="Secondary/accent color (hex code)")
    font_family: Optional[StrictStr] = Field(default='system-ui, -apple-system, sans-serif', description="Font family for text")
    background_color: Optional[StrictStr] = Field(default='#FFFFFF', description="Background color (hex code)")
    text_color: Optional[StrictStr] = Field(default='#374151', description="Primary text color (hex code)")
    heading_font_family: Optional[StrictStr] = Field(default=None, description="Optional separate font family for headings")
    surface_color: Optional[StrictStr] = Field(default=None, description="Surface/card background color (hex code)")
    muted_color: Optional[StrictStr] = Field(default=None, description="Muted/secondary text color (hex code)")
    border_color: Optional[StrictStr] = Field(default=None, description="Border color for cards and elements (hex code)")
    border_radius: Optional[StrictStr] = Field(default='12px', description="Default border radius for cards and elements")
    card_style: Optional[StrictStr] = Field(default='elevated', description="Card visual style: elevated (shadow), flat (no shadow), bordered, or glass (frosted glass effect)")
    card_hover_effect: Optional[StrictStr] = Field(default='lift', description="Card hover animation effect: lift (move up), glow, scale, or none")
    __properties: ClassVar[List[str]] = ["primary_color", "secondary_color", "font_family", "background_color", "text_color", "heading_font_family", "surface_color", "muted_color", "border_color", "border_radius", "card_style", "card_hover_effect"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ThemeConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ThemeConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "primary_color": obj.get("primary_color") if obj.get("primary_color") is not None else '#007AFF',
            "secondary_color": obj.get("secondary_color"),
            "font_family": obj.get("font_family") if obj.get("font_family") is not None else 'system-ui, -apple-system, sans-serif',
            "background_color": obj.get("background_color") if obj.get("background_color") is not None else '#FFFFFF',
            "text_color": obj.get("text_color") if obj.get("text_color") is not None else '#374151',
            "heading_font_family": obj.get("heading_font_family"),
            "surface_color": obj.get("surface_color"),
            "muted_color": obj.get("muted_color"),
            "border_color": obj.get("border_color"),
            "border_radius": obj.get("border_radius") if obj.get("border_radius") is not None else '12px',
            "card_style": obj.get("card_style") if obj.get("card_style") is not None else 'elevated',
            "card_hover_effect": obj.get("card_hover_effect") if obj.get("card_hover_effect") is not None else 'lift'
        })
        return _obj


