# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class MeanShiftParams(BaseModel):
    """
    Parameters for Mean Shift clustering algorithm.
    """ # noqa: E501
    bandwidth: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Bandwidth used in the RBF kernel. If None, estimated using sklearn.cluster.estimate_bandwidth")
    seeds: Optional[List[List[Union[StrictFloat, StrictInt]]]] = Field(default=None, description="Seeds used to initialize kernels. If None, all points are used as seeds")
    bin_seeding: Optional[StrictBool] = Field(default=False, description="If true, initial kernel locations are discretized into a grid to speed up algorithm")
    min_bin_freq: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=1, description="Minimum number of seeds within a bin for the bin to be considered")
    cluster_all: Optional[StrictBool] = Field(default=True, description="If true, all points are clustered, even orphans. If false, orphans are given label -1")
    n_jobs: Optional[StrictInt] = Field(default=1, description="Number of parallel jobs to run (-1 means using all processors)")
    max_iter: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=300, description="Maximum number of iterations per seed point before the algorithm stops")
    __properties: ClassVar[List[str]] = ["bandwidth", "seeds", "bin_seeding", "min_bin_freq", "cluster_all", "n_jobs", "max_iter"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MeanShiftParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MeanShiftParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "bandwidth": obj.get("bandwidth"),
            "seeds": obj.get("seeds"),
            "bin_seeding": obj.get("bin_seeding") if obj.get("bin_seeding") is not None else False,
            "min_bin_freq": obj.get("min_bin_freq") if obj.get("min_bin_freq") is not None else 1,
            "cluster_all": obj.get("cluster_all") if obj.get("cluster_all") is not None else True,
            "n_jobs": obj.get("n_jobs") if obj.get("n_jobs") is not None else 1,
            "max_iter": obj.get("max_iter") if obj.get("max_iter") is not None else 300
        })
        return _obj


