# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_create_trigger(self) -> None:
        """Test case for create_trigger

        Create Trigger
        """
        pass

    def test_delete_trigger(self) -> None:
        """Test case for delete_trigger

        Delete Trigger
        """
        pass

    def test_execute_trigger_now(self) -> None:
        """Test case for execute_trigger_now

        Execute Trigger Now
        """
        pass

    def test_get_trigger(self) -> None:
        """Test case for get_trigger

        Get Trigger
        """
        pass

    def test_get_trigger_history(self) -> None:
        """Test case for get_trigger_history

        Get Trigger Execution History
        """
        pass

    def test_list_triggers(self) -> None:
        """Test case for list_triggers

        List Triggers
        """
        pass

    def test_pause_trigger(self) -> None:
        """Test case for pause_trigger

        Pause Trigger
        """
        pass

    def test_resume_trigger(self) -> None:
        """Test case for resume_trigger

        Resume Trigger
        """
        pass

    def test_update_trigger(self) -> None:
        """Test case for update_trigger

        Update Trigger
        """
        pass


if __name__ == '__main__':
    unittest.main()
