# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.retriever_benchmarks_api import RetrieverBenchmarksApi


class TestRetrieverBenchmarksApi(unittest.TestCase):
    """RetrieverBenchmarksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RetrieverBenchmarksApi()

    def tearDown(self) -> None:
        pass

    def test_create_benchmark_retrievers(self) -> None:
        """Test case for create_benchmark_retrievers

        Create benchmark
        """
        pass

    def test_create_benchmark_retrievers_0(self) -> None:
        """Test case for create_benchmark_retrievers_0

        Create benchmark
        """
        pass

    def test_delete_benchmark_retrievers(self) -> None:
        """Test case for delete_benchmark_retrievers

        Delete benchmark
        """
        pass

    def test_delete_benchmark_retrievers_0(self) -> None:
        """Test case for delete_benchmark_retrievers_0

        Delete benchmark
        """
        pass

    def test_get_benchmark_retrievers(self) -> None:
        """Test case for get_benchmark_retrievers

        Get benchmark
        """
        pass

    def test_get_benchmark_retrievers_0(self) -> None:
        """Test case for get_benchmark_retrievers_0

        Get benchmark
        """
        pass

    def test_list_benchmarks_retrievers(self) -> None:
        """Test case for list_benchmarks_retrievers

        List benchmarks
        """
        pass

    def test_list_benchmarks_retrievers_0(self) -> None:
        """Test case for list_benchmarks_retrievers_0

        List benchmarks
        """
        pass


if __name__ == '__main__':
    unittest.main()
