# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.benchmark_comparison import BenchmarkComparison
from mixpeek.models.benchmark_result import BenchmarkResult
from mixpeek.models.benchmark_status import BenchmarkStatus
from mixpeek.models.session_filter_output import SessionFilterOutput
from typing import Optional, Set
from typing_extensions import Self

class BenchmarkResponse(BaseModel):
    """
    Response containing benchmark details and results.
    """ # noqa: E501
    benchmark_id: StrictStr = Field(description="Unique benchmark identifier.")
    benchmark_name: StrictStr = Field(description="Human-readable name.")
    baseline_retriever_id: StrictStr = Field(description="Baseline retriever ID.")
    candidate_retriever_ids: List[StrictStr] = Field(description="Candidate retriever IDs.")
    session_filter: Optional[SessionFilterOutput] = Field(default=None, description="Filter criteria used.")
    session_count: StrictInt = Field(description="Number of sessions in benchmark.")
    status: BenchmarkStatus = Field(description="Current benchmark status.")
    results: Optional[List[BenchmarkResult]] = Field(default=None, description="Results per pipeline (available when completed).")
    comparison: Optional[BenchmarkComparison] = Field(default=None, description="Statistical comparison (available when completed).")
    created_at: datetime = Field(description="Creation timestamp.")
    started_at: Optional[datetime] = Field(default=None, description="Execution start time.")
    completed_at: Optional[datetime] = Field(default=None, description="Completion time.")
    error_message: Optional[StrictStr] = Field(default=None, description="Error message if failed.")
    __properties: ClassVar[List[str]] = ["benchmark_id", "benchmark_name", "baseline_retriever_id", "candidate_retriever_ids", "session_filter", "session_count", "status", "results", "comparison", "created_at", "started_at", "completed_at", "error_message"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BenchmarkResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of session_filter
        if self.session_filter:
            _dict['session_filter'] = self.session_filter.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in results (list)
        _items = []
        if self.results:
            for _item_results in self.results:
                if _item_results:
                    _items.append(_item_results.to_dict())
            _dict['results'] = _items
        # override the default output from pydantic by calling `to_dict()` of comparison
        if self.comparison:
            _dict['comparison'] = self.comparison.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BenchmarkResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "benchmark_id": obj.get("benchmark_id"),
            "benchmark_name": obj.get("benchmark_name"),
            "baseline_retriever_id": obj.get("baseline_retriever_id"),
            "candidate_retriever_ids": obj.get("candidate_retriever_ids"),
            "session_filter": SessionFilterOutput.from_dict(obj["session_filter"]) if obj.get("session_filter") is not None else None,
            "session_count": obj.get("session_count"),
            "status": obj.get("status"),
            "results": [BenchmarkResult.from_dict(_item) for _item in obj["results"]] if obj.get("results") is not None else None,
            "comparison": BenchmarkComparison.from_dict(obj["comparison"]) if obj.get("comparison") is not None else None,
            "created_at": obj.get("created_at"),
            "started_at": obj.get("started_at"),
            "completed_at": obj.get("completed_at"),
            "error_message": obj.get("error_message")
        })
        return _obj


