# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.multimodal_extractor_params import MultimodalExtractorParams

class TestMultimodalExtractorParams(unittest.TestCase):
    """MultimodalExtractorParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MultimodalExtractorParams:
        """Test MultimodalExtractorParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MultimodalExtractorParams`
        """
        model = MultimodalExtractorParams()
        if include_optional:
            return MultimodalExtractorParams(
                extractor_type = 'multimodal_extractor',
                split_method = 'time',
                description_prompt = 'Describe the video segment in detail.',
                time_split_interval = 56,
                silence_db_threshold = 56,
                scene_detection_threshold = 1.337,
                run_transcription = True,
                transcription_language = 'en',
                run_video_description = True,
                run_transcription_embedding = True,
                run_multimodal_embedding = True,
                run_ocr = True,
                sensitivity = 'low',
                enable_thumbnails = True,
                use_cdn = True,
                generation_config = mixpeek.models.generation_config.GenerationConfig(
                    candidate_count = 56, 
                    max_output_tokens = 56, 
                    temperature = 1.337, 
                    top_p = 1.337, 
                    response_mime_type = '', 
                    response_schema = mixpeek.models.response_schema.Response Schema(), ),
                response_shape = None
            )
        else:
            return MultimodalExtractorParams(
        )
        """

    def testMultimodalExtractorParams(self):
        """Test MultimodalExtractorParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
