# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Union
from typing import Optional, Set
from typing_extensions import Self

class StagePerformanceOutput(BaseModel):
    """
    Performance breakdown by stage.
    """ # noqa: E501
    stage_name: StrictStr = Field(description="Name of the profiled stage")
    component: StrictStr = Field(description="Component (e.g., extractor, cluster)")
    execution_count: StrictInt = Field(description="Number of executions")
    avg_latency_ms: Union[StrictFloat, StrictInt] = Field(description="Average latency")
    p95_latency_ms: Union[StrictFloat, StrictInt] = Field(description="95th percentile latency")
    max_latency_ms: Union[StrictFloat, StrictInt] = Field(description="Maximum latency")
    total_time_ms: Union[StrictFloat, StrictInt] = Field(description="Total time spent in this stage")
    pct_of_total: Union[StrictFloat, StrictInt] = Field(description="Percentage of total time spent in this stage")
    __properties: ClassVar[List[str]] = ["stage_name", "component", "execution_count", "avg_latency_ms", "p95_latency_ms", "max_latency_ms", "total_time_ms", "pct_of_total"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StagePerformanceOutput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StagePerformanceOutput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "stage_name": obj.get("stage_name"),
            "component": obj.get("component"),
            "execution_count": obj.get("execution_count"),
            "avg_latency_ms": obj.get("avg_latency_ms"),
            "p95_latency_ms": obj.get("p95_latency_ms"),
            "max_latency_ms": obj.get("max_latency_ms"),
            "total_time_ms": obj.get("total_time_ms"),
            "pct_of_total": obj.get("pct_of_total")
        })
        return _obj


