# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.create_migration_response import CreateMigrationResponse

class TestCreateMigrationResponse(unittest.TestCase):
    """CreateMigrationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateMigrationResponse:
        """Test CreateMigrationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateMigrationResponse`
        """
        model = CreateMigrationResponse()
        if include_optional:
            return CreateMigrationResponse(
                migration_id = '',
                status = 'draft',
                validation_result = mixpeek.models.validation_result.ValidationResult(
                    valid = True, 
                    errors = [
                        mixpeek.models.validation_error.ValidationError(
                            loc = [
                                null
                                ], 
                            msg = '', 
                            type = '', )
                        ], 
                    warnings = [
                        mixpeek.models.validation_error.ValidationError(
                            loc = [
                                null
                                ], 
                            msg = '', 
                            type = '', )
                        ], 
                    estimated_resources = {
                        'key' : 56
                        }, 
                    estimated_duration_seconds = 56, ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                message = ''
            )
        else:
            return CreateMigrationResponse(
                migration_id = '',
                status = 'draft',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                message = '',
        )
        """

    def testCreateMigrationResponse(self):
        """Test CreateMigrationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
