# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class SchemaSyncRequest(BaseModel):
    """
    Request to sync a collection's schema by sampling documents.  Used by: - Manual API calls from users - Automatic triggers from BatchJobPoller
    """ # noqa: E501
    sample_size: Optional[Annotated[int, Field(le=10000, strict=True, ge=1)]] = Field(default=1000, description="Number of documents to sample for schema discovery")
    force: Optional[StrictBool] = Field(default=False, description="Force schema sync even if within debounce window. Default: false (respects 5-minute debounce)")
    cascade_to_downstream: Optional[StrictBool] = Field(default=True, description="Automatically update downstream collections that use this collection as source. Default: true")
    __properties: ClassVar[List[str]] = ["sample_size", "force", "cascade_to_downstream"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SchemaSyncRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SchemaSyncRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "sample_size": obj.get("sample_size") if obj.get("sample_size") is not None else 1000,
            "force": obj.get("force") if obj.get("force") is not None else False,
            "cascade_to_downstream": obj.get("cascade_to_downstream") if obj.get("cascade_to_downstream") is not None else True
        })
        return _obj


