# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_webhooks_response import ListWebhooksResponse

class TestListWebhooksResponse(unittest.TestCase):
    """ListWebhooksResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListWebhooksResponse:
        """Test ListWebhooksResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListWebhooksResponse`
        """
        model = ListWebhooksResponse()
        if include_optional:
            return ListWebhooksResponse(
                results = [
                    mixpeek.models.webhook.Webhook(
                        webhook_id = 'wh_62ECB020842930cc', 
                        webhook_name = '0', 
                        event_types = [
                            'object.created'
                            ], 
                        channels = [
                            mixpeek.models.webhook_channel.WebhookChannel(
                                channel = null, 
                                configs = null, )
                            ], 
                        is_active = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total = 56
            )
        else:
            return ListWebhooksResponse(
                results = [
                    mixpeek.models.webhook.Webhook(
                        webhook_id = 'wh_62ECB020842930cc', 
                        webhook_name = '0', 
                        event_types = [
                            'object.created'
                            ], 
                        channels = [
                            mixpeek.models.webhook_channel.WebhookChannel(
                                channel = null, 
                                configs = null, )
                            ], 
                        is_active = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total = 56,
        )
        """

    def testListWebhooksResponse(self):
        """Test ListWebhooksResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
