# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.analytics_retrievers_api import AnalyticsRetrieversApi


class TestAnalyticsRetrieversApi(unittest.TestCase):
    """AnalyticsRetrieversApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AnalyticsRetrieversApi()

    def tearDown(self) -> None:
        pass

    def test_analyze_for_tuning_analytics_retrievers(self) -> None:
        """Test case for analyze_for_tuning_analytics_retrievers

        Analyze For Tuning
        """
        pass

    def test_get_cache_performance_analytics_retrievers(self) -> None:
        """Test case for get_cache_performance_analytics_retrievers

        Get Cache Performance
        """
        pass

    def test_get_retriever_performance_analytics(self) -> None:
        """Test case for get_retriever_performance_analytics

        Get Retriever Performance
        """
        pass

    def test_get_retriever_signals_analytics(self) -> None:
        """Test case for get_retriever_signals_analytics

        Get Retriever Signals
        """
        pass

    def test_get_slowest_queries_analytics_retrievers_id_slow(self) -> None:
        """Test case for get_slowest_queries_analytics_retrievers_id_slow

        Get Slowest Queries
        """
        pass

    def test_get_stage_breakdown_analytics_retrievers(self) -> None:
        """Test case for get_stage_breakdown_analytics_retrievers

        Get Stage Breakdown
        """
        pass


if __name__ == '__main__':
    unittest.main()
