# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.analytics_performance_api import AnalyticsPerformanceApi


class TestAnalyticsPerformanceApi(unittest.TestCase):
    """AnalyticsPerformanceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AnalyticsPerformanceApi()

    def tearDown(self) -> None:
        pass

    def test_analyze_bottlenecks_analytics_performance_engine(self) -> None:
        """Test case for analyze_bottlenecks_analytics_performance_engine

        Analyze Bottlenecks
        """
        pass

    def test_get_batch_diagnostics_analytics_performance_batches(self) -> None:
        """Test case for get_batch_diagnostics_analytics_performance_batches

        Get Batch Diagnostics
        """
        pass

    def test_get_engine_performance_analytics(self) -> None:
        """Test case for get_engine_performance_analytics

        Get Engine Performance
        """
        pass

    def test_get_engine_stage_breakdown_analytics_performance(self) -> None:
        """Test case for get_engine_stage_breakdown_analytics_performance

        Get Engine Stage Breakdown
        """
        pass

    def test_get_extractor_breakdown_analytics_performance_engine(self) -> None:
        """Test case for get_extractor_breakdown_analytics_performance_engine

        Get Extractor Breakdown
        """
        pass

    def test_get_slowest_operations_analytics_performance_engine_slow(self) -> None:
        """Test case for get_slowest_operations_analytics_performance_engine_slow

        Get Slowest Operations
        """
        pass


if __name__ == '__main__':
    unittest.main()
