# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.bucket_templates_api import BucketTemplatesApi


class TestBucketTemplatesApi(unittest.TestCase):
    """BucketTemplatesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BucketTemplatesApi()

    def tearDown(self) -> None:
        pass

    def test_create_bucket_template_from(self) -> None:
        """Test case for create_bucket_template_from

        Create Bucket Template
        """
        pass

    def test_get_bucket_template(self) -> None:
        """Test case for get_bucket_template

        Get Bucket Template
        """
        pass

    def test_instantiate_bucket_template(self) -> None:
        """Test case for instantiate_bucket_template

        Instantiate Bucket Template
        """
        pass

    def test_list_bucket_templates(self) -> None:
        """Test case for list_bucket_templates

        List Bucket Templates
        """
        pass


if __name__ == '__main__':
    unittest.main()
