# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.spectral_params import SpectralParams

class TestSpectralParams(unittest.TestCase):
    """SpectralParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpectralParams:
        """Test SpectralParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpectralParams`
        """
        model = SpectralParams()
        if include_optional:
            return SpectralParams(
                n_clusters = 2.0,
                eigen_solver = '',
                n_components = 1.0,
                random_state = 56,
                n_init = 1.0,
                gamma = 1.337,
                affinity = 'rbf',
                n_neighbors = 1.0,
                eigen_tol = 0.0,
                assign_labels = 'kmeans',
                degree = 1.337,
                coef0 = 1.337,
                kernel_params = mixpeek.models.kernel_params.Kernel Params(),
                n_jobs = 56,
                verbose = True
            )
        else:
            return SpectralParams(
        )
        """

    def testSpectralParams(self):
        """Test SpectralParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
