# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.taxonomy_analytics_api import TaxonomyAnalyticsApi


class TestTaxonomyAnalyticsApi(unittest.TestCase):
    """TaxonomyAnalyticsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TaxonomyAnalyticsApi()

    def tearDown(self) -> None:
        pass

    def test_analyze_transition_paths_taxonomies_taxonomy_id_analytics(self) -> None:
        """Test case for analyze_transition_paths_taxonomies_taxonomy_id_analytics

        Analyze multi-step transition paths
        """
        pass

    def test_analyze_transition_paths_taxonomies_taxonomy_id_analytics_0(self) -> None:
        """Test case for analyze_transition_paths_taxonomies_taxonomy_id_analytics_0

        Analyze multi-step transition paths
        """
        pass

    def test_compute_step_transitions_taxonomies_taxonomy_id_analytics(self) -> None:
        """Test case for compute_step_transitions_taxonomies_taxonomy_id_analytics

        Compute step transition analytics
        """
        pass

    def test_compute_step_transitions_taxonomies_taxonomy_id_analytics_0(self) -> None:
        """Test case for compute_step_transitions_taxonomies_taxonomy_id_analytics_0

        Compute step transition analytics
        """
        pass

    def test_get_available_steps_taxonomies_taxonomy_id_analytics(self) -> None:
        """Test case for get_available_steps_taxonomies_taxonomy_id_analytics

        Get Available Steps
        """
        pass

    def test_get_available_steps_taxonomies_taxonomy_id_analytics_0(self) -> None:
        """Test case for get_available_steps_taxonomies_taxonomy_id_analytics_0

        Get Available Steps
        """
        pass


if __name__ == '__main__':
    unittest.main()
