# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.alert_execution_list_response import AlertExecutionListResponse

class TestAlertExecutionListResponse(unittest.TestCase):
    """AlertExecutionListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AlertExecutionListResponse:
        """Test AlertExecutionListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AlertExecutionListResponse`
        """
        model = AlertExecutionListResponse()
        if include_optional:
            return AlertExecutionListResponse(
                results = [
                    mixpeek.models.alert_execution_result.AlertExecutionResult(
                        alert_id = '', 
                        collection_id = '', 
                        execution_id = '', 
                        triggered = True, 
                        match_count = 0.0, 
                        matches = [
                            mixpeek.models.alert_match_result.AlertMatchResult(
                                document_id = '', 
                                asset_id = '', 
                                score = 0.0, 
                                matched_features = mixpeek.models.matched_features.Matched Features(), 
                                metadata = mixpeek.models.metadata.Metadata(), )
                            ], 
                        source_documents = [
                            ''
                            ], 
                        executed_at = '', 
                        duration_ms = 0.0, )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total_count = 56
            )
        else:
            return AlertExecutionListResponse(
                results = [
                    mixpeek.models.alert_execution_result.AlertExecutionResult(
                        alert_id = '', 
                        collection_id = '', 
                        execution_id = '', 
                        triggered = True, 
                        match_count = 0.0, 
                        matches = [
                            mixpeek.models.alert_match_result.AlertMatchResult(
                                document_id = '', 
                                asset_id = '', 
                                score = 0.0, 
                                matched_features = mixpeek.models.matched_features.Matched Features(), 
                                metadata = mixpeek.models.metadata.Metadata(), )
                            ], 
                        source_documents = [
                            ''
                            ], 
                        executed_at = '', 
                        duration_ms = 0.0, )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
                total_count = 56,
        )
        """

    def testAlertExecutionListResponse(self):
        """Test AlertExecutionListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
