# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class UserStatus(str, Enum):
    """
    Lifecycle state of an organization user.  Status values control whether a user can authenticate and access resources:  - ACTIVE: User is fully operational and can authenticate with their API keys. - SUSPENDED: User access is temporarily disabled. API keys will not work but   account data is preserved. Can be reactivated by an admin. - PENDING: User invitation has been created but not yet accepted. User cannot   authenticate until they complete the onboarding flow.
    """

    """
    allowed enum values
    """
    ACTIVE = 'active'
    SUSPENDED = 'suspended'
    PENDING = 'pending'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of UserStatus from a JSON string"""
        return cls(json.loads(json_str))


