# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_params_rag_prepare import StageParamsRagPrepare

class TestStageParamsRagPrepare(unittest.TestCase):
    """StageParamsRagPrepare unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StageParamsRagPrepare:
        """Test StageParamsRagPrepare
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StageParamsRagPrepare`
        """
        model = StageParamsRagPrepare()
        if include_optional:
            return StageParamsRagPrepare(
                max_tokens = 100,
                tokenizer = 'cl100k_base',
                truncation_strategy = 'priority_truncate',
                output_mode = 'single_context',
                document_template = '[{{CONTEXT.INDEX}}] {{DOC.content}}

',
                content_field = 'content',
                separator = ' ',
                citation = mixpeek.models.citation_config.CitationConfig(
                    style = 'numbered', 
                    include_title = True, 
                    include_url = True, ),
                context_field = 'rag_context',
                citations_field = 'citations',
                formatted_content_field = 'formatted_content'
            )
        else:
            return StageParamsRagPrepare(
        )
        """

    def testStageParamsRagPrepare(self):
        """Test StageParamsRagPrepare"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
