# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.path_analysis_response import PathAnalysisResponse

class TestPathAnalysisResponse(unittest.TestCase):
    """PathAnalysisResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PathAnalysisResponse:
        """Test PathAnalysisResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PathAnalysisResponse`
        """
        model = PathAnalysisResponse()
        if include_optional:
            return PathAnalysisResponse(
                from_step = '',
                to_step = '',
                total_sequences = 56,
                completed_sequences = 56,
                completion_rate = 0.0,
                paths = [
                    mixpeek.models.transition_path.TransitionPath(
                        path = [
                            ''
                            ], 
                        count = 0.0, 
                        percentage = 0.0, 
                        avg_duration_sec = 1.337, )
                    ]
            )
        else:
            return PathAnalysisResponse(
                from_step = '',
                to_step = '',
                total_sequences = 56,
                completed_sequences = 56,
                completion_rate = 0.0,
                paths = [
                    mixpeek.models.transition_path.TransitionPath(
                        path = [
                            ''
                            ], 
                        count = 0.0, 
                        percentage = 0.0, 
                        avg_duration_sec = 1.337, )
                    ],
        )
        """

    def testPathAnalysisResponse(self):
        """Test PathAnalysisResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
