# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.vector_based_config_input import VectorBasedConfigInput

class TestVectorBasedConfigInput(unittest.TestCase):
    """VectorBasedConfigInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VectorBasedConfigInput:
        """Test VectorBasedConfigInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VectorBasedConfigInput`
        """
        model = VectorBasedConfigInput()
        if include_optional:
            return VectorBasedConfigInput(
                feature_uri = '',
                feature_uris = [
                    ''
                    ],
                feature_extractor_name = '',
                version = '',
                output_name = '',
                clustering_method = 'kmeans',
                sample_size = 56,
                kmeans_parameters = None,
                dbscan_parameters = None,
                hdbscan_parameters = None,
                algorithm_params = None,
                multi_feature_strategy = 'concatenate',
                normalize_features = True,
                feature_weights = {
                    'key' : 1.337
                    },
                weight_learning_config = mixpeek.models.weight_learning_config.WeightLearningConfig(
                    method = 'bayesian', 
                    max_iterations = 5.0, 
                    metric = 'silhouette', 
                    sample_size = 100.0, 
                    random_state = 56, ),
                output_strategy = 'single',
                effective_feature_method = 'mean',
                enrich_source = True
            )
        else:
            return VectorBasedConfigInput(
                clustering_method = 'kmeans',
        )
        """

    def testVectorBasedConfigInput(self):
        """Test VectorBasedConfigInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
