# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.get_session_response import GetSessionResponse

class TestGetSessionResponse(unittest.TestCase):
    """GetSessionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetSessionResponse:
        """Test GetSessionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetSessionResponse`
        """
        model = GetSessionResponse()
        if include_optional:
            return GetSessionResponse(
                session_id = '',
                namespace_id = '',
                internal_id = '',
                user_id = '',
                session_name = '',
                agent_config = mixpeek.models.agent_config.AgentConfig(
                    model = 'gemini-2.0-flash', 
                    temperature = 0.0, 
                    max_tokens = 1.0, 
                    system_prompt = 'You are a helpful AI assistant with access to Mixpeek's data infrastructure.', 
                    available_tools = [
                        ''
                        ], ),
                user_memory = mixpeek.models.user_memory.User Memory(),
                status = 'active',
                message_count = 56,
                stats = mixpeek.models.session_stats.SessionStats(
                    total_messages = 0.0, 
                    total_tokens = 0.0, 
                    total_tool_calls = 0.0, 
                    avg_latency_ms = 0.0, ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_activity_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return GetSessionResponse(
                session_id = '',
                namespace_id = '',
                internal_id = '',
                agent_config = mixpeek.models.agent_config.AgentConfig(
                    model = 'gemini-2.0-flash', 
                    temperature = 0.0, 
                    max_tokens = 1.0, 
                    system_prompt = 'You are a helpful AI assistant with access to Mixpeek's data infrastructure.', 
                    available_tools = [
                        ''
                        ], ),
                status = 'active',
                message_count = 56,
                stats = mixpeek.models.session_stats.SessionStats(
                    total_messages = 0.0, 
                    total_tokens = 0.0, 
                    total_tool_calls = 0.0, 
                    avg_latency_ms = 0.0, ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_activity_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testGetSessionResponse(self):
        """Test GetSessionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
