# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.document_graph_extractor_params import DocumentGraphExtractorParams

class TestDocumentGraphExtractorParams(unittest.TestCase):
    """DocumentGraphExtractorParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DocumentGraphExtractorParams:
        """Test DocumentGraphExtractorParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DocumentGraphExtractorParams`
        """
        model = DocumentGraphExtractorParams()
        if include_optional:
            return DocumentGraphExtractorParams(
                extractor_type = 'document_graph_extractor',
                use_layout_detection = True,
                layout_detector = 'pymupdf',
                vertical_threshold = 1.0,
                horizontal_threshold = 1.0,
                min_text_length = 1.0,
                base_confidence = 0.0,
                min_confidence_for_vlm = 0.0,
                use_vlm_correction = True,
                fast_mode = True,
                vlm_provider = 'google',
                vlm_model = 'gemini-2.0-flash',
                llm_api_key = '',
                run_text_embedding = True,
                render_dpi = 72.0,
                generate_thumbnails = True,
                thumbnail_mode = 'both',
                thumbnail_dpi = 36.0
            )
        else:
            return DocumentGraphExtractorParams(
        )
        """

    def testDocumentGraphExtractorParams(self):
        """Test DocumentGraphExtractorParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
