# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.manifest_api import ManifestApi


class TestManifestApi(unittest.TestCase):
    """ManifestApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ManifestApi()

    def tearDown(self) -> None:
        pass

    def test_apply_manifest(self) -> None:
        """Test case for apply_manifest

        Apply Manifest
        """
        pass

    def test_diff_manifest(self) -> None:
        """Test case for diff_manifest

        Diff Manifest
        """
        pass

    def test_export_manifest_get(self) -> None:
        """Test case for export_manifest_get

        Export Manifest Get
        """
        pass

    def test_export_manifest_post(self) -> None:
        """Test case for export_manifest_post

        Export Manifest Post
        """
        pass

    def test_generate_manifest(self) -> None:
        """Test case for generate_manifest

        Generate Manifest
        """
        pass

    def test_validate_manifest(self) -> None:
        """Test case for validate_manifest

        Validate Manifest
        """
        pass


if __name__ == '__main__':
    unittest.main()
