# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AuditEventResponse(BaseModel):
    """
    Single audit event in list response.
    """ # noqa: E501
    audit_id: StrictStr = Field(description="Unique audit event identifier")
    timestamp: Optional[Any]
    resource_type: StrictStr = Field(description="Type of resource affected")
    resource_id: StrictStr = Field(description="ID of the affected resource")
    action: StrictStr = Field(description="Action performed")
    actor_id: StrictStr = Field(description="Who performed the action")
    actor_type: Optional[StrictStr] = Field(default='user', description="Type of actor")
    status: Optional[StrictStr] = Field(default='success', description="Status of the action")
    changes: Optional[Any] = None
    ip_address: Optional[StrictStr] = Field(default=None, description="Request IP address")
    user_agent: Optional[StrictStr] = Field(default=None, description="Request user agent")
    __properties: ClassVar[List[str]] = ["audit_id", "timestamp", "resource_type", "resource_id", "action", "actor_id", "actor_type", "status", "changes", "ip_address", "user_agent"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AuditEventResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if timestamp (nullable) is None
        # and model_fields_set contains the field
        if self.timestamp is None and "timestamp" in self.model_fields_set:
            _dict['timestamp'] = None

        # set to None if changes (nullable) is None
        # and model_fields_set contains the field
        if self.changes is None and "changes" in self.model_fields_set:
            _dict['changes'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AuditEventResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "audit_id": obj.get("audit_id"),
            "timestamp": obj.get("timestamp"),
            "resource_type": obj.get("resource_type"),
            "resource_id": obj.get("resource_id"),
            "action": obj.get("action"),
            "actor_id": obj.get("actor_id"),
            "actor_type": obj.get("actor_type") if obj.get("actor_type") is not None else 'user',
            "status": obj.get("status") if obj.get("status") is not None else 'success',
            "changes": obj.get("changes"),
            "ip_address": obj.get("ip_address"),
            "user_agent": obj.get("user_agent")
        })
        return _obj


