# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_performance_output import StagePerformanceOutput

class TestStagePerformanceOutput(unittest.TestCase):
    """StagePerformanceOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StagePerformanceOutput:
        """Test StagePerformanceOutput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StagePerformanceOutput`
        """
        model = StagePerformanceOutput()
        if include_optional:
            return StagePerformanceOutput(
                stage_name = '',
                component = '',
                execution_count = 56,
                avg_latency_ms = 1.337,
                p95_latency_ms = 1.337,
                max_latency_ms = 1.337,
                total_time_ms = 1.337,
                pct_of_total = 1.337
            )
        else:
            return StagePerformanceOutput(
                stage_name = '',
                component = '',
                execution_count = 56,
                avg_latency_ms = 1.337,
                p95_latency_ms = 1.337,
                max_latency_ms = 1.337,
                total_time_ms = 1.337,
                pct_of_total = 1.337,
        )
        """

    def testStagePerformanceOutput(self):
        """Test StagePerformanceOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
