# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.retrievers_api import RetrieversApi


class TestRetrieversApi(unittest.TestCase):
    """RetrieversApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RetrieversApi()

    def tearDown(self) -> None:
        pass

    def test_clone_retriever(self) -> None:
        """Test case for clone_retriever

        Clone Retriever
        """
        pass

    def test_create_retriever(self) -> None:
        """Test case for create_retriever

        Create Retriever
        """
        pass

    def test_delete_retriever(self) -> None:
        """Test case for delete_retriever

        Delete Retriever
        """
        pass

    def test_execute_retriever(self) -> None:
        """Test case for execute_retriever

        Execute Retriever (Auto-Optimized)
        """
        pass

    def test_explain_retriever_execution_id_execute(self) -> None:
        """Test case for explain_retriever_execution_id_execute

        Explain Retriever Execution Plan
        """
        pass

    def test_get_execution_retrievers(self) -> None:
        """Test case for get_execution_retrievers

        Get Execution
        """
        pass

    def test_get_retriever(self) -> None:
        """Test case for get_retriever

        Get Retriever
        """
        pass

    def test_list_executions_retrievers(self) -> None:
        """Test case for list_executions_retrievers

        List Executions
        """
        pass

    def test_list_retrievers(self) -> None:
        """Test case for list_retrievers

        List Retrievers
        """
        pass

    def test_patch_retriever(self) -> None:
        """Test case for patch_retriever

        Patch Retriever
        """
        pass


if __name__ == '__main__':
    unittest.main()
