# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.feature_extractor_response_model import FeatureExtractorResponseModel

class TestFeatureExtractorResponseModel(unittest.TestCase):
    """FeatureExtractorResponseModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FeatureExtractorResponseModel:
        """Test FeatureExtractorResponseModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FeatureExtractorResponseModel`
        """
        model = FeatureExtractorResponseModel()
        if include_optional:
            return FeatureExtractorResponseModel(
                feature_extractor_name = '',
                version = '',
                feature_extractor_id = '',
                description = '',
                icon = '',
                source = 'builtin',
                input_schema = mixpeek.models.input_schema.Input Schema(),
                output_schema = mixpeek.models.output_schema.Output Schema(),
                parameter_schema = mixpeek.models.parameter_schema.Parameter Schema(),
                supported_input_types = [
                    ''
                    ],
                max_inputs = {
                    'key' : 56
                    },
                default_parameters = mixpeek.models.default_parameters.Default Parameters(),
                costs = mixpeek.models.costs_info.CostsInfo(
                    tier = 1.0, 
                    tier_label = '', 
                    rates = [
                        mixpeek.models.cost_rate.CostRate(
                            unit = null, 
                            credits_per_unit = 1.0, 
                            description = '', )
                        ], ),
                required_vector_indexes = [
                    mixpeek.models.vector_index_definition.VectorIndexDefinition(
                        feature_uri = '', 
                        name = '0', 
                        description = '0123456789', 
                        type = 'single', 
                        index = null, )
                    ],
                required_payload_indexes = [
                    mixpeek.models.payload_index_config.PayloadIndexConfig(
                        field_name = '0', 
                        type = null, 
                        field_schema = null, 
                        is_protected = True, )
                    ],
                position_fields = [
                    ''
                    ]
            )
        else:
            return FeatureExtractorResponseModel(
                feature_extractor_name = '',
                version = '',
                feature_extractor_id = '',
                description = '',
                icon = '',
                input_schema = mixpeek.models.input_schema.Input Schema(),
                output_schema = mixpeek.models.output_schema.Output Schema(),
                parameter_schema = mixpeek.models.parameter_schema.Parameter Schema(),
                supported_input_types = [
                    ''
                    ],
                max_inputs = {
                    'key' : 56
                    },
                default_parameters = mixpeek.models.default_parameters.Default Parameters(),
                required_vector_indexes = [
                    mixpeek.models.vector_index_definition.VectorIndexDefinition(
                        feature_uri = '', 
                        name = '0', 
                        description = '0123456789', 
                        type = 'single', 
                        index = null, )
                    ],
                required_payload_indexes = [
                    mixpeek.models.payload_index_config.PayloadIndexConfig(
                        field_name = '0', 
                        type = null, 
                        field_schema = null, 
                        is_protected = True, )
                    ],
        )
        """

    def testFeatureExtractorResponseModel(self):
        """Test FeatureExtractorResponseModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
