# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.namespace_summary_response import NamespaceSummaryResponse

class TestNamespaceSummaryResponse(unittest.TestCase):
    """NamespaceSummaryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NamespaceSummaryResponse:
        """Test NamespaceSummaryResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NamespaceSummaryResponse`
        """
        model = NamespaceSummaryResponse()
        if include_optional:
            return NamespaceSummaryResponse(
                namespace_id = '',
                time_range_days = 56,
                summary = mixpeek.models.summary.Summary(),
                recommendations = [
                    mixpeek.models.index_recommendation.IndexRecommendation(
                        field_name = '', 
                        query_count = 56, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, 
                        slow_query_count = 56, 
                        very_slow_query_count = 56, 
                        priority_score = 1.337, 
                        recommendation = '', 
                        mongodb_index_command = '', )
                    ],
                most_queried_fields = [
                    mixpeek.models.field_query_metrics.FieldQueryMetrics(
                        field_name = '', 
                        query_count = 56, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, )
                    ],
                slowest_fields = [
                    mixpeek.models.field_performance_metrics.FieldPerformanceMetrics(
                        field_name = '', 
                        usage_count = 56, 
                        avg_latency_ms = 1.337, 
                        p50_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, 
                        p99_latency_ms = 1.337, 
                        max_latency_ms = 1.337, 
                        index_priority_score = 1.337, )
                    ],
                compound_indexes = [
                    mixpeek.models.compound_index_pattern.CompoundIndexPattern(
                        field_combination = [
                            ''
                            ], 
                        combination_count = 56, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, )
                    ]
            )
        else:
            return NamespaceSummaryResponse(
                namespace_id = '',
                time_range_days = 56,
                summary = mixpeek.models.summary.Summary(),
                recommendations = [
                    mixpeek.models.index_recommendation.IndexRecommendation(
                        field_name = '', 
                        query_count = 56, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, 
                        slow_query_count = 56, 
                        very_slow_query_count = 56, 
                        priority_score = 1.337, 
                        recommendation = '', 
                        mongodb_index_command = '', )
                    ],
                most_queried_fields = [
                    mixpeek.models.field_query_metrics.FieldQueryMetrics(
                        field_name = '', 
                        query_count = 56, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, )
                    ],
                slowest_fields = [
                    mixpeek.models.field_performance_metrics.FieldPerformanceMetrics(
                        field_name = '', 
                        usage_count = 56, 
                        avg_latency_ms = 1.337, 
                        p50_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, 
                        p99_latency_ms = 1.337, 
                        max_latency_ms = 1.337, 
                        index_priority_score = 1.337, )
                    ],
                compound_indexes = [
                    mixpeek.models.compound_index_pattern.CompoundIndexPattern(
                        field_combination = [
                            ''
                            ], 
                        combination_count = 56, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, )
                    ],
        )
        """

    def testNamespaceSummaryResponse(self):
        """Test NamespaceSummaryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
