# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.step_transition_response import StepTransitionResponse

class TestStepTransitionResponse(unittest.TestCase):
    """StepTransitionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StepTransitionResponse:
        """Test StepTransitionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StepTransitionResponse`
        """
        model = StepTransitionResponse()
        if include_optional:
            return StepTransitionResponse(
                from_step = '',
                to_step = '',
                count = 0.0,
                converted = 0.0,
                conversion_rate = 0.0,
                durations_sec = mixpeek.models.duration_stats.DurationStats(
                    mean = 1.337, 
                    median = 1.337, 
                    p50 = 1.337, 
                    p90 = 1.337, 
                    p95 = 1.337, 
                    std_dev = 1.337, 
                    min = 1.337, 
                    max = 1.337, ),
                top_predictors = [
                    mixpeek.models.predictor_lift.PredictorLift(
                        field = '', 
                        value = '', 
                        count = 0.0, 
                        conversion_rate = 0.0, 
                        lift = 1.337, )
                    ],
                metadata = mixpeek.models.metadata.Metadata()
            )
        else:
            return StepTransitionResponse(
                from_step = '',
                to_step = '',
                count = 0.0,
                converted = 0.0,
                conversion_rate = 0.0,
        )
        """

    def testStepTransitionResponse(self):
        """Test StepTransitionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
