# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.face_identity_extractor_params import FaceIdentityExtractorParams

class TestFaceIdentityExtractorParams(unittest.TestCase):
    """FaceIdentityExtractorParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FaceIdentityExtractorParams:
        """Test FaceIdentityExtractorParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FaceIdentityExtractorParams`
        """
        model = FaceIdentityExtractorParams()
        if include_optional:
            return FaceIdentityExtractorParams(
                extractor_type = 'face_identity_extractor',
                detection_model = 'scrfd_2.5g',
                min_face_size = 10.0,
                detection_threshold = 0.0,
                max_faces_per_image = 1.0,
                normalize_embeddings = True,
                enable_quality_scoring = True,
                quality_threshold = 0.0,
                max_video_length = 1.0,
                video_sampling_fps = 0.1,
                video_deduplication = True,
                video_deduplication_threshold = 0.0,
                output_mode = 'per_face',
                include_face_crops = True,
                store_detection_metadata = True
            )
        else:
            return FaceIdentityExtractorParams(
        )
        """

    def testFaceIdentityExtractorParams(self):
        """Test FaceIdentityExtractorParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
