# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.cloned_resource_summary import ClonedResourceSummary
from mixpeek.models.namespace_model import NamespaceModel
from typing import Optional, Set
from typing_extensions import Self

class CloneNamespaceResponse(BaseModel):
    """
    Response after initiating namespace clone.
    """ # noqa: E501
    namespace: NamespaceModel = Field(description="Cloned namespace with new namespace_id")
    source_namespace_id: StrictStr = Field(description="Source namespace that was cloned")
    status: Optional[StrictStr] = Field(default='cloning', description="Clone status: 'cloning', 'ready', or 'failed'")
    task_id: Optional[StrictStr] = Field(default=None, description="Celery task ID for tracking clone progress")
    cloned_resources: Optional[ClonedResourceSummary] = Field(default=None, description="Summary of cloned resources (present when ready)")
    __properties: ClassVar[List[str]] = ["namespace", "source_namespace_id", "status", "task_id", "cloned_resources"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CloneNamespaceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of namespace
        if self.namespace:
            _dict['namespace'] = self.namespace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cloned_resources
        if self.cloned_resources:
            _dict['cloned_resources'] = self.cloned_resources.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CloneNamespaceResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "namespace": NamespaceModel.from_dict(obj["namespace"]) if obj.get("namespace") is not None else None,
            "source_namespace_id": obj.get("source_namespace_id"),
            "status": obj.get("status") if obj.get("status") is not None else 'cloning',
            "task_id": obj.get("task_id"),
            "cloned_resources": ClonedResourceSummary.from_dict(obj["cloned_resources"]) if obj.get("cloned_resources") is not None else None
        })
        return _obj


