# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.create_benchmark_request import CreateBenchmarkRequest

class TestCreateBenchmarkRequest(unittest.TestCase):
    """CreateBenchmarkRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateBenchmarkRequest:
        """Test CreateBenchmarkRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateBenchmarkRequest`
        """
        model = CreateBenchmarkRequest()
        if include_optional:
            return CreateBenchmarkRequest(
                benchmark_name = '0',
                baseline_retriever_id = '',
                candidate_retriever_ids = [
                    ''
                    ],
                session_filter = mixpeek.models.session_filter.SessionFilter(
                    retriever_ids = [
                        ''
                        ], 
                    taxonomy_node_ids = [
                        ''
                        ], 
                    time_range = mixpeek.models.time_range.TimeRange(
                        start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    min_interactions = 1.0, 
                    interaction_types = [
                        ''
                        ], 
                    sample_strategy = 'random', 
                    interaction_weights = null, ),
                session_count = 10.0
            )
        else:
            return CreateBenchmarkRequest(
                benchmark_name = '0',
                baseline_retriever_id = '',
                candidate_retriever_ids = [
                    ''
                    ],
        )
        """

    def testCreateBenchmarkRequest(self):
        """Test CreateBenchmarkRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
