# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class KMeansParams(BaseModel):
    """
    Parameters for K-Means clustering algorithm.
    """ # noqa: E501
    n_clusters: Optional[Annotated[int, Field(le=1000, strict=True, ge=2)]] = Field(default=8, description="Number of clusters to form")
    max_iter: Optional[Annotated[int, Field(le=10000, strict=True, ge=1)]] = Field(default=300, description="Maximum number of iterations")
    random_state: Optional[StrictInt] = Field(default=42, description="Random seed for reproducibility")
    n_init: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=10, description="Number of times k-means will run with different centroid seeds")
    tol: Optional[Union[StrictFloat, StrictInt]] = Field(default=1.0E-4, description="Tolerance for convergence")
    init: Optional[StrictStr] = Field(default='k-means++', description="Method for initialization ('k-means++' or 'random')")
    verbose: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=0, description="Verbosity mode")
    copy_x: Optional[StrictBool] = Field(default=True, description="If True, the original data is not modified")
    algorithm: Optional[StrictStr] = Field(default='lloyd', description="K-means algorithm to use ('lloyd', 'elkan', or 'auto')")
    __properties: ClassVar[List[str]] = ["n_clusters", "max_iter", "random_state", "n_init", "tol", "init", "verbose", "copy_x", "algorithm"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of KMeansParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of KMeansParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "n_clusters": obj.get("n_clusters") if obj.get("n_clusters") is not None else 8,
            "max_iter": obj.get("max_iter") if obj.get("max_iter") is not None else 300,
            "random_state": obj.get("random_state") if obj.get("random_state") is not None else 42,
            "n_init": obj.get("n_init") if obj.get("n_init") is not None else 10,
            "tol": obj.get("tol") if obj.get("tol") is not None else 1.0E-4,
            "init": obj.get("init") if obj.get("init") is not None else 'k-means++',
            "verbose": obj.get("verbose") if obj.get("verbose") is not None else 0,
            "copy_x": obj.get("copy_x") if obj.get("copy_x") is not None else True,
            "algorithm": obj.get("algorithm") if obj.get("algorithm") is not None else 'lloyd'
        })
        return _obj


