# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.tigris_config import TigrisConfig

class TestTigrisConfig(unittest.TestCase):
    """TigrisConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TigrisConfig:
        """Test TigrisConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TigrisConfig`
        """
        model = TigrisConfig()
        if include_optional:
            return TigrisConfig(
                provider_type = 'tigris',
                credentials = mixpeek.models.tigris_access_key_credentials.TigrisAccessKeyCredentials(
                    type = 'access_key', 
                    access_key_id = '0', 
                    secret_access_key = '0', ),
                region = 'auto',
                endpoint_url = 'https://fly.storage.tigris.dev'
            )
        else:
            return TigrisConfig(
                credentials = mixpeek.models.tigris_access_key_credentials.TigrisAccessKeyCredentials(
                    type = 'access_key', 
                    access_key_id = '0', 
                    secret_access_key = '0', ),
        )
        """

    def testTigrisConfig(self):
        """Test TigrisConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
