# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.available_steps_response import AvailableStepsResponse

class TestAvailableStepsResponse(unittest.TestCase):
    """AvailableStepsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AvailableStepsResponse:
        """Test AvailableStepsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AvailableStepsResponse`
        """
        model = AvailableStepsResponse()
        if include_optional:
            return AvailableStepsResponse(
                taxonomy_id = '',
                collection_id = '',
                total_events = 0.0,
                total_sequences = 0.0,
                steps = [
                    mixpeek.models.step_info.StepInfo(
                        step_key = '', 
                        event_count = 0.0, 
                        sequence_count = 0.0, 
                        first_seen = '', 
                        last_seen = '', )
                    ]
            )
        else:
            return AvailableStepsResponse(
                taxonomy_id = '',
                collection_id = '',
                total_events = 0.0,
                total_sequences = 0.0,
                steps = [
                    mixpeek.models.step_info.StepInfo(
                        step_key = '', 
                        event_count = 0.0, 
                        sequence_count = 0.0, 
                        first_seen = '', 
                        last_seen = '', )
                    ],
        )
        """

    def testAvailableStepsResponse(self):
        """Test AvailableStepsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
