# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.public_retriever_api_api import PublicRetrieverAPIApi


class TestPublicRetrieverAPIApi(unittest.TestCase):
    """PublicRetrieverAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PublicRetrieverAPIApi()

    def tearDown(self) -> None:
        pass

    def test_execute_retriever_name(self) -> None:
        """Test case for execute_retriever_name

        Execute Public Retriever
        """
        pass

    def test_get_retriever_config_name(self) -> None:
        """Test case for get_retriever_config_name

        Get Public Retriever Config
        """
        pass

    def test_get_retriever_template_name(self) -> None:
        """Test case for get_retriever_template_name

        Get Public Retriever Template
        """
        pass

    def test_list_retrievers(self) -> None:
        """Test case for list_retrievers

        List Public Retrievers
        """
        pass

    def test_track_interaction_batch_retrievers_name(self) -> None:
        """Test case for track_interaction_batch_retrievers_name

        Track Interaction Batch
        """
        pass

    def test_track_interaction_retrievers_name(self) -> None:
        """Test case for track_interaction_retrievers_name

        Track Interaction
        """
        pass

    def test_verify_password_retrievers_name(self) -> None:
        """Test case for verify_password_retrievers_name

        Verify Password
        """
        pass


if __name__ == '__main__':
    unittest.main()
