# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_params_aggregate import StageParamsAggregate

class TestStageParamsAggregate(unittest.TestCase):
    """StageParamsAggregate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StageParamsAggregate:
        """Test StageParamsAggregate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StageParamsAggregate`
        """
        model = StageParamsAggregate()
        if include_optional:
            return StageParamsAggregate(
                aggregations = [
                    mixpeek.models.aggregation_operation.AggregationOperation(
                        function = null, 
                        field = '', 
                        alias = '', 
                        distinct_field = '', )
                    ],
                group_by = [
                    mixpeek.models.group_by_field_config.GroupByFieldConfig(
                        field = '', 
                        alias = '', )
                    ],
                sort_by = 'null',
                sort_order = 'desc',
                limit = 1,
                include_documents = True
            )
        else:
            return StageParamsAggregate(
        )
        """

    def testStageParamsAggregate(self):
        """Test StageParamsAggregate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
