# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.field_config import FieldConfig

class TestFieldConfig(unittest.TestCase):
    """FieldConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FieldConfig:
        """Test FieldConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FieldConfig`
        """
        model = FieldConfig()
        if include_optional:
            return FieldConfig(
                format = 'text',
                format_options = mixpeek.models.field_format_options.FieldFormatOptions(
                    label = '', 
                    show_empty = True, 
                    truncate_chars = 1.0, 
                    width = 1.0, 
                    height = 1.0, 
                    lazy_load = True, 
                    aspect_ratio = '', 
                    object_fit = 'cover', 
                    date_format = 'relative', 
                    decimals = 0.0, 
                    prefix = '', 
                    suffix = '', 
                    open_in_new_tab = True, 
                    show_domain = True, 
                    true_label = 'Yes', 
                    false_label = 'No', 
                    separator = ', ', 
                    max_items = 1.0, )
            )
        else:
            return FieldConfig(
                format = 'text',
        )
        """

    def testFieldConfig(self):
        """Test FieldConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
