# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class InternalProcessingModel(BaseModel):
    """
    Processing and provenance tracking information.  Consolidates all processing-related metadata including source URLs, processing history, and taxonomy enrichment lineage.
    """ # noqa: E501
    source_url: Optional[StrictStr] = Field(default=None, description="Original URL before S3 mirroring (for URL-based ingestion).")
    object_key_source: Optional[StrictStr] = Field(default=None, description="S3 key source identifier.")
    detected_mime_type: Optional[StrictStr] = Field(default=None, description="MIME type detected during canonicalization.")
    history: Optional[List[Dict[str, Any]]] = Field(default=None, description="Processing steps history with timestamps and operations.")
    taxonomy_lineage: Optional[List[Dict[str, Any]]] = Field(default=None, description="Taxonomy enrichment entries applied to this document.")
    last_health_check: Optional[Dict[str, Any]] = Field(default=None, description="Last health check result (for batch processing).")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["source_url", "object_key_source", "detected_mime_type", "history", "taxonomy_lineage", "last_health_check"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InternalProcessingModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InternalProcessingModel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "source_url": obj.get("source_url"),
            "object_key_source": obj.get("object_key_source"),
            "detected_mime_type": obj.get("detected_mime_type"),
            "history": obj.get("history"),
            "taxonomy_lineage": obj.get("taxonomy_lineage"),
            "last_health_check": obj.get("last_health_check")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


