# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.apply_result import ApplyResult

class TestApplyResult(unittest.TestCase):
    """ApplyResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplyResult:
        """Test ApplyResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplyResult`
        """
        model = ApplyResult()
        if include_optional:
            return ApplyResult(
                success = True,
                resources = [
                    mixpeek.models.resource_result.ResourceResult(
                        resource_type = '', 
                        name = '', 
                        resource_id = '', 
                        status = null, 
                        error = '', )
                    ],
                created_count = 56,
                failed_count = 56,
                skipped_count = 56,
                errors = [
                    ''
                    ],
                rollback_performed = True,
                dry_run = True
            )
        else:
            return ApplyResult(
                success = True,
        )
        """

    def testApplyResult(self):
        """Test ApplyResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
