# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.namespace_list_stats import NamespaceListStats

class TestNamespaceListStats(unittest.TestCase):
    """NamespaceListStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NamespaceListStats:
        """Test NamespaceListStats
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NamespaceListStats`
        """
        model = NamespaceListStats()
        if include_optional:
            return NamespaceListStats(
                total_feature_extractors = 56,
                total_payload_indexes = 56,
                total_documents = 56,
                total_buckets = 56,
                total_collections = 56,
                total_objects = 56,
                avg_feature_extractors_per_namespace = 1.337,
                avg_payload_indexes_per_namespace = 1.337,
                avg_documents_per_namespace = 1.337,
                avg_buckets_per_namespace = 1.337,
                avg_collections_per_namespace = 1.337,
                avg_objects_per_namespace = 1.337
            )
        else:
            return NamespaceListStats(
        )
        """

    def testNamespaceListStats(self):
        """Test NamespaceListStats"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
