# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.cluster_triggers_api import ClusterTriggersApi


class TestClusterTriggersApi(unittest.TestCase):
    """ClusterTriggersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ClusterTriggersApi()

    def tearDown(self) -> None:
        pass

    def test_create_trigger_clusters(self) -> None:
        """Test case for create_trigger_clusters

        Create Cluster Trigger
        """
        pass

    def test_delete_trigger_clusters(self) -> None:
        """Test case for delete_trigger_clusters

        Delete Cluster Trigger
        """
        pass

    def test_get_trigger_clusters(self) -> None:
        """Test case for get_trigger_clusters

        Get Cluster Trigger
        """
        pass

    def test_get_trigger_history_clusters(self) -> None:
        """Test case for get_trigger_history_clusters

        Get Trigger Execution History
        """
        pass

    def test_list_triggers_clusters(self) -> None:
        """Test case for list_triggers_clusters

        List Cluster Triggers
        """
        pass

    def test_pause_trigger_clusters(self) -> None:
        """Test case for pause_trigger_clusters

        Pause Cluster Trigger
        """
        pass

    def test_resume_trigger_clusters(self) -> None:
        """Test case for resume_trigger_clusters

        Resume Cluster Trigger
        """
        pass

    def test_update_trigger_clusters(self) -> None:
        """Test case for update_trigger_clusters

        Update Cluster Trigger
        """
        pass


if __name__ == '__main__':
    unittest.main()
