# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.buckets_api import BucketsApi


class TestBucketsApi(unittest.TestCase):
    """BucketsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BucketsApi()

    def tearDown(self) -> None:
        pass

    def test_create_bucket(self) -> None:
        """Test case for create_bucket

        Create Bucket
        """
        pass

    def test_delete_bucket(self) -> None:
        """Test case for delete_bucket

        Delete Bucket
        """
        pass

    def test_get_bucket(self) -> None:
        """Test case for get_bucket

        Get Bucket
        """
        pass

    def test_list_buckets(self) -> None:
        """Test case for list_buckets

        List Buckets
        """
        pass

    def test_patch_bucket(self) -> None:
        """Test case for patch_bucket

        Partially Update Bucket
        """
        pass

    def test_update_bucket(self) -> None:
        """Test case for update_bucket

        Update Bucket
        """
        pass


if __name__ == '__main__':
    unittest.main()
