# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.create_session_request import CreateSessionRequest

class TestCreateSessionRequest(unittest.TestCase):
    """CreateSessionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateSessionRequest:
        """Test CreateSessionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateSessionRequest`
        """
        model = CreateSessionRequest()
        if include_optional:
            return CreateSessionRequest(
                agent_config = mixpeek.models.agent_config.AgentConfig(
                    model = 'gemini-2.0-flash', 
                    temperature = 0.0, 
                    max_tokens = 1.0, 
                    system_prompt = 'You are a helpful AI assistant with access to Mixpeek's data infrastructure.', 
                    available_tools = [
                        ''
                        ], ),
                quotas = mixpeek.models.session_quotas.SessionQuotas(
                    max_messages = 1.0, 
                    max_tokens_total = 1.0, 
                    max_tool_calls = 1.0, 
                    max_session_duration_minutes = 1.0, 
                    rate_limit_messages_per_minute = 1.0, ),
                user_id = '',
                user_memory = mixpeek.models.user_memory.User Memory(),
                metadata = mixpeek.models.metadata.Metadata(),
                enable_memory = True
            )
        else:
            return CreateSessionRequest(
                agent_config = mixpeek.models.agent_config.AgentConfig(
                    model = 'gemini-2.0-flash', 
                    temperature = 0.0, 
                    max_tokens = 1.0, 
                    system_prompt = 'You are a helpful AI assistant with access to Mixpeek's data infrastructure.', 
                    available_tools = [
                        ''
                        ], ),
        )
        """

    def testCreateSessionRequest(self):
        """Test CreateSessionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
