# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_params_mmr import StageParamsMmr

class TestStageParamsMmr(unittest.TestCase):
    """StageParamsMmr unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StageParamsMmr:
        """Test StageParamsMmr
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StageParamsMmr`
        """
        model = StageParamsMmr()
        if include_optional:
            return StageParamsMmr(
                var_lambda = 0.0,
                top_k = 1,
                diversity_feature_uri = 'null',
                diversity_features = [
                    mixpeek.models.diversity_feature_config.DiversityFeatureConfig(
                        feature_uri = '', 
                        weight = 0.0, )
                    ],
                diversity_fields = [
                    ''
                    ],
                diversity_field_weights = {
                    'key' : 1.337
                    },
                score_field = 'score',
                mmr_score_field = 'scores.mmr',
                similarity_metric = 'cosine'
            )
        else:
            return StageParamsMmr(
        )
        """

    def testStageParamsMmr(self):
        """Test StageParamsMmr"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
