# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.bucket_uploads_api import BucketUploadsApi


class TestBucketUploadsApi(unittest.TestCase):
    """BucketUploadsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BucketUploadsApi()

    def tearDown(self) -> None:
        pass

    def test_confirm_upload_buckets(self) -> None:
        """Test case for confirm_upload_buckets

        Confirm Upload
        """
        pass

    def test_confirm_uploads_batch_buckets(self) -> None:
        """Test case for confirm_uploads_batch_buckets

        Batch Confirm Uploads
        """
        pass

    def test_create_upload_buckets(self) -> None:
        """Test case for create_upload_buckets

        Create Upload
        """
        pass

    def test_create_uploads_batch_buckets(self) -> None:
        """Test case for create_uploads_batch_buckets

        Batch Create Uploads
        """
        pass

    def test_delete_upload_buckets(self) -> None:
        """Test case for delete_upload_buckets

        Delete Upload
        """
        pass

    def test_get_upload_buckets(self) -> None:
        """Test case for get_upload_buckets

        Get Upload
        """
        pass

    def test_list_uploads_buckets(self) -> None:
        """Test case for list_uploads_buckets

        List Uploads
        """
        pass


if __name__ == '__main__':
    unittest.main()
