# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_params_web_scrape import StageParamsWebScrape

class TestStageParamsWebScrape(unittest.TestCase):
    """StageParamsWebScrape unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StageParamsWebScrape:
        """Test StageParamsWebScrape
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StageParamsWebScrape`
        """
        model = StageParamsWebScrape()
        if include_optional:
            return StageParamsWebScrape(
                url = 'null',
                url_field = 'metadata.url',
                output_field = 'metadata.web_content',
                strategy = 'auto',
                timeout = 1,
                include_html = True,
                min_content_length = 100,
                when = {
                    'key' : null
                    },
                on_error = 'skip',
                batch_size = 1,
                max_depth = 0,
                max_pages = 1,
                same_domain_only = True,
                url_patterns = mixpeek.models.url_patterns.URLPatterns(
                    include = [
                        ''
                        ], 
                    exclude = [
                        ''
                        ], ),
                delay_between_requests = 0.0
            )
        else:
            return StageParamsWebScrape(
        )
        """

    def testStageParamsWebScrape(self):
        """Test StageParamsWebScrape"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
