# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.sync_create_request import SyncCreateRequest

class TestSyncCreateRequest(unittest.TestCase):
    """SyncCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyncCreateRequest:
        """Test SyncCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyncCreateRequest`
        """
        model = SyncCreateRequest()
        if include_optional:
            return SyncCreateRequest(
                connection_id = '',
                source_path = '',
                sync_mode = 'initial_only',
                file_filters = mixpeek.models.file_filters.File Filters(),
                schema_mapping = mixpeek.models.schema_mapping.SchemaMapping(
                    mappings = {
                        'key' : null
                        }, ),
                polling_interval_seconds = 30.0,
                batch_size = 1.0,
                skip_batch_submission = True,
                metadata = mixpeek.models.metadata.Metadata()
            )
        else:
            return SyncCreateRequest(
                connection_id = '',
                source_path = '',
        )
        """

    def testSyncCreateRequest(self):
        """Test SyncCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
