# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.templates_api import TemplatesApi


class TestTemplatesApi(unittest.TestCase):
    """TemplatesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TemplatesApi()

    def tearDown(self) -> None:
        pass

    def test_create_bucket_template_from(self) -> None:
        """Test case for create_bucket_template_from

        Create Bucket Template
        """
        pass

    def test_create_cluster_template_from(self) -> None:
        """Test case for create_cluster_template_from

        Create Cluster Template
        """
        pass

    def test_create_collection_template_from(self) -> None:
        """Test case for create_collection_template_from

        Create Collection Template
        """
        pass

    def test_create_namespace_template_from(self) -> None:
        """Test case for create_namespace_template_from

        Create Namespace Template
        """
        pass

    def test_create_retriever_template_from(self) -> None:
        """Test case for create_retriever_template_from

        Create Retriever Template
        """
        pass

    def test_create_taxonomy_template_taxonomies_from(self) -> None:
        """Test case for create_taxonomy_template_taxonomies_from

        Create Taxonomy Template
        """
        pass

    def test_get_bucket_template(self) -> None:
        """Test case for get_bucket_template

        Get Bucket Template
        """
        pass

    def test_get_cluster_template(self) -> None:
        """Test case for get_cluster_template

        Get Cluster Template
        """
        pass

    def test_get_collection_template(self) -> None:
        """Test case for get_collection_template

        Get Collection Template
        """
        pass

    def test_get_namespace_template(self) -> None:
        """Test case for get_namespace_template

        Get Namespace Template
        """
        pass

    def test_get_retriever_template(self) -> None:
        """Test case for get_retriever_template

        Get Retriever Template
        """
        pass

    def test_get_taxonomy_template_taxonomies(self) -> None:
        """Test case for get_taxonomy_template_taxonomies

        Get Taxonomy Template
        """
        pass

    def test_instantiate_bucket_template(self) -> None:
        """Test case for instantiate_bucket_template

        Instantiate Bucket Template
        """
        pass

    def test_instantiate_cluster_template(self) -> None:
        """Test case for instantiate_cluster_template

        Instantiate Cluster Template
        """
        pass

    def test_instantiate_collection_template(self) -> None:
        """Test case for instantiate_collection_template

        Instantiate Collection Template
        """
        pass

    def test_instantiate_namespace_template(self) -> None:
        """Test case for instantiate_namespace_template

        Instantiate Namespace Template
        """
        pass

    def test_instantiate_retriever_template(self) -> None:
        """Test case for instantiate_retriever_template

        Instantiate Retriever Template
        """
        pass

    def test_instantiate_taxonomy_template_taxonomies(self) -> None:
        """Test case for instantiate_taxonomy_template_taxonomies

        Instantiate Taxonomy Template
        """
        pass

    def test_list_bucket_templates(self) -> None:
        """Test case for list_bucket_templates

        List Bucket Templates
        """
        pass

    def test_list_cluster_templates(self) -> None:
        """Test case for list_cluster_templates

        List Cluster Templates
        """
        pass

    def test_list_collection_templates(self) -> None:
        """Test case for list_collection_templates

        List Collection Templates
        """
        pass

    def test_list_namespace_templates(self) -> None:
        """Test case for list_namespace_templates

        List Namespace Templates
        """
        pass

    def test_list_retriever_templates(self) -> None:
        """Test case for list_retriever_templates

        List Retriever Templates
        """
        pass

    def test_list_taxonomy_templates_taxonomies(self) -> None:
        """Test case for list_taxonomy_templates_taxonomies

        List Taxonomy Templates
        """
        pass


if __name__ == '__main__':
    unittest.main()
