# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_public_retrievers_response import ListPublicRetrieversResponse

class TestListPublicRetrieversResponse(unittest.TestCase):
    """ListPublicRetrieversResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListPublicRetrieversResponse:
        """Test ListPublicRetrieversResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListPublicRetrieversResponse`
        """
        model = ListPublicRetrieversResponse()
        if include_optional:
            return ListPublicRetrieversResponse(
                results = [
                    mixpeek.models.public_retriever_list_item.PublicRetrieverListItem(
                        public_name = '', 
                        public_url = '', 
                        title = '', 
                        description = '', 
                        logo_url = '', 
                        icon_base64 = '', 
                        og_image_url = '', 
                        password_protected = True, 
                        is_active = True, 
                        external_links = [
                            mixpeek.models.external_link.ExternalLink(
                                name = '0', 
                                url = '0', )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total_count = 56,
                page = 56,
                page_size = 56,
                total_pages = 56,
                stats = mixpeek.models.public_retriever_list_stats.PublicRetrieverListStats(
                    total_active = 56, 
                    total_password_protected = 56, 
                    total_open = 56, )
            )
        else:
            return ListPublicRetrieversResponse(
                results = [
                    mixpeek.models.public_retriever_list_item.PublicRetrieverListItem(
                        public_name = '', 
                        public_url = '', 
                        title = '', 
                        description = '', 
                        logo_url = '', 
                        icon_base64 = '', 
                        og_image_url = '', 
                        password_protected = True, 
                        is_active = True, 
                        external_links = [
                            mixpeek.models.external_link.ExternalLink(
                                name = '0', 
                                url = '0', )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total_count = 56,
                page = 56,
                page_size = 56,
                total_pages = 56,
        )
        """

    def testListPublicRetrieversResponse(self):
        """Test ListPublicRetrieversResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
