# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.organization_secrets_api import OrganizationSecretsApi


class TestOrganizationSecretsApi(unittest.TestCase):
    """OrganizationSecretsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationSecretsApi()

    def tearDown(self) -> None:
        pass

    def test_create_secret_organizations(self) -> None:
        """Test case for create_secret_organizations

        Create Secret
        """
        pass

    def test_delete_secret_organizations_name(self) -> None:
        """Test case for delete_secret_organizations_name

        Delete Secret
        """
        pass

    def test_list_secrets_organizations(self) -> None:
        """Test case for list_secrets_organizations

        List Secrets
        """
        pass

    def test_update_secret_organizations_name(self) -> None:
        """Test case for update_secret_organizations_name

        Update Secret
        """
        pass


if __name__ == '__main__':
    unittest.main()
