# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.batch_upload_request import BatchUploadRequest

class TestBatchUploadRequest(unittest.TestCase):
    """BatchUploadRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BatchUploadRequest:
        """Test BatchUploadRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BatchUploadRequest`
        """
        model = BatchUploadRequest()
        if include_optional:
            return BatchUploadRequest(
                uploads = [
                    mixpeek.models.create_upload_request.CreateUploadRequest(
                        filename = '0', 
                        content_type = '', 
                        file_size_bytes = 1.0, 
                        presigned_url_expiration = 60.0, 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        create_object_on_confirm = True, 
                        object_metadata = mixpeek.models.object_metadata.Object Metadata(), 
                        blob_property = 'H', 
                        blob_type = '', 
                        file_hash = 'bf325375e030fccba00917317c574773100bf03b5fc61486286e564b23e9566b0123456789101112131415161718192021222324252627282930313233343536373839404142434445464748495051525354555657585960616263', 
                        skip_duplicates = True, )
                    ],
                shared_metadata = mixpeek.models.shared_metadata.Shared Metadata(),
                shared_object_metadata = mixpeek.models.shared_object_metadata.Shared Object Metadata()
            )
        else:
            return BatchUploadRequest(
                uploads = [
                    mixpeek.models.create_upload_request.CreateUploadRequest(
                        filename = '0', 
                        content_type = '', 
                        file_size_bytes = 1.0, 
                        presigned_url_expiration = 60.0, 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        create_object_on_confirm = True, 
                        object_metadata = mixpeek.models.object_metadata.Object Metadata(), 
                        blob_property = 'H', 
                        blob_type = '', 
                        file_hash = 'bf325375e030fccba00917317c574773100bf03b5fc61486286e564b23e9566b0123456789101112131415161718192021222324252627282930313233343536373839404142434445464748495051525354555657585960616263', 
                        skip_duplicates = True, )
                    ],
        )
        """

    def testBatchUploadRequest(self):
        """Test BatchUploadRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
