# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.evaluation_list_response import EvaluationListResponse

class TestEvaluationListResponse(unittest.TestCase):
    """EvaluationListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EvaluationListResponse:
        """Test EvaluationListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EvaluationListResponse`
        """
        model = EvaluationListResponse()
        if include_optional:
            return EvaluationListResponse(
                evaluations = [
                    mixpeek.models.evaluation_record.EvaluationRecord(
                        evaluation_id = '', 
                        retriever_id = '', 
                        dataset_id = '', 
                        dataset_name = '', 
                        config = null, 
                        status = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        namespace_id = '', 
                        internal_id = '', 
                        query_count = 56, 
                        overall_metrics = {
                            'key' : 1.337
                            }, 
                        metrics_by_k = {
                            'key' : {
                                'key' : 1.337
                                }
                            }, 
                        error_message = '', )
                    ],
                total = 56,
                page = 56,
                page_size = 56
            )
        else:
            return EvaluationListResponse(
                evaluations = [
                    mixpeek.models.evaluation_record.EvaluationRecord(
                        evaluation_id = '', 
                        retriever_id = '', 
                        dataset_id = '', 
                        dataset_name = '', 
                        config = null, 
                        status = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        namespace_id = '', 
                        internal_id = '', 
                        query_count = 56, 
                        overall_metrics = {
                            'key' : 1.337
                            }, 
                        metrics_by_k = {
                            'key' : {
                                'key' : 1.337
                                }
                            }, 
                        error_message = '', )
                    ],
                total = 56,
                page = 56,
                page_size = 56,
        )
        """

    def testEvaluationListResponse(self):
        """Test EvaluationListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
