# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.web_scraper_extractor_params import WebScraperExtractorParams

class TestWebScraperExtractorParams(unittest.TestCase):
    """WebScraperExtractorParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebScraperExtractorParams:
        """Test WebScraperExtractorParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebScraperExtractorParams`
        """
        model = WebScraperExtractorParams()
        if include_optional:
            return WebScraperExtractorParams(
                extractor_type = 'web_scraper',
                max_depth = 0.0,
                max_pages = 1.0,
                crawl_timeout = 10.0,
                crawl_mode = 'deterministic',
                crawl_goal = '',
                render_strategy = 'static',
                include_patterns = [
                    ''
                    ],
                exclude_patterns = [
                    ''
                    ],
                chunk_strategy = 'none',
                chunk_size = 1.0,
                chunk_overlap = 0.0,
                document_id_strategy = 'url',
                generate_text_embeddings = True,
                generate_code_embeddings = True,
                generate_image_embeddings = True,
                response_shape = None,
                llm_provider = '',
                llm_model = '',
                llm_api_key = '',
                max_retries = 0.0,
                retry_base_delay = 0.1,
                retry_max_delay = 1.0,
                respect_retry_after = True,
                proxies = [
                    ''
                    ],
                rotate_proxy_on_error = True,
                rotate_proxy_every_n_requests = 0.0,
                captcha_service_provider = '',
                captcha_service_api_key = '',
                detect_captcha = True,
                persist_cookies = True,
                custom_headers = {
                    'key' : ''
                    },
                delay_between_requests = 0.0
            )
        else:
            return WebScraperExtractorParams(
        )
        """

    def testWebScraperExtractorParams(self):
        """Test WebScraperExtractorParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
