# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.collection_documents_api import CollectionDocumentsApi


class TestCollectionDocumentsApi(unittest.TestCase):
    """CollectionDocumentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CollectionDocumentsApi()

    def tearDown(self) -> None:
        pass

    def test_aggregate_documents(self) -> None:
        """Test case for aggregate_documents

        Aggregate Documents
        """
        pass

    def test_batch_delete(self) -> None:
        """Test case for batch_delete

        Batch Delete Documents
        """
        pass

    def test_batch_update(self) -> None:
        """Test case for batch_update

        Batch Update Documents
        """
        pass

    def test_bulk_update(self) -> None:
        """Test case for bulk_update

        Bulk Update Documents
        """
        pass

    def test_create_document(self) -> None:
        """Test case for create_document

        Create a document.
        """
        pass

    def test_delete_document(self) -> None:
        """Test case for delete_document

        Delete a document by ID.
        """
        pass

    def test_get_document(self) -> None:
        """Test case for get_document

        Get a document by ID.
        """
        pass

    def test_list_documents(self) -> None:
        """Test case for list_documents

        List documents.
        """
        pass

    def test_patch_document(self) -> None:
        """Test case for patch_document

        Patch Document
        """
        pass

    def test_update_document(self) -> None:
        """Test case for update_document

        Update Document
        """
        pass


if __name__ == '__main__':
    unittest.main()
