# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.benchmark_comparison import BenchmarkComparison

class TestBenchmarkComparison(unittest.TestCase):
    """BenchmarkComparison unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BenchmarkComparison:
        """Test BenchmarkComparison
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BenchmarkComparison`
        """
        model = BenchmarkComparison()
        if include_optional:
            return BenchmarkComparison(
                baseline_retriever_id = '',
                comparisons = [
                    mixpeek.models.pipeline_comparison.PipelineComparison(
                        candidate_retriever_id = '', 
                        ndcg_delta = {
                            'key' : 1.337
                            }, 
                        recall_delta = {
                            'key' : 1.337
                            }, 
                        latency_delta_ms = 1.337, 
                        p_value = 1.337, 
                        confidence_interval = [
                            null
                            ], 
                        taxonomy_wins = [
                            ''
                            ], 
                        taxonomy_losses = [
                            ''
                            ], )
                    ],
                recommendation = ''
            )
        else:
            return BenchmarkComparison(
                baseline_retriever_id = '',
                comparisons = [
                    mixpeek.models.pipeline_comparison.PipelineComparison(
                        candidate_retriever_id = '', 
                        ndcg_delta = {
                            'key' : 1.337
                            }, 
                        recall_delta = {
                            'key' : 1.337
                            }, 
                        latency_delta_ms = 1.337, 
                        p_value = 1.337, 
                        confidence_interval = [
                            null
                            ], 
                        taxonomy_wins = [
                            ''
                            ], 
                        taxonomy_losses = [
                            ''
                            ], )
                    ],
        )
        """

    def testBenchmarkComparison(self):
        """Test BenchmarkComparison"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
