# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class AgglomerativeParams(BaseModel):
    """
    Parameters for Agglomerative clustering algorithm.
    """ # noqa: E501
    n_clusters: Optional[Annotated[int, Field(strict=True, ge=2)]] = Field(default=2, description="Number of clusters to find. Can be None if distance_threshold is not None")
    affinity: Optional[StrictStr] = Field(default='euclidean', description="Metric used to compute linkage. Can be 'euclidean', 'l1', 'l2', 'manhattan', 'cosine', or 'precomputed'")
    memory: Optional[StrictStr] = Field(default=None, description="Path to the caching directory")
    connectivity: Optional[Any] = None
    compute_full_tree: Optional[StrictStr] = Field(default='auto', description="Whether to compute the full tree ('auto', True, or False)")
    linkage: Optional[StrictStr] = Field(default='ward', description="Linkage criterion ('ward', 'complete', 'average', 'single')")
    distance_threshold: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The linkage distance threshold above which clusters will not be merged")
    compute_distances: Optional[StrictBool] = Field(default=False, description="Whether to compute distances between clusters")
    __properties: ClassVar[List[str]] = ["n_clusters", "affinity", "memory", "connectivity", "compute_full_tree", "linkage", "distance_threshold", "compute_distances"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgglomerativeParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if connectivity (nullable) is None
        # and model_fields_set contains the field
        if self.connectivity is None and "connectivity" in self.model_fields_set:
            _dict['connectivity'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgglomerativeParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "n_clusters": obj.get("n_clusters") if obj.get("n_clusters") is not None else 2,
            "affinity": obj.get("affinity") if obj.get("affinity") is not None else 'euclidean',
            "memory": obj.get("memory"),
            "connectivity": obj.get("connectivity"),
            "compute_full_tree": obj.get("compute_full_tree") if obj.get("compute_full_tree") is not None else 'auto',
            "linkage": obj.get("linkage") if obj.get("linkage") is not None else 'ward',
            "distance_threshold": obj.get("distance_threshold"),
            "compute_distances": obj.get("compute_distances") if obj.get("compute_distances") is not None else False
        })
        return _obj


