# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.organization_admin_update_request import OrganizationAdminUpdateRequest

class TestOrganizationAdminUpdateRequest(unittest.TestCase):
    """OrganizationAdminUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationAdminUpdateRequest:
        """Test OrganizationAdminUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationAdminUpdateRequest`
        """
        model = OrganizationAdminUpdateRequest()
        if include_optional:
            return OrganizationAdminUpdateRequest(
                account_type = 'free',
                rate_limits = mixpeek.models.base_rate_limits.BaseRateLimits(
                    metadata = 1.0, 
                    data = 1.0, 
                    search = 1.0, 
                    upload = 1.0, 
                    compute = 1.0, ),
                infrastructure = mixpeek.models.organization_infrastructure.OrganizationInfrastructure(
                    qdrant_url = '', 
                    qdrant_api_key = '', 
                    ray_head_node_url = '', 
                    ray_dashboard_url = '', 
                    compute_tier = null, )
            )
        else:
            return OrganizationAdminUpdateRequest(
        )
        """

    def testOrganizationAdminUpdateRequest(self):
        """Test OrganizationAdminUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
