# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.analytics_namespaces_api import AnalyticsNamespacesApi


class TestAnalyticsNamespacesApi(unittest.TestCase):
    """AnalyticsNamespacesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AnalyticsNamespacesApi()

    def tearDown(self) -> None:
        pass

    def test_get_compound_index_patterns_analytics_namespaces_indexes(self) -> None:
        """Test case for get_compound_index_patterns_analytics_namespaces_indexes

        Get Compound Index Patterns
        """
        pass

    def test_get_field_performance_analytics_namespaces(self) -> None:
        """Test case for get_field_performance_analytics_namespaces

        Get Field Performance
        """
        pass

    def test_get_index_recommendations_analytics_namespaces_indexes(self) -> None:
        """Test case for get_index_recommendations_analytics_namespaces_indexes

        Get Index Recommendations
        """
        pass

    def test_get_most_queried_fields_analytics_namespaces(self) -> None:
        """Test case for get_most_queried_fields_analytics_namespaces

        Get Most Queried Fields
        """
        pass

    def test_get_namespace_summary_analytics(self) -> None:
        """Test case for get_namespace_summary_analytics

        Get Namespace Summary
        """
        pass

    def test_get_slow_queries_analytics_namespaces(self) -> None:
        """Test case for get_slow_queries_analytics_namespaces

        Get Slow Queries
        """
        pass


if __name__ == '__main__':
    unittest.main()
