# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.llm_labeling_input import LLMLabelingInput

class TestLLMLabelingInput(unittest.TestCase):
    """LLMLabelingInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LLMLabelingInput:
        """Test LLMLabelingInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LLMLabelingInput`
        """
        model = LLMLabelingInput()
        if include_optional:
            return LLMLabelingInput(
                enabled = True,
                labeling_inputs = mixpeek.models.llm_labeling_input.LLMLabelingInput(
                    input_mappings = [
                        mixpeek.models.input_mapping.InputMapping(
                            input_key = '', 
                            source_type = 'payload', 
                            path = '', 
                            override = null, )
                        ], ),
                provider = 'openai',
                model_name = None,
                include_summary = True,
                include_keywords = True,
                max_samples_per_cluster = 1.0,
                sample_text_max_length = 50.0,
                use_embedding_dedup = True,
                embedding_similarity_threshold = 0.5,
                cache_ttl_seconds = 0.0,
                custom_prompt = '',
                response_shape = None,
                parameters = mixpeek.models.parameters.Parameters()
            )
        else:
            return LLMLabelingInput(
        )
        """

    def testLLMLabelingInput(self):
        """Test LLMLabelingInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
