# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.document_lineage_api import DocumentLineageApi


class TestDocumentLineageApi(unittest.TestCase):
    """DocumentLineageApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DocumentLineageApi()

    def tearDown(self) -> None:
        pass

    def test_get_decomposition_tree_objects(self) -> None:
        """Test case for get_decomposition_tree_objects

        Get decomposition tree visualization
        """
        pass

    def test_get_document_lineage(self) -> None:
        """Test case for get_document_lineage

        Get document lineage
        """
        pass

    def test_get_documents_by_object(self) -> None:
        """Test case for get_documents_by_object

        Get all documents derived from an object
        """
        pass


if __name__ == '__main__':
    unittest.main()
