# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.namespace_model import NamespaceModel

class TestNamespaceModel(unittest.TestCase):
    """NamespaceModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NamespaceModel:
        """Test NamespaceModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NamespaceModel`
        """
        model = NamespaceModel()
        if include_optional:
            return NamespaceModel(
                namespace_id = '',
                namespace_name = 'spotify_playlists_dev',
                infrastructure = mixpeek.models.namespace_infrastructure.NamespaceInfrastructure(
                    ray_cluster_id = 'ray_HqXzyCBw3_uufVPIPFhB9JcGRYnua_cdyyvLY8IzLpul9', 
                    ray_head_node_url = '', 
                    ray_dashboard_url = '', 
                    qdrant_url = '', 
                    qdrant_api_key = '', 
                    qdrant_collection = '012', 
                    compute_tier = null, 
                    max_concurrent_jobs = 1.0, 
                    autoscaling_enabled = True, 
                    min_workers = 0.0, 
                    max_workers = 1.0, 
                    gpu_type = '', 
                    gpus_per_worker = 0.0, 
                    s3_plugin_bucket = 'mixpeek-plugins', 
                    s3_plugin_prefix = '', 
                    max_custom_plugins = 0.0, 
                    max_custom_models = 0.0, ),
                cluster_id = '',
                description = '',
                feature_extractors = [
                    mixpeek.models.base_feature_extractor_model.BaseFeatureExtractorModel(
                        feature_extractor_name = '', 
                        version = '', 
                        params = mixpeek.models.params.Params(), 
                        feature_extractor_id = '', )
                    ],
                payload_indexes = [
                    mixpeek.models.payload_index_config.PayloadIndexConfig(
                        field_name = '0', 
                        type = null, 
                        field_schema = null, 
                        is_protected = True, )
                    ],
                document_count = 56,
                bucket_count = 56,
                collection_count = 56,
                object_count = 56,
                auto_create_indexes = True,
                vector_inference_map = {
                    'key' : ''
                    },
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return NamespaceModel(
                namespace_name = 'spotify_playlists_dev',
        )
        """

    def testNamespaceModel(self):
        """Test NamespaceModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
