# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.collection_model import CollectionModel

class TestCollectionModel(unittest.TestCase):
    """CollectionModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CollectionModel:
        """Test CollectionModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CollectionModel`
        """
        model = CollectionModel()
        if include_optional:
            return CollectionModel(
                collection_id = '',
                collection_name = '012',
                description = '',
                input_schema = {
                    'key' : null
                    },
                output_schema = {
                    'key' : null
                    },
                feature_extractor = mixpeek.models.feature_extractor_config.FeatureExtractorConfig(
                    feature_extractor_name = '', 
                    version = '', 
                    params = mixpeek.models.params.Params(), 
                    parameters = null, 
                    input_mappings = null, 
                    field_passthrough = [
                        mixpeek.models.field_passthrough.FieldPassthrough(
                            source_path = '', 
                            target_path = '', 
                            default = null, 
                            required = True, )
                        ], 
                    include_all_source_fields = True, 
                    feature_extractor_id = '', ),
                source = mixpeek.models.source_config.SourceConfig(
                    type = null, 
                    bucket_ids = [
                        ''
                        ], 
                    collection_id = '', 
                    collection_ids = [
                        ''
                        ], 
                    inherited_bucket_ids = [
                        ''
                        ], 
                    source_filters = mixpeek.models.source_filters.SourceFilters(
                        filters = {
                            'key' : null
                            }, ), ),
                source_bucket_schemas = {
                    'key' : {
                        'key' : null
                        }
                    },
                source_lineage = [
                    mixpeek.models.single_lineage_entry.SingleLineageEntry(
                        source_config = null, 
                        feature_extractor = null, 
                        output_schema = null, )
                    ],
                vector_indexes = [
                    null
                    ],
                payload_indexes = [
                    null
                    ],
                enabled = True,
                metadata = mixpeek.models.metadata.Metadata(),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                document_count = 56,
                schema_version = 56,
                last_schema_sync = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                schema_sync_enabled = True,
                taxonomy_applications = [
                    {
                        'key' : null
                        }
                    ],
                cluster_applications = [
                    mixpeek.models.cluster_application_config.ClusterApplicationConfig(
                        cluster_id = '', 
                        auto_execute_on_batch = True, 
                        min_document_threshold = 56, 
                        cooldown_seconds = 56, 
                        execution_phase = 1.0, 
                        priority = 0.0, )
                    ],
                alert_applications = [
                    {
                        'key' : null
                        }
                    ]
            )
        else:
            return CollectionModel(
                collection_name = '012',
                input_schema = {
                    'key' : null
                    },
                output_schema = {
                    'key' : null
                    },
                feature_extractor = mixpeek.models.feature_extractor_config.FeatureExtractorConfig(
                    feature_extractor_name = '', 
                    version = '', 
                    params = mixpeek.models.params.Params(), 
                    parameters = null, 
                    input_mappings = null, 
                    field_passthrough = [
                        mixpeek.models.field_passthrough.FieldPassthrough(
                            source_path = '', 
                            target_path = '', 
                            default = null, 
                            required = True, )
                        ], 
                    include_all_source_fields = True, 
                    feature_extractor_id = '', ),
                source = mixpeek.models.source_config.SourceConfig(
                    type = null, 
                    bucket_ids = [
                        ''
                        ], 
                    collection_id = '', 
                    collection_ids = [
                        ''
                        ], 
                    inherited_bucket_ids = [
                        ''
                        ], 
                    source_filters = mixpeek.models.source_filters.SourceFilters(
                        filters = {
                            'key' : null
                            }, ), ),
        )
        """

    def testCollectionModel(self):
        """Test CollectionModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
