# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.retriever_evaluations_api import RetrieverEvaluationsApi


class TestRetrieverEvaluationsApi(unittest.TestCase):
    """RetrieverEvaluationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RetrieverEvaluationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_dataset_retrievers_evaluations(self) -> None:
        """Test case for create_dataset_retrievers_evaluations

        Create evaluation dataset
        """
        pass

    def test_get_dataset_retrievers_evaluations(self) -> None:
        """Test case for get_dataset_retrievers_evaluations

        Get evaluation dataset
        """
        pass

    def test_get_evaluation_retrievers(self) -> None:
        """Test case for get_evaluation_retrievers

        Get evaluation results
        """
        pass

    def test_list_datasets_retrievers_evaluations(self) -> None:
        """Test case for list_datasets_retrievers_evaluations

        List evaluation datasets
        """
        pass

    def test_list_evaluations_retrievers(self) -> None:
        """Test case for list_evaluations_retrievers

        List evaluations
        """
        pass

    def test_start_evaluation_retrievers(self) -> None:
        """Test case for start_evaluation_retrievers

        Run evaluation
        """
        pass


if __name__ == '__main__':
    unittest.main()
