# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.shared_triggers_models_list_triggers_response import SharedTriggersModelsListTriggersResponse

class TestSharedTriggersModelsListTriggersResponse(unittest.TestCase):
    """SharedTriggersModelsListTriggersResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SharedTriggersModelsListTriggersResponse:
        """Test SharedTriggersModelsListTriggersResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SharedTriggersModelsListTriggersResponse`
        """
        model = SharedTriggersModelsListTriggersResponse()
        if include_optional:
            return SharedTriggersModelsListTriggersResponse(
                results = [
                    mixpeek.models.trigger_model.TriggerModel(
                        trigger_id = '', 
                        namespace_id = '', 
                        internal_id = '', 
                        action_type = null, 
                        action_config = mixpeek.models.action_config.Action Config(), 
                        trigger_type = null, 
                        schedule_config = mixpeek.models.schedule_config.Schedule Config(), 
                        status = null, 
                        last_triggered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_execution_task_id = '', 
                        next_scheduled_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        execution_count = 56, 
                        consecutive_failures = 56, 
                        last_execution_status = '', 
                        last_execution_error = '', 
                        event_counter = 56, 
                        last_cooldown_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        baseline_snapshot = mixpeek.models.baseline_snapshot.Baseline Snapshot(), 
                        last_drift_measurement = mixpeek.models.last_drift_measurement.Last Drift Measurement(), 
                        last_condition_check_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = '', )
                    ],
                total = 56,
                offset = 56,
                limit = 56
            )
        else:
            return SharedTriggersModelsListTriggersResponse(
                results = [
                    mixpeek.models.trigger_model.TriggerModel(
                        trigger_id = '', 
                        namespace_id = '', 
                        internal_id = '', 
                        action_type = null, 
                        action_config = mixpeek.models.action_config.Action Config(), 
                        trigger_type = null, 
                        schedule_config = mixpeek.models.schedule_config.Schedule Config(), 
                        status = null, 
                        last_triggered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_execution_task_id = '', 
                        next_scheduled_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        execution_count = 56, 
                        consecutive_failures = 56, 
                        last_execution_status = '', 
                        last_execution_error = '', 
                        event_counter = 56, 
                        last_cooldown_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        baseline_snapshot = mixpeek.models.baseline_snapshot.Baseline Snapshot(), 
                        last_drift_measurement = mixpeek.models.last_drift_measurement.Last Drift Measurement(), 
                        last_condition_check_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = '', )
                    ],
                total = 56,
                offset = 56,
                limit = 56,
        )
        """

    def testSharedTriggersModelsListTriggersResponse(self):
        """Test SharedTriggersModelsListTriggersResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
