# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.single_lineage_entry import SingleLineageEntry

class TestSingleLineageEntry(unittest.TestCase):
    """SingleLineageEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SingleLineageEntry:
        """Test SingleLineageEntry
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SingleLineageEntry`
        """
        model = SingleLineageEntry()
        if include_optional:
            return SingleLineageEntry(
                source_config = mixpeek.models.source_config.SourceConfig(
                    type = null, 
                    bucket_ids = [
                        ''
                        ], 
                    collection_id = '', 
                    collection_ids = [
                        ''
                        ], 
                    inherited_bucket_ids = [
                        ''
                        ], 
                    source_filters = mixpeek.models.source_filters.SourceFilters(
                        filters = {
                            'key' : null
                            }, ), ),
                feature_extractor = mixpeek.models.feature_extractor_config.FeatureExtractorConfig(
                    feature_extractor_name = '', 
                    version = '', 
                    params = mixpeek.models.params.Params(), 
                    parameters = null, 
                    input_mappings = null, 
                    field_passthrough = [
                        mixpeek.models.field_passthrough.FieldPassthrough(
                            source_path = '', 
                            target_path = '', 
                            default = null, 
                            required = True, )
                        ], 
                    include_all_source_fields = True, 
                    feature_extractor_id = '', ),
                output_schema = {
                    'key' : null
                    }
            )
        else:
            return SingleLineageEntry(
                source_config = mixpeek.models.source_config.SourceConfig(
                    type = null, 
                    bucket_ids = [
                        ''
                        ], 
                    collection_id = '', 
                    collection_ids = [
                        ''
                        ], 
                    inherited_bucket_ids = [
                        ''
                        ], 
                    source_filters = mixpeek.models.source_filters.SourceFilters(
                        filters = {
                            'key' : null
                            }, ), ),
                feature_extractor = mixpeek.models.feature_extractor_config.FeatureExtractorConfig(
                    feature_extractor_name = '', 
                    version = '', 
                    params = mixpeek.models.params.Params(), 
                    parameters = null, 
                    input_mappings = null, 
                    field_passthrough = [
                        mixpeek.models.field_passthrough.FieldPassthrough(
                            source_path = '', 
                            target_path = '', 
                            default = null, 
                            required = True, )
                        ], 
                    include_all_source_fields = True, 
                    feature_extractor_id = '', ),
                output_schema = {
                    'key' : null
                    },
        )
        """

    def testSingleLineageEntry(self):
        """Test SingleLineageEntry"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
