# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class StagePerformanceInput(BaseModel):
    """
    Performance statistics for a retriever stage.
    """ # noqa: E501
    avg_execution_ms: Optional[Union[StrictFloat, StrictInt]] = Field(default=0.0, description="Average execution time in milliseconds")
    execution_count: Optional[StrictInt] = Field(default=0, description="Number of times executed")
    error_count: Optional[StrictInt] = Field(default=0, description="Number of errors encountered")
    last_executed_at: Optional[datetime] = Field(default=None, description="Last time this stage was executed")
    __properties: ClassVar[List[str]] = ["avg_execution_ms", "execution_count", "error_count", "last_executed_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StagePerformanceInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StagePerformanceInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "avg_execution_ms": obj.get("avg_execution_ms") if obj.get("avg_execution_ms") is not None else 0.0,
            "execution_count": obj.get("execution_count") if obj.get("execution_count") is not None else 0,
            "error_count": obj.get("error_count") if obj.get("error_count") is not None else 0,
            "last_executed_at": obj.get("last_executed_at")
        })
        return _obj


