# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.webhook_input import WebhookInput

class TestWebhookInput(unittest.TestCase):
    """WebhookInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebhookInput:
        """Test WebhookInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebhookInput`
        """
        model = WebhookInput()
        if include_optional:
            return WebhookInput(
                webhook_id = 'wh_62ECB020842930cc',
                webhook_name = '0',
                internal_id = '',
                event_types = [
                    'object.created'
                    ],
                channels = [
                    mixpeek.models.webhook_channel.WebhookChannel(
                        channel = null, 
                        configs = null, )
                    ],
                is_active = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return WebhookInput(
                webhook_name = '0',
                event_types = [
                    'object.created'
                    ],
                channels = [
                    mixpeek.models.webhook_channel.WebhookChannel(
                        channel = null, 
                        configs = null, )
                    ],
        )
        """

    def testWebhookInput(self):
        """Test WebhookInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
