# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.bucket_syncs_api import BucketSyncsApi


class TestBucketSyncsApi(unittest.TestCase):
    """BucketSyncsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BucketSyncsApi()

    def tearDown(self) -> None:
        pass

    def test_create_sync_configuration_buckets(self) -> None:
        """Test case for create_sync_configuration_buckets

        Create Sync Configuration
        """
        pass

    def test_delete_sync_configuration_buckets_id_config(self) -> None:
        """Test case for delete_sync_configuration_buckets_id_config

        Delete Sync Configuration
        """
        pass

    def test_get_sync_configuration_buckets_id_config(self) -> None:
        """Test case for get_sync_configuration_buckets_id_config

        Get Sync Configuration
        """
        pass

    def test_list_sync_configurations_buckets(self) -> None:
        """Test case for list_sync_configurations_buckets

        List Sync Configurations
        """
        pass

    def test_pause_sync_configuration_buckets_id_config(self) -> None:
        """Test case for pause_sync_configuration_buckets_id_config

        Pause Sync Configuration
        """
        pass

    def test_resume_sync_configuration_buckets_id_config(self) -> None:
        """Test case for resume_sync_configuration_buckets_id_config

        Resume Sync Configuration
        """
        pass

    def test_trigger_sync_configuration_buckets_id_config(self) -> None:
        """Test case for trigger_sync_configuration_buckets_id_config

        Trigger Sync Configuration
        """
        pass

    def test_update_sync_configuration_buckets_id_config(self) -> None:
        """Test case for update_sync_configuration_buckets_id_config

        Update Sync Configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()
