# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from mixpeek.models.api_analytics_models_time_range import ApiAnalyticsModelsTimeRange
from mixpeek.models.interaction_tuning_recommendation import InteractionTuningRecommendation
from typing import Optional, Set
from typing_extensions import Self

class InteractionTuningResponse(BaseModel):
    """
    Response for interaction tuning analysis.
    """ # noqa: E501
    retriever_id: StrictStr = Field(description="Retriever identifier")
    analysis_period: ApiAnalyticsModelsTimeRange = Field(description="Analysis period")
    recommendations: List[InteractionTuningRecommendation] = Field(description="Tuning recommendations")
    current_performance: Dict[str, Any] = Field(description="Current performance baseline")
    __properties: ClassVar[List[str]] = ["retriever_id", "analysis_period", "recommendations", "current_performance"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InteractionTuningResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of analysis_period
        if self.analysis_period:
            _dict['analysis_period'] = self.analysis_period.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in recommendations (list)
        _items = []
        if self.recommendations:
            for _item_recommendations in self.recommendations:
                if _item_recommendations:
                    _items.append(_item_recommendations.to_dict())
            _dict['recommendations'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InteractionTuningResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "retriever_id": obj.get("retriever_id"),
            "analysis_period": ApiAnalyticsModelsTimeRange.from_dict(obj["analysis_period"]) if obj.get("analysis_period") is not None else None,
            "recommendations": [InteractionTuningRecommendation.from_dict(_item) for _item in obj["recommendations"]] if obj.get("recommendations") is not None else None,
            "current_performance": obj.get("current_performance")
        })
        return _obj


