# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.published_retrievers_api import PublishedRetrieversApi


class TestPublishedRetrieversApi(unittest.TestCase):
    """PublishedRetrieversApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PublishedRetrieversApi()

    def tearDown(self) -> None:
        pass

    def test_check_name_availability_retrievers_id_publish(self) -> None:
        """Test case for check_name_availability_retrievers_id_publish

        Check Name Availability
        """
        pass

    def test_get_organization_publish_stats_retrievers(self) -> None:
        """Test case for get_organization_publish_stats_retrievers

        Get Organization Publish Stats
        """
        pass

    def test_get_published_retriever_id_publish(self) -> None:
        """Test case for get_published_retriever_id_publish

        Get Published Retriever
        """
        pass

    def test_list_published_retrievers(self) -> None:
        """Test case for list_published_retrievers

        List Published Retrievers
        """
        pass

    def test_publish_retriever(self) -> None:
        """Test case for publish_retriever

        Publish Retriever
        """
        pass

    def test_unpublish_retriever_id_publish(self) -> None:
        """Test case for unpublish_retriever_id_publish

        Unpublish Retriever
        """
        pass

    def test_update_published_retriever_id_publish(self) -> None:
        """Test case for update_published_retriever_id_publish

        Update Published Retriever
        """
        pass


if __name__ == '__main__':
    unittest.main()
