# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.algorithm_params import AlgorithmParams

class TestAlgorithmParams(unittest.TestCase):
    """AlgorithmParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AlgorithmParams:
        """Test AlgorithmParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AlgorithmParams`
        """
        model = AlgorithmParams()
        if include_optional:
            return AlgorithmParams(
                n_clusters = 2.0,
                max_iter = 1.0,
                random_state = 56,
                n_init = 1.0,
                tol = 1.337,
                init = 'k-means++',
                verbose = 0.0,
                copy_x = True,
                algorithm = 'auto',
                eps = 1.337,
                min_samples = 2.0,
                metric = 'minkowski',
                metric_params = mixpeek.models.metric_params.Metric Params(),
                leaf_size = 1.0,
                p = 1.337,
                n_jobs = 56,
                min_cluster_size = 1.337,
                cluster_selection_epsilon = 0.0,
                max_cluster_size = 1.0,
                alpha = 1.337,
                cluster_selection_method = 'eom',
                allow_single_cluster = True,
                prediction_data = True,
                match_reference_implementation = True,
                affinity = 'rbf',
                memory = '',
                connectivity = None,
                compute_full_tree = 'auto',
                linkage = 'ward',
                distance_threshold = 1.337,
                compute_distances = True,
                eigen_solver = '',
                n_components = 1.0,
                gamma = 1.337,
                n_neighbors = 1.0,
                eigen_tol = 0.0,
                assign_labels = 'kmeans',
                degree = 1.337,
                coef0 = 1.337,
                kernel_params = mixpeek.models.kernel_params.Kernel Params(),
                covariance_type = 'full',
                reg_covar = 0.0,
                init_params = 'kmeans',
                weights_init = [
                    null
                    ],
                means_init = [
                    null
                    ],
                precisions_init = [
                    null
                    ],
                warm_start = True,
                verbose_interval = 1.0,
                bandwidth = 1.337,
                seeds = [
                    [
                        1.337
                        ]
                    ],
                bin_seeding = True,
                min_bin_freq = 1.0,
                cluster_all = True,
                max_eps = 1.337,
                cluster_method = 'xi',
                xi = 0.0,
                predecessor_correction = True
            )
        else:
            return AlgorithmParams(
        )
        """

    def testAlgorithmParams(self):
        """Test AlgorithmParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
