# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.key_status import KeyStatus
from mixpeek.models.permission import Permission
from mixpeek.models.resource_scope_input import ResourceScopeInput
from typing import Optional, Set
from typing_extensions import Self

class APIKeyUpdateRequest(BaseModel):
    """
    Partial update payload for an API key.
    """ # noqa: E501
    name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=100)]] = Field(default=None, description="New key label.")
    description: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="Updated description for the key.")
    permissions: Optional[List[Permission]] = Field(default=None, description="Replace existing permissions with the provided list.")
    scopes: Optional[List[ResourceScopeInput]] = Field(default=None, description="Replace existing scopes. Use empty list for global access.")
    rate_limit_override: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Updated per-key rate limit override.")
    expires_at: Optional[datetime] = Field(default=None, description="New expiration timestamp. Use null to remove expiration.")
    status: Optional[KeyStatus] = Field(default=None, description="Manually set key status (e.g. revoke).")
    __properties: ClassVar[List[str]] = ["name", "description", "permissions", "scopes", "rate_limit_override", "expires_at", "status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of APIKeyUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in scopes (list)
        _items = []
        if self.scopes:
            for _item_scopes in self.scopes:
                if _item_scopes:
                    _items.append(_item_scopes.to_dict())
            _dict['scopes'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of APIKeyUpdateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "permissions": obj.get("permissions"),
            "scopes": [ResourceScopeInput.from_dict(_item) for _item in obj["scopes"]] if obj.get("scopes") is not None else None,
            "rate_limit_override": obj.get("rate_limit_override"),
            "expires_at": obj.get("expires_at"),
            "status": obj.get("status")
        })
        return _obj


