# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from mixpeek.models.task_progress import TaskProgress
from typing import Optional, Set
from typing_extensions import Self

class TierDiagnostic(BaseModel):
    """
    Diagnostic information for a single tier.
    """ # noqa: E501
    tier_num: StrictInt = Field(description="Tier number")
    task_id: Optional[StrictStr] = Field(default=None, description="Task ID for this tier")
    status: StrictStr = Field(description="Tier status (PENDING, PROCESSING, COMPLETED, FAILED)")
    started_at: Optional[datetime] = Field(default=None, description="When tier started")
    completed_at: Optional[datetime] = Field(default=None, description="When tier completed")
    duration_seconds: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Duration in seconds")
    progress: Optional[TaskProgress] = Field(default=None, description="Progress information")
    ray_job_id: Optional[StrictStr] = Field(default=None, description="Ray job ID")
    ray_dashboard_url: Optional[StrictStr] = Field(default=None, description="Link to Ray dashboard")
    error: Optional[StrictStr] = Field(default=None, description="Error message if failed")
    error_type: Optional[StrictStr] = Field(default=None, description="Error type if failed")
    __properties: ClassVar[List[str]] = ["tier_num", "task_id", "status", "started_at", "completed_at", "duration_seconds", "progress", "ray_job_id", "ray_dashboard_url", "error", "error_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TierDiagnostic from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of progress
        if self.progress:
            _dict['progress'] = self.progress.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TierDiagnostic from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "tier_num": obj.get("tier_num"),
            "task_id": obj.get("task_id"),
            "status": obj.get("status"),
            "started_at": obj.get("started_at"),
            "completed_at": obj.get("completed_at"),
            "duration_seconds": obj.get("duration_seconds"),
            "progress": TaskProgress.from_dict(obj["progress"]) if obj.get("progress") is not None else None,
            "ray_job_id": obj.get("ray_job_id"),
            "ray_dashboard_url": obj.get("ray_dashboard_url"),
            "error": obj.get("error"),
            "error_type": obj.get("error_type")
        })
        return _obj


