# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.notifications_api import NotificationsApi


class TestNotificationsApi(unittest.TestCase):
    """NotificationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationsApi()

    def tearDown(self) -> None:
        pass

    def test_delete_notification(self) -> None:
        """Test case for delete_notification

        Delete Notification
        """
        pass

    def test_get_funnel_state_notifications(self) -> None:
        """Test case for get_funnel_state_notifications

        Get Funnel State
        """
        pass

    def test_get_notification(self) -> None:
        """Test case for get_notification

        Get Notification
        """
        pass

    def test_get_preferences_notifications(self) -> None:
        """Test case for get_preferences_notifications

        Get Preferences
        """
        pass

    def test_get_reminder_preferences_notifications(self) -> None:
        """Test case for get_reminder_preferences_notifications

        Get Reminder Preferences
        """
        pass

    def test_get_unread_count_notifications(self) -> None:
        """Test case for get_unread_count_notifications

        Get Unread Count
        """
        pass

    def test_list_notifications(self) -> None:
        """Test case for list_notifications

        List Notifications
        """
        pass

    def test_mark_all_as_read_notifications(self) -> None:
        """Test case for mark_all_as_read_notifications

        Mark All As Read
        """
        pass

    def test_mark_as_read_notifications(self) -> None:
        """Test case for mark_as_read_notifications

        Mark As Read
        """
        pass

    def test_update_preferences_notifications(self) -> None:
        """Test case for update_preferences_notifications

        Update Preferences
        """
        pass

    def test_update_reminder_preferences_notifications(self) -> None:
        """Test case for update_reminder_preferences_notifications

        Update Reminder Preferences
        """
        pass


if __name__ == '__main__':
    unittest.main()
