# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.create_blob_request import CreateBlobRequest
from typing import Optional, Set
from typing_extensions import Self

class CreateObjectRequest(BaseModel):
    """
    Request model for creating a bucket object.  Objects can be created with blobs from two sources: 1. Direct data (URLs, base64) - Use CreateBlobRequest.data field 2. Upload references - Use CreateBlobRequest.upload_id field (from POST /buckets/{id}/uploads)  Upload Reference Workflow:     For large files or client-side uploads, use the presigned URL workflow:     1. POST /buckets/{id}/uploads → Returns {upload_id, presigned_url}     2. User uploads file to presigned_url (client-side)     3. POST /uploads/{upload_id}/confirm → Validates upload     4. POST /buckets/{id}/objects with upload_id in blobs (this endpoint)  Use Cases:     - Single blob with direct data (simple)     - Multiple blobs from presigned uploads (recommended for large files)     - Mix of direct data and upload references     - Combine multiple uploads into one object  See Also:     - CreateBlobRequest for blob field documentation     - POST /buckets/{id}/uploads for presigned URL generation
    """ # noqa: E501
    key_prefix: Optional[StrictStr] = Field(default=None, description="Storage key/path prefix of the object, this will be used to retrieve the object from the storage. It's at the root of the object.")
    blobs: Optional[List[CreateBlobRequest]] = Field(default=None, description="List of blobs to be created in this object")
    skip_duplicates: Optional[StrictBool] = Field(default=False, description="Skip duplicate blobs, if a blob with the same hash already exists, it will be skipped.")
    canonicalize_source: Optional[StrictBool] = Field(default=True, description="Mirror non-S3 sources into internal S3 and reference canonically.")
    force_remirror: Optional[StrictBool] = Field(default=False, description="Force re-upload to S3 even if a blob with identical content already exists.")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["key_prefix", "blobs", "skip_duplicates", "canonicalize_source", "force_remirror"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateObjectRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in blobs (list)
        _items = []
        if self.blobs:
            for _item_blobs in self.blobs:
                if _item_blobs:
                    _items.append(_item_blobs.to_dict())
            _dict['blobs'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateObjectRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "key_prefix": obj.get("key_prefix"),
            "blobs": [CreateBlobRequest.from_dict(_item) for _item in obj["blobs"]] if obj.get("blobs") is not None else None,
            "skip_duplicates": obj.get("skip_duplicates") if obj.get("skip_duplicates") is not None else False,
            "canonicalize_source": obj.get("canonicalize_source") if obj.get("canonicalize_source") is not None else True,
            "force_remirror": obj.get("force_remirror") if obj.get("force_remirror") is not None else False
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


