# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.retriever_execution_statistics import RetrieverExecutionStatistics

class TestRetrieverExecutionStatistics(unittest.TestCase):
    """RetrieverExecutionStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RetrieverExecutionStatistics:
        """Test RetrieverExecutionStatistics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RetrieverExecutionStatistics`
        """
        model = RetrieverExecutionStatistics()
        if include_optional:
            return RetrieverExecutionStatistics(
                stages = {
                    'key' : mixpeek.models.stage_statistics.StageStatistics(
                        input_count = 0.0, 
                        output_count = 0.0, 
                        duration_ms = 0.0, 
                        efficiency = 0.0, 
                        cache_hit = True, 
                        error = '', 
                        llm_calls = 0.0, 
                        tokens_used = 0.0, 
                        metadata = mixpeek.models.metadata.Metadata(), )
                    },
                total_time_ms = 0.0,
                credits_used = 0.0
            )
        else:
            return RetrieverExecutionStatistics(
        )
        """

    def testRetrieverExecutionStatistics(self):
        """Test RetrieverExecutionStatistics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
