# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.custom_model_document import CustomModelDocument

class TestCustomModelDocument(unittest.TestCase):
    """CustomModelDocument unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomModelDocument:
        """Test CustomModelDocument
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomModelDocument`
        """
        model = CustomModelDocument()
        if include_optional:
            return CustomModelDocument(
                model_id = '',
                namespace_id = '',
                name = '',
                version = '',
                model_archive_url = '',
                model_format = 'safetensors',
                model_hash = '',
                deployed = True,
                deployment_info = mixpeek.models.model_deployment_info.ModelDeploymentInfo(
                    ray_cluster_url = '', 
                    ray_deployment_name = '', 
                    endpoint = '', 
                    base_image = '', 
                    deployed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                framework = '',
                task_type = '',
                input_schema = mixpeek.models.input_schema.Input Schema(),
                output_schema = mixpeek.models.output_schema.Output Schema(),
                resource_requirements = mixpeek.models.model_resource_requirements.ModelResourceRequirements(
                    num_cpus = 0.1, 
                    num_gpus = 0.0, 
                    memory = 56, ),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return CustomModelDocument(
                model_id = '',
                namespace_id = '',
                name = '',
                version = '',
                model_archive_url = '',
                model_format = 'safetensors',
                model_hash = '',
        )
        """

    def testCustomModelDocument(self):
        """Test CustomModelDocument"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
