# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.namespace_migrations_api import NamespaceMigrationsApi


class TestNamespaceMigrationsApi(unittest.TestCase):
    """NamespaceMigrationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NamespaceMigrationsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_migration_namespaces(self) -> None:
        """Test case for cancel_migration_namespaces

        Cancel Migration
        """
        pass

    def test_create_migration_namespaces(self) -> None:
        """Test case for create_migration_namespaces

        Create Migration
        """
        pass

    def test_delete_migration_namespaces(self) -> None:
        """Test case for delete_migration_namespaces

        Delete Migration
        """
        pass

    def test_get_migration_namespaces(self) -> None:
        """Test case for get_migration_namespaces

        Get Migration
        """
        pass

    def test_list_migrations_namespaces(self) -> None:
        """Test case for list_migrations_namespaces

        List Migrations
        """
        pass

    def test_start_migration_namespaces(self) -> None:
        """Test case for start_migration_namespaces

        Start Migration
        """
        pass

    def test_validate_migration_namespaces(self) -> None:
        """Test case for validate_migration_namespaces

        Validate Migration
        """
        pass


if __name__ == '__main__':
    unittest.main()
