# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class StageStatistics(BaseModel):
    """
    Execution metrics for a single stage in a retriever execution run.
    """ # noqa: E501
    input_count: Annotated[int, Field(strict=True, ge=0)] = Field(description="Number of documents received by the stage (REQUIRED).")
    output_count: Annotated[int, Field(strict=True, ge=0)] = Field(description="Number of documents emitted by the stage (REQUIRED).")
    duration_ms: Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]] = Field(description="Wall-clock duration in milliseconds (REQUIRED).")
    efficiency: Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]] = Field(description="Output/Input ratio. 0 when input_count is 0 (REQUIRED).")
    cache_hit: Optional[StrictBool] = Field(default=None, description="Indicates whether the result originated from stage cache (OPTIONAL).")
    error: Optional[StrictStr] = Field(default=None, description="Stage-specific error message if execution failed but retriever execution continued (OPTIONAL).")
    llm_calls: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, description="Number of LLM invocations performed by the stage (OPTIONAL).")
    tokens_used: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, description="Total tokens consumed by the stage (OPTIONAL, only for LLM stages).")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Stage-specific metadata containing additional execution details (OPTIONAL). For example, join stages include: join_strategy, join_type, matched_count, match_rate, etc. LLM stages may include: model_name, temperature, max_tokens, etc.")
    __properties: ClassVar[List[str]] = ["input_count", "output_count", "duration_ms", "efficiency", "cache_hit", "error", "llm_calls", "tokens_used", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StageStatistics from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StageStatistics from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "input_count": obj.get("input_count"),
            "output_count": obj.get("output_count"),
            "duration_ms": obj.get("duration_ms"),
            "efficiency": obj.get("efficiency"),
            "cache_hit": obj.get("cache_hit"),
            "error": obj.get("error"),
            "llm_calls": obj.get("llm_calls"),
            "tokens_used": obj.get("tokens_used"),
            "metadata": obj.get("metadata")
        })
        return _obj


