# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_templates_response import ListTemplatesResponse

class TestListTemplatesResponse(unittest.TestCase):
    """ListTemplatesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListTemplatesResponse:
        """Test ListTemplatesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListTemplatesResponse`
        """
        model = ListTemplatesResponse()
        if include_optional:
            return ListTemplatesResponse(
                results = [
                    mixpeek.models.base_template_model.BaseTemplateModel(
                        template_id = 'tmpl_p', 
                        template_type = null, 
                        mode = null, 
                        scope = null, 
                        internal_id = '', 
                        name = '0', 
                        description = '0', 
                        category = '', 
                        configuration = mixpeek.models.configuration.Configuration(), 
                        tags = [
                            ''
                            ], 
                        is_active = True, 
                        is_public = True, 
                        use_cases = [
                            ''
                            ], 
                        requirements = [
                            ''
                            ], 
                        created_by = '', 
                        source_resource_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total_count = 56
            )
        else:
            return ListTemplatesResponse(
                results = [
                    mixpeek.models.base_template_model.BaseTemplateModel(
                        template_id = 'tmpl_p', 
                        template_type = null, 
                        mode = null, 
                        scope = null, 
                        internal_id = '', 
                        name = '0', 
                        description = '0', 
                        category = '', 
                        configuration = mixpeek.models.configuration.Configuration(), 
                        tags = [
                            ''
                            ], 
                        is_active = True, 
                        is_public = True, 
                        use_cases = [
                            ''
                            ], 
                        requirements = [
                            ''
                            ], 
                        created_by = '', 
                        source_resource_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total_count = 56,
        )
        """

    def testListTemplatesResponse(self):
        """Test ListTemplatesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
