# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.seo_config import SEOConfig

class TestSEOConfig(unittest.TestCase):
    """SEOConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SEOConfig:
        """Test SEOConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SEOConfig`
        """
        model = SEOConfig()
        if include_optional:
            return SEOConfig(
                meta_title = '',
                meta_description = '',
                keywords = [
                    ''
                    ],
                og_image_url = '',
                og_image_alt = '',
                og_type = 'website',
                twitter_card = 'summary_large_image',
                twitter_site = '@mixpeek',
                twitter_creator = '',
                robots = 'index, follow',
                canonical_url = '',
                site_name = 'Mixpeek',
                author = '',
                locale = 'en_US',
                logo_url = '',
                favicon_url = '',
                structured_data = mixpeek.models.structured_data_config.StructuredDataConfig(
                    type = 'WebApplication', 
                    additional_properties = mixpeek.models.additional_properties.Additional Properties(), )
            )
        else:
            return SEOConfig(
        )
        """

    def testSEOConfig(self):
        """Test SEOConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
