# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.pagination_method import PaginationMethod
from typing import Optional, Set
from typing_extensions import Self

class OffsetPaginationParams(BaseModel):
    """
    Offset-based pagination using page number sizing.  Best for: Traditional page UIs with page number navigation  How it works: - Uses page numbers (1, 2, 3...) and page size - Calculates offset as: (page_number - 1) * page_size - Simple and familiar for users - Can jump to any page directly  Tradeoffs: - Can have \"page drift\" if data changes between requests - Example: Items added/deleted causes duplicates or gaps - Less efficient for large offsets (database must skip N rows)  Use when: - Building traditional page-numbered UIs - Users need to jump to specific pages - Result set is relatively stable - Working with smaller datasets  Example: Page 1: {\"method\": \"offset\", \"page_size\": 25, \"page_number\": 1} Page 2: {\"method\": \"offset\", \"page_size\": 25, \"page_number\": 2}
    """ # noqa: E501
    method: Optional[PaginationMethod] = Field(default=None, description="Constant identifying offset pagination (REQUIRED).")
    page_size: Optional[Annotated[int, Field(le=500, strict=True, ge=1)]] = Field(default=10, description="Number of documents per page (REQUIRED). Default: 10.")
    page_number: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=1, description="1-based page index to retrieve (REQUIRED). Default: 1.")
    __properties: ClassVar[List[str]] = ["method", "page_size", "page_number"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OffsetPaginationParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OffsetPaginationParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "method": obj.get("method"),
            "page_size": obj.get("page_size") if obj.get("page_size") is not None else 10,
            "page_number": obj.get("page_number") if obj.get("page_number") is not None else 1
        })
        return _obj


