# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.sync_update_request import SyncUpdateRequest

class TestSyncUpdateRequest(unittest.TestCase):
    """SyncUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyncUpdateRequest:
        """Test SyncUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyncUpdateRequest`
        """
        model = SyncUpdateRequest()
        if include_optional:
            return SyncUpdateRequest(
                description = '',
                metadata = mixpeek.models.metadata.Metadata(),
                status = 'PENDING',
                is_active = True,
                polling_interval_seconds = 30.0,
                batch_size = 1.0,
                schema_mapping = mixpeek.models.schema_mapping.SchemaMapping(
                    mappings = {
                        'key' : null
                        }, ),
                skip_batch_submission = True
            )
        else:
            return SyncUpdateRequest(
        )
        """

    def testSyncUpdateRequest(self):
        """Test SyncUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
