# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.batch_delete_documents_response import BatchDeleteDocumentsResponse

class TestBatchDeleteDocumentsResponse(unittest.TestCase):
    """BatchDeleteDocumentsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BatchDeleteDocumentsResponse:
        """Test BatchDeleteDocumentsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BatchDeleteDocumentsResponse`
        """
        model = BatchDeleteDocumentsResponse()
        if include_optional:
            return BatchDeleteDocumentsResponse(
                deleted_count = 56,
                failed_count = 56,
                results = [
                    mixpeek.models.batch_document_delete_result.BatchDocumentDeleteResult(
                        document_id = '', 
                        success = True, 
                        error = '', )
                    ],
                message = 'Batch delete completed'
            )
        else:
            return BatchDeleteDocumentsResponse(
                deleted_count = 56,
        )
        """

    def testBatchDeleteDocumentsResponse(self):
        """Test BatchDeleteDocumentsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
