# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.extractor_job_info import ExtractorJobInfo

class TestExtractorJobInfo(unittest.TestCase):
    """ExtractorJobInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExtractorJobInfo:
        """Test ExtractorJobInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExtractorJobInfo`
        """
        model = ExtractorJobInfo()
        if include_optional:
            return ExtractorJobInfo(
                extractor_type = '',
                collection_ids = [
                    ''
                    ],
                ray_job_id = '',
                celery_task_id = '',
                status = 'PENDING',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                duration_ms = 1.337,
                documents_written = 56,
                errors = [
                    mixpeek.models.batch_error_detail.BatchErrorDetail(
                        error_type = null, 
                        message = '', 
                        component = '', 
                        stage = '', 
                        traceback = '', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        affected_document_ids = [
                            ''
                            ], 
                        affected_count = 1.0, 
                        recovery_suggestion = '', 
                        metadata = mixpeek.models.metadata.Metadata(), )
                    ],
                error = ''
            )
        else:
            return ExtractorJobInfo(
                extractor_type = '',
        )
        """

    def testExtractorJobInfo(self):
        """Test ExtractorJobInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
