# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_notifications_response import ListNotificationsResponse

class TestListNotificationsResponse(unittest.TestCase):
    """ListNotificationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListNotificationsResponse:
        """Test ListNotificationsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListNotificationsResponse`
        """
        model = ListNotificationsResponse()
        if include_optional:
            return ListNotificationsResponse(
                results = [
                    mixpeek.models.notification.Notification(
                        id = '', 
                        type = null, 
                        priority = null, 
                        title = '', 
                        content = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        organization_id = '', 
                        user_id = '', 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        delivery_status = {
                            'key' : ''
                            }, 
                        read = True, 
                        read_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = mixpeek.models.pagination.Pagination(),
                total = 56
            )
        else:
            return ListNotificationsResponse(
                results = [
                    mixpeek.models.notification.Notification(
                        id = '', 
                        type = null, 
                        priority = null, 
                        title = '', 
                        content = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        organization_id = '', 
                        user_id = '', 
                        metadata = mixpeek.models.metadata.Metadata(), 
                        delivery_status = {
                            'key' : ''
                            }, 
                        read = True, 
                        read_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                pagination = mixpeek.models.pagination.Pagination(),
                total = 56,
        )
        """

    def testListNotificationsResponse(self):
        """Test ListNotificationsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
