# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.batch_confirm_response import BatchConfirmResponse

class TestBatchConfirmResponse(unittest.TestCase):
    """BatchConfirmResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BatchConfirmResponse:
        """Test BatchConfirmResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BatchConfirmResponse`
        """
        model = BatchConfirmResponse()
        if include_optional:
            return BatchConfirmResponse(
                task_id = '',
                status = 'PENDING',
                confirmations_count = 56,
                task = mixpeek.models.task_response.TaskResponse(
                    task_id = '', 
                    task_type = null, 
                    status = null, 
                    inputs = [
                        null
                        ], 
                    outputs = [
                        null
                        ], 
                    additional_data = mixpeek.models.additional_data.Additional Data(), 
                    error = '', ),
                message = 'Batch confirmation is being processed in the background.'
            )
        else:
            return BatchConfirmResponse(
                task_id = '',
                status = 'PENDING',
                confirmations_count = 56,
                task = mixpeek.models.task_response.TaskResponse(
                    task_id = '', 
                    task_type = null, 
                    status = null, 
                    inputs = [
                        null
                        ], 
                    outputs = [
                        null
                        ], 
                    additional_data = mixpeek.models.additional_data.Additional Data(), 
                    error = '', ),
        )
        """

    def testBatchConfirmResponse(self):
        """Test BatchConfirmResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
