# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.invoice_list_response import InvoiceListResponse

class TestInvoiceListResponse(unittest.TestCase):
    """InvoiceListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InvoiceListResponse:
        """Test InvoiceListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InvoiceListResponse`
        """
        model = InvoiceListResponse()
        if include_optional:
            return InvoiceListResponse(
                invoices = [
                    mixpeek.models.invoice_info.InvoiceInfo(
                        invoice_id = '', 
                        invoice_url = '', 
                        invoice_pdf = '', 
                        amount_due = 56, 
                        amount_paid = 56, 
                        status = '', 
                        billing_month = '', 
                        total_credits = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        paid_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                total = 56,
                has_more = True
            )
        else:
            return InvoiceListResponse(
                total = 56,
                has_more = True,
        )
        """

    def testInvoiceListResponse(self):
        """Test InvoiceListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
