# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.components_config import ComponentsConfig

class TestComponentsConfig(unittest.TestCase):
    """ComponentsConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ComponentsConfig:
        """Test ComponentsConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ComponentsConfig`
        """
        model = ComponentsConfig()
        if include_optional:
            return ComponentsConfig(
                show_hero = True,
                show_search = True,
                show_filters = True,
                show_results_header = True,
                result_layout = 'grid',
                result_card = mixpeek.models.result_card_properties.ResultCardProperties(
                    layout = 'vertical', 
                    show_thumbnail = True, 
                    thumbnail_aspect_ratio = '16/9', 
                    thumbnail_fit = 'cover', 
                    show_score = True, 
                    truncate_title = 1.0, 
                    truncate_description = 1.0, 
                    field_order = [
                        ''
                        ], 
                    show_find_similar = True, 
                    card_click_action = 'viewDetails', 
                    thumbnail_field = '', 
                    title_field = '', 
                    card_fields = [
                        ''
                        ], 
                    modal_fields = [
                        ''
                        ], 
                    card_style = 'default', )
            )
        else:
            return ComponentsConfig(
        )
        """

    def testComponentsConfig(self):
        """Test ComponentsConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
