# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.instantiated_taxonomy_template_response import InstantiatedTaxonomyTemplateResponse

class TestInstantiatedTaxonomyTemplateResponse(unittest.TestCase):
    """InstantiatedTaxonomyTemplateResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InstantiatedTaxonomyTemplateResponse:
        """Test InstantiatedTaxonomyTemplateResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InstantiatedTaxonomyTemplateResponse`
        """
        model = InstantiatedTaxonomyTemplateResponse()
        if include_optional:
            return InstantiatedTaxonomyTemplateResponse(
                taxonomy_id = '',
                taxonomy_name = '',
                template_id = '',
                status = 'created',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return InstantiatedTaxonomyTemplateResponse(
                taxonomy_id = '',
                taxonomy_name = '',
                template_id = '',
        )
        """

    def testInstantiatedTaxonomyTemplateResponse(self):
        """Test InstantiatedTaxonomyTemplateResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
