# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.clone_taxonomy_response import CloneTaxonomyResponse

class TestCloneTaxonomyResponse(unittest.TestCase):
    """CloneTaxonomyResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CloneTaxonomyResponse:
        """Test CloneTaxonomyResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CloneTaxonomyResponse`
        """
        model = CloneTaxonomyResponse()
        if include_optional:
            return CloneTaxonomyResponse(
                taxonomy = mixpeek.models.taxonomy_model.TaxonomyModel(
                    taxonomy_id = '', 
                    version = 1.0, 
                    taxonomy_name = '', 
                    description = '', 
                    retriever_id = '', 
                    input_mappings = [
                        mixpeek.models.input_mapping.InputMapping(
                            input_key = '', 
                            source_type = 'payload', 
                            path = '', 
                            override = null, )
                        ], 
                    config = null, 
                    ready = True, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    metadata = mixpeek.models.metadata.Metadata(), ),
                source_taxonomy_id = ''
            )
        else:
            return CloneTaxonomyResponse(
                taxonomy = mixpeek.models.taxonomy_model.TaxonomyModel(
                    taxonomy_id = '', 
                    version = 1.0, 
                    taxonomy_name = '', 
                    description = '', 
                    retriever_id = '', 
                    input_mappings = [
                        mixpeek.models.input_mapping.InputMapping(
                            input_key = '', 
                            source_type = 'payload', 
                            path = '', 
                            override = null, )
                        ], 
                    config = null, 
                    ready = True, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    metadata = mixpeek.models.metadata.Metadata(), ),
                source_taxonomy_id = '',
        )
        """

    def testCloneTaxonomyResponse(self):
        """Test CloneTaxonomyResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
