# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.api_plugins_models_plugin_detail_response import ApiPluginsModelsPluginDetailResponse

class TestApiPluginsModelsPluginDetailResponse(unittest.TestCase):
    """ApiPluginsModelsPluginDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiPluginsModelsPluginDetailResponse:
        """Test ApiPluginsModelsPluginDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiPluginsModelsPluginDetailResponse`
        """
        model = ApiPluginsModelsPluginDetailResponse()
        if include_optional:
            return ApiPluginsModelsPluginDetailResponse(
                success = True,
                plugin = mixpeek.models.plugin_document.PluginDocument(
                    plugin_id = '', 
                    organization_id = '', 
                    name = '', 
                    version = '', 
                    description = '', 
                    s3_archive_url = '', 
                    code_hash = '', 
                    validation_status = 'passed', 
                    validation_errors = [
                        ''
                        ], 
                    security_scan_passed = True, 
                    deployed = True, 
                    deployment_info = mixpeek.models.plugin_deployment_info.PluginDeploymentInfo(
                        ray_cluster_url = '', 
                        ray_deployment_name = '', 
                        feature_uri = '', 
                        deployed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    manifest = mixpeek.models.plugin_manifest_metadata.PluginManifestMetadata(
                        feature_extractor_name = '', 
                        version = '', 
                        description = '', 
                        input_schema = mixpeek.models.input_schema.Input Schema(), 
                        output_schema = mixpeek.models.output_schema.Output Schema(), 
                        parameter_schema = mixpeek.models.parameter_schema.Parameter Schema(), 
                        required_vector_indexes = [
                            None
                            ], 
                        features = [
                            None
                            ], 
                        dependencies = [
                            ''
                            ], 
                        feature_uri = '', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    deployed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    resolved_inference_name = '', )
            )
        else:
            return ApiPluginsModelsPluginDetailResponse(
                plugin = mixpeek.models.plugin_document.PluginDocument(
                    plugin_id = '', 
                    organization_id = '', 
                    name = '', 
                    version = '', 
                    description = '', 
                    s3_archive_url = '', 
                    code_hash = '', 
                    validation_status = 'passed', 
                    validation_errors = [
                        ''
                        ], 
                    security_scan_passed = True, 
                    deployed = True, 
                    deployment_info = mixpeek.models.plugin_deployment_info.PluginDeploymentInfo(
                        ray_cluster_url = '', 
                        ray_deployment_name = '', 
                        feature_uri = '', 
                        deployed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    manifest = mixpeek.models.plugin_manifest_metadata.PluginManifestMetadata(
                        feature_extractor_name = '', 
                        version = '', 
                        description = '', 
                        input_schema = mixpeek.models.input_schema.Input Schema(), 
                        output_schema = mixpeek.models.output_schema.Output Schema(), 
                        parameter_schema = mixpeek.models.parameter_schema.Parameter Schema(), 
                        required_vector_indexes = [
                            None
                            ], 
                        features = [
                            None
                            ], 
                        dependencies = [
                            ''
                            ], 
                        feature_uri = '', ), 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    deployed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    resolved_inference_name = '', ),
        )
        """

    def testApiPluginsModelsPluginDetailResponse(self):
        """Test ApiPluginsModelsPluginDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
