# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.collection_templates_api import CollectionTemplatesApi


class TestCollectionTemplatesApi(unittest.TestCase):
    """CollectionTemplatesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CollectionTemplatesApi()

    def tearDown(self) -> None:
        pass

    def test_create_collection_template_from(self) -> None:
        """Test case for create_collection_template_from

        Create Collection Template
        """
        pass

    def test_get_collection_template(self) -> None:
        """Test case for get_collection_template

        Get Collection Template
        """
        pass

    def test_instantiate_collection_template(self) -> None:
        """Test case for instantiate_collection_template

        Instantiate Collection Template
        """
        pass

    def test_list_collection_templates(self) -> None:
        """Test case for list_collection_templates

        List Collection Templates
        """
        pass


if __name__ == '__main__':
    unittest.main()
