# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ExtractorSource(str, Enum):
    """
    The source/origin of a feature extractor.  Values:     BUILTIN: Core extractors shipped with Mixpeek (text, image, multimodal, etc.)     CUSTOM: User-created extractors uploaded to their namespace (Enterprise only)     COMMUNITY: Community-contributed extractors from the Mixpeek marketplace  This field helps API consumers understand: - What level of support/maintenance to expect - Whether the extractor is available to all users or namespace-specific - Licensing and attribution requirements
    """

    """
    allowed enum values
    """
    BUILTIN = 'builtin'
    CUSTOM = 'custom'
    COMMUNITY = 'community'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ExtractorSource from a JSON string"""
        return cls(json.loads(json_str))


