# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.payment_method_info import PaymentMethodInfo
from typing import Optional, Set
from typing_extensions import Self

class ConfirmPaymentMethodResponse(BaseModel):
    """
    Response after confirming payment method.
    """ # noqa: E501
    success: Optional[StrictBool] = Field(default=True, description="Whether payment method was successfully confirmed")
    payment_method: PaymentMethodInfo = Field(description="Confirmed payment method details")
    auto_billing_enabled: StrictBool = Field(description="Whether auto-billing is now enabled")
    billing_period_start: datetime = Field(description="When the current billing period started")
    __properties: ClassVar[List[str]] = ["success", "payment_method", "auto_billing_enabled", "billing_period_start"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ConfirmPaymentMethodResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of payment_method
        if self.payment_method:
            _dict['payment_method'] = self.payment_method.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ConfirmPaymentMethodResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "success": obj.get("success") if obj.get("success") is not None else True,
            "payment_method": PaymentMethodInfo.from_dict(obj["payment_method"]) if obj.get("payment_method") is not None else None,
            "auto_billing_enabled": obj.get("auto_billing_enabled"),
            "billing_period_start": obj.get("billing_period_start")
        })
        return _obj


