# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.analytics_taxonomies_api import AnalyticsTaxonomiesApi


class TestAnalyticsTaxonomiesApi(unittest.TestCase):
    """AnalyticsTaxonomiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AnalyticsTaxonomiesApi()

    def tearDown(self) -> None:
        pass

    def test_get_assignment_metrics_analytics_taxonomies_taxonomy(self) -> None:
        """Test case for get_assignment_metrics_analytics_taxonomies_taxonomy

        Get Assignment Metrics
        """
        pass

    def test_get_confidence_distribution_analytics_taxonomies_taxonomy(self) -> None:
        """Test case for get_confidence_distribution_analytics_taxonomies_taxonomy

        Get Confidence Distribution
        """
        pass

    def test_get_enrichment_history_analytics_taxonomies_taxonomy(self) -> None:
        """Test case for get_enrichment_history_analytics_taxonomies_taxonomy

        Get Enrichment History
        """
        pass

    def test_get_label_distribution_analytics_taxonomies_taxonomy(self) -> None:
        """Test case for get_label_distribution_analytics_taxonomies_taxonomy

        Get Label Distribution
        """
        pass


if __name__ == '__main__':
    unittest.main()
