# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.bucket_objects_api import BucketObjectsApi


class TestBucketObjectsApi(unittest.TestCase):
    """BucketObjectsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BucketObjectsApi()

    def tearDown(self) -> None:
        pass

    def test_aggregate_objects_buckets(self) -> None:
        """Test case for aggregate_objects_buckets

        Aggregate Objects
        """
        pass

    def test_create_object_buckets(self) -> None:
        """Test case for create_object_buckets

        Create Object
        """
        pass

    def test_create_objects_batch_buckets(self) -> None:
        """Test case for create_objects_batch_buckets

        Create Objects in Batch
        """
        pass

    def test_delete_object_buckets(self) -> None:
        """Test case for delete_object_buckets

        Delete Object
        """
        pass

    def test_get_object_buckets(self) -> None:
        """Test case for get_object_buckets

        Get Object
        """
        pass

    def test_list_objects_buckets(self) -> None:
        """Test case for list_objects_buckets

        List Objects
        """
        pass

    def test_patch_object_buckets(self) -> None:
        """Test case for patch_object_buckets

        Partially Update Object
        """
        pass

    def test_update_object_buckets(self) -> None:
        """Test case for update_object_buckets

        Update Object
        """
        pass


if __name__ == '__main__':
    unittest.main()
