# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_tasks_response import ListTasksResponse

class TestListTasksResponse(unittest.TestCase):
    """ListTasksResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListTasksResponse:
        """Test ListTasksResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListTasksResponse`
        """
        model = ListTasksResponse()
        if include_optional:
            return ListTasksResponse(
                results = [
                    mixpeek.models.task_response.TaskResponse(
                        task_id = '', 
                        task_type = null, 
                        status = null, 
                        inputs = [
                            null
                            ], 
                        outputs = [
                            null
                            ], 
                        additional_data = mixpeek.models.additional_data.Additional Data(), 
                        error = '', )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', )
            )
        else:
            return ListTasksResponse(
                results = [
                    mixpeek.models.task_response.TaskResponse(
                        task_id = '', 
                        task_type = null, 
                        status = null, 
                        inputs = [
                            null
                            ], 
                        outputs = [
                            null
                            ], 
                        additional_data = mixpeek.models.additional_data.Additional Data(), 
                        error = '', )
                    ],
                pagination = mixpeek.models.pagination_response.PaginationResponse(
                    total = 56, 
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    next_page = '', 
                    previous_page = '', 
                    next_cursor = '', ),
        )
        """

    def testListTasksResponse(self):
        """Test ListTasksResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
