# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.index_suggestions_response import IndexSuggestionsResponse

class TestIndexSuggestionsResponse(unittest.TestCase):
    """IndexSuggestionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IndexSuggestionsResponse:
        """Test IndexSuggestionsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IndexSuggestionsResponse`
        """
        model = IndexSuggestionsResponse()
        if include_optional:
            return IndexSuggestionsResponse(
                namespace_id = '',
                analysis_period = '',
                suggestions = [
                    mixpeek.models.index_suggestion.IndexSuggestion(
                        field_name = '', 
                        query_count_24h = 56, 
                        query_count_7d = 56, 
                        suggested_type = '', 
                        is_indexed = True, 
                        first_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        estimated_performance_gain = '', )
                    ],
                auto_create_enabled = True,
                next_auto_create_run = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return IndexSuggestionsResponse(
                namespace_id = '',
                analysis_period = '',
                suggestions = [
                    mixpeek.models.index_suggestion.IndexSuggestion(
                        field_name = '', 
                        query_count_24h = 56, 
                        query_count_7d = 56, 
                        suggested_type = '', 
                        is_indexed = True, 
                        first_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_seen = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        estimated_performance_gain = '', )
                    ],
                auto_create_enabled = True,
        )
        """

    def testIndexSuggestionsResponse(self):
        """Test IndexSuggestionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
