# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.private_api import PrivateApi


class TestPrivateApi(unittest.TestCase):
    """PrivateApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PrivateApi()

    def tearDown(self) -> None:
        pass

    def test_add_user_to_organization(self) -> None:
        """Test case for add_user_to_organization

        Add User To Organization Private
        """
        pass

    def test_complete_tier_internal_batches_batch_id_num(self) -> None:
        """Test case for complete_tier_internal_batches_batch_id_num

        Mark tier complete and trigger next tier (KISS - Engine callback)
        """
        pass

    def test_configure_storage_cors_configurations(self) -> None:
        """Test case for configure_storage_cors_configurations

        Configure CORS for Object Storage
        """
        pass

    def test_create_bootstrap_key_organizations_id_users_email(self) -> None:
        """Test case for create_bootstrap_key_organizations_id_users_email

        Create Bootstrap Api Key
        """
        pass

    def test_create_organization(self) -> None:
        """Test case for create_organization

        Create Organization Private
        """
        pass

    def test_delete_organization(self) -> None:
        """Test case for delete_organization

        Delete Organization Private
        """
        pass

    def test_diagnose_clickhouse_configurations_diagnostics(self) -> None:
        """Test case for diagnose_clickhouse_configurations_diagnostics

        Diagnose ClickHouse Configuration
        """
        pass

    def test_get_organization(self) -> None:
        """Test case for get_organization

        Get Organization Private
        """
        pass

    def test_get_storage_cors_configurations(self) -> None:
        """Test case for get_storage_cors_configurations

        Get Current CORS Configuration
        """
        pass

    def test_update_organization(self) -> None:
        """Test case for update_organization

        Update Organization Private
        """
        pass

    def test_update_task_status_internal(self) -> None:
        """Test case for update_task_status_internal

        Update task status (Engine callback)
        """
        pass


if __name__ == '__main__':
    unittest.main()
