# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.config1 import Config1
from mixpeek.models.input_mapping import InputMapping
from typing import Optional, Set
from typing_extensions import Self

class TaxonomyModelInput(BaseModel):
    """
    Primary Pydantic model representing a taxonomy definition.
    """ # noqa: E501
    taxonomy_id: Optional[StrictStr] = Field(default=None, description="Unique identifier for the taxonomy")
    version: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=1, description="Monotonic version number of the taxonomy configuration")
    taxonomy_name: StrictStr = Field(description="A unique name for the taxonomy within the namespace.")
    description: Optional[StrictStr] = Field(default=None, description="Optional human-readable description.")
    retriever_id: Optional[StrictStr] = Field(default=None, description="Optional taxonomy-level retriever (prefer per-layer).")
    input_mappings: Optional[List[InputMapping]] = Field(default=None, description="Optional taxonomy-level inputs (prefer per-layer).")
    config: Config1
    ready: Optional[StrictBool] = Field(default=True, description="Whether the taxonomy is ready for use. False for async inference (cluster/LLM) that needs processing. True for flat/explicit hierarchies.")
    created_at: Optional[datetime] = Field(default=None, description="Creation timestamp for this taxonomy record")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Additional user-defined metadata for the taxonomy")
    __properties: ClassVar[List[str]] = ["taxonomy_id", "version", "taxonomy_name", "description", "retriever_id", "input_mappings", "config", "ready", "created_at", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TaxonomyModelInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in input_mappings (list)
        _items = []
        if self.input_mappings:
            for _item_input_mappings in self.input_mappings:
                if _item_input_mappings:
                    _items.append(_item_input_mappings.to_dict())
            _dict['input_mappings'] = _items
        # override the default output from pydantic by calling `to_dict()` of config
        if self.config:
            _dict['config'] = self.config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TaxonomyModelInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "taxonomy_id": obj.get("taxonomy_id"),
            "version": obj.get("version") if obj.get("version") is not None else 1,
            "taxonomy_name": obj.get("taxonomy_name"),
            "description": obj.get("description"),
            "retriever_id": obj.get("retriever_id"),
            "input_mappings": [InputMapping.from_dict(_item) for _item in obj["input_mappings"]] if obj.get("input_mappings") is not None else None,
            "config": Config1.from_dict(obj["config"]) if obj.get("config") is not None else None,
            "ready": obj.get("ready") if obj.get("ready") is not None else True,
            "created_at": obj.get("created_at"),
            "metadata": obj.get("metadata")
        })
        return _obj


