# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.blob_details import BlobDetails
from mixpeek.models.bucket_schema_field_type import BucketSchemaFieldType
from typing import Optional, Set
from typing_extensions import Self

class BlobModel(BaseModel):
    """
    Model for a blob within a bucket object.  Blobs store file references with a flat properties structure. All blob-specific data (formerly in separate 'data' and 'metadata' fields) is now unified in a single 'properties' dictionary.  Example:     {         \"blob_id\": \"blob_xyz123\",         \"property\": \"video\",         \"type\": \"video\",         \"properties\": {             \"url\": \"s3://bucket/video.mp4\",             \"duration\": 120,             \"resolution\": \"1920x1080\",             \"author\": \"John Doe\"  # All data unified here         }     }
    """ # noqa: E501
    blob_id: Optional[StrictStr] = Field(default=None, description="Unique identifier for the blob")
    var_property: StrictStr = Field(description="Property name of the blob", alias="property")
    key_prefix: Optional[StrictStr] = Field(default=None, description="Storage key/path of the blob, this will be used to retrieve the blob from the storage. It is similar to a file path. If not provided, it will be placed in the root of the bucket.")
    type: BucketSchemaFieldType = Field(description="The schema field type this blob corresponds to (e.g., IMAGE, PDF, DOCUMENT)")
    properties: Optional[Dict[str, Any]] = Field(default=None, description="All blob data and metadata unified (formerly separate 'data' and 'metadata' fields). Contains URLs, dimensions, metadata, and any other blob-specific information.")
    details: Optional[BlobDetails] = Field(default=None, description="System-generated file details (filename, size, hash, etc.)")
    __properties: ClassVar[List[str]] = ["blob_id", "property", "key_prefix", "type", "properties", "details"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BlobModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of details
        if self.details:
            _dict['details'] = self.details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BlobModel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "blob_id": obj.get("blob_id"),
            "property": obj.get("property"),
            "key_prefix": obj.get("key_prefix"),
            "type": obj.get("type"),
            "properties": obj.get("properties"),
            "details": BlobDetails.from_dict(obj["details"]) if obj.get("details") is not None else None
        })
        return _obj


