# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.organization_api_keys_api import OrganizationAPIKeysApi


class TestOrganizationAPIKeysApi(unittest.TestCase):
    """OrganizationAPIKeysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationAPIKeysApi()

    def tearDown(self) -> None:
        pass

    def test_create_key_organizations_users_email(self) -> None:
        """Test case for create_key_organizations_users_email

        Create Api Key
        """
        pass

    def test_delete_key_organizations_users_email_name(self) -> None:
        """Test case for delete_key_organizations_users_email_name

        Delete Api Key
        """
        pass

    def test_list_keys_organizations_users_email(self) -> None:
        """Test case for list_keys_organizations_users_email

        List Api Keys
        """
        pass

    def test_rotate_key_organizations_users_email_name(self) -> None:
        """Test case for rotate_key_organizations_users_email_name

        Rotate Api Key
        """
        pass

    def test_update_key_organizations_users_email_name(self) -> None:
        """Test case for update_key_organizations_users_email_name

        Update Api Key
        """
        pass


if __name__ == '__main__':
    unittest.main()
