# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.retriever_interactions_api import RetrieverInteractionsApi


class TestRetrieverInteractionsApi(unittest.TestCase):
    """RetrieverInteractionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RetrieverInteractionsApi()

    def tearDown(self) -> None:
        pass

    def test_create_interaction_retrievers(self) -> None:
        """Test case for create_interaction_retrievers

        Create Interaction
        """
        pass

    def test_delete_interaction_retrievers(self) -> None:
        """Test case for delete_interaction_retrievers

        Delete Interaction
        """
        pass

    def test_get_interaction_retrievers(self) -> None:
        """Test case for get_interaction_retrievers

        Get Interaction
        """
        pass

    def test_list_interactions_retrievers(self) -> None:
        """Test case for list_interactions_retrievers

        List Interactions
        """
        pass


if __name__ == '__main__':
    unittest.main()
