# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.bucket_response import BucketResponse

class TestBucketResponse(unittest.TestCase):
    """BucketResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BucketResponse:
        """Test BucketResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BucketResponse`
        """
        model = BucketResponse()
        if include_optional:
            return BucketResponse(
                bucket_id = '',
                bucket_name = '',
                description = '',
                bucket_schema = {
                    'key' : null
                    },
                unique_key = mixpeek.models.unique_key_config.UniqueKeyConfig(
                    fields = [
                        ''
                        ], 
                    default_policy = 'insert', ),
                metadata = mixpeek.models.metadata.Metadata(),
                object_count = 56,
                total_size_bytes = 56,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_upload_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = 'PENDING',
                is_locked = True,
                batch_stats = mixpeek.models.batch_statistics.BatchStatistics(
                    total = 56, 
                    active = 56, 
                    completed = 56, 
                    failed = 56, ),
                storage_stats = mixpeek.models.storage_statistics.StorageStatistics(
                    total_size_bytes = 56, 
                    avg_size_bytes = 56, 
                    max_size_bytes = 56, 
                    min_size_bytes = 56, )
            )
        else:
            return BucketResponse(
                bucket_name = '',
                object_count = 56,
                total_size_bytes = 56,
        )
        """

    def testBucketResponse(self):
        """Test BucketResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
