# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.list_migrations_response import ListMigrationsResponse

class TestListMigrationsResponse(unittest.TestCase):
    """ListMigrationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListMigrationsResponse:
        """Test ListMigrationsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListMigrationsResponse`
        """
        model = ListMigrationsResponse()
        if include_optional:
            return ListMigrationsResponse(
                results = [
                    mixpeek.models.get_migration_response.GetMigrationResponse(
                        migration_id = '', 
                        internal_id = '', 
                        namespace_id = '', 
                        config = null, 
                        status = null, 
                        progress = null, 
                        validation_result = mixpeek.models.validation_result.ValidationResult(
                            valid = True, 
                            errors = [
                                mixpeek.models.validation_error.ValidationError(
                                    loc = [
                                        null
                                        ], 
                                    msg = '', 
                                    type = '', )
                                ], 
                            warnings = [
                                mixpeek.models.validation_error.ValidationError(
                                    loc = [
                                        null
                                        ], 
                                    msg = '', 
                                    type = '', )
                                ], 
                            estimated_resources = {
                                'key' : 56
                                }, 
                            estimated_duration_seconds = 56, ), 
                        dependency_graph = mixpeek.models.dependency_graph.DependencyGraph(
                            nodes = [
                                mixpeek.models.dependency_node.DependencyNode(
                                    resource_id = '', 
                                    resource_type = null, 
                                    dependencies = [
                                        ''
                                        ], 
                                    tier = 0.0, )
                                ], 
                            execution_order = [
                                ''
                                ], ), 
                        task_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_message = '', 
                        additional_data = mixpeek.models.additional_data.Additional Data(), )
                    ],
                total = 56,
                limit = 56,
                offset = 56
            )
        else:
            return ListMigrationsResponse(
                results = [
                    mixpeek.models.get_migration_response.GetMigrationResponse(
                        migration_id = '', 
                        internal_id = '', 
                        namespace_id = '', 
                        config = null, 
                        status = null, 
                        progress = null, 
                        validation_result = mixpeek.models.validation_result.ValidationResult(
                            valid = True, 
                            errors = [
                                mixpeek.models.validation_error.ValidationError(
                                    loc = [
                                        null
                                        ], 
                                    msg = '', 
                                    type = '', )
                                ], 
                            warnings = [
                                mixpeek.models.validation_error.ValidationError(
                                    loc = [
                                        null
                                        ], 
                                    msg = '', 
                                    type = '', )
                                ], 
                            estimated_resources = {
                                'key' : 56
                                }, 
                            estimated_duration_seconds = 56, ), 
                        dependency_graph = mixpeek.models.dependency_graph.DependencyGraph(
                            nodes = [
                                mixpeek.models.dependency_node.DependencyNode(
                                    resource_id = '', 
                                    resource_type = null, 
                                    dependencies = [
                                        ''
                                        ], 
                                    tier = 0.0, )
                                ], 
                            execution_order = [
                                ''
                                ], ), 
                        task_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        completed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_message = '', 
                        additional_data = mixpeek.models.additional_data.Additional Data(), )
                    ],
                total = 56,
                limit = 56,
                offset = 56,
        )
        """

    def testListMigrationsResponse(self):
        """Test ListMigrationsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
