# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.display_config_input import DisplayConfigInput

class TestDisplayConfigInput(unittest.TestCase):
    """DisplayConfigInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DisplayConfigInput:
        """Test DisplayConfigInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DisplayConfigInput`
        """
        model = DisplayConfigInput()
        if include_optional:
            return DisplayConfigInput(
                title = '',
                description = '',
                logo_url = '',
                icon_base64 = '',
                seo = mixpeek.models.seo_config.SEOConfig(
                    meta_title = '', 
                    meta_description = '', 
                    keywords = [
                        ''
                        ], 
                    og_image_url = '', 
                    og_image_alt = '', 
                    og_type = 'website', 
                    twitter_card = 'summary_large_image', 
                    twitter_site = '@mixpeek', 
                    twitter_creator = '', 
                    robots = 'index, follow', 
                    canonical_url = '', 
                    site_name = 'Mixpeek', 
                    author = '', 
                    locale = 'en_US', 
                    logo_url = '', 
                    favicon_url = '', 
                    structured_data = null, ),
                markdowns = [
                    mixpeek.models.markdown_content.MarkdownContent(
                        title = '0', 
                        content = '0', )
                    ],
                theme = mixpeek.models.theme_config.ThemeConfig(
                    primary_color = '#007AFF', 
                    secondary_color = '', 
                    font_family = 'system-ui, -apple-system, sans-serif', 
                    background_color = '#FFFFFF', 
                    text_color = '#374151', 
                    heading_font_family = '', 
                    surface_color = '', 
                    muted_color = '', 
                    border_color = '', 
                    border_radius = '12px', 
                    card_style = 'elevated', 
                    card_hover_effect = 'lift', ),
                inputs = [
                    mixpeek.models.input_rendering_config.InputRenderingConfig(
                        field_name = '', 
                        field_schema = null, 
                        input_type = 'text', 
                        label = '', 
                        placeholder = '', 
                        helper_text = '', 
                        suggestions = [
                            ''
                            ], 
                        required = True, 
                        order = 0.0, )
                    ],
                layout = mixpeek.models.layout_config.LayoutConfig(
                    mode = 'grid', 
                    columns = 1.0, 
                    gap = '16px', 
                    full_width = True, ),
                exposed_fields = [
                    ''
                    ],
                components = mixpeek.models.components_config.ComponentsConfig(
                    show_hero = True, 
                    show_search = True, 
                    show_filters = True, 
                    show_results_header = True, 
                    result_layout = 'grid', 
                    result_card = mixpeek.models.result_card_properties.ResultCardProperties(
                        layout = 'vertical', 
                        show_thumbnail = True, 
                        thumbnail_aspect_ratio = '16/9', 
                        thumbnail_fit = 'cover', 
                        show_score = True, 
                        truncate_title = 1.0, 
                        truncate_description = 1.0, 
                        field_order = [
                            ''
                            ], 
                        show_find_similar = True, 
                        card_click_action = 'viewDetails', 
                        thumbnail_field = '', 
                        title_field = '', 
                        card_fields = [
                            ''
                            ], 
                        modal_fields = [
                            ''
                            ], 
                        card_style = 'default', ), ),
                field_config = {
                    'key' : mixpeek.models.field_config.FieldConfig(
                        format = null, 
                        format_options = null, )
                    },
                custom_cta = mixpeek.models.custom_cta.CustomCTA(
                    label = '0', 
                    markdown_content = '0', ),
                external_links = [
                    mixpeek.models.external_link.ExternalLink(
                        name = '0', 
                        url = '0', )
                    ],
                template_type = '',
                field_mappings = {
                    'key' : ''
                    },
                extensions = mixpeek.models.extensions.Extensions()
            )
        else:
            return DisplayConfigInput(
                title = '',
                inputs = [
                    mixpeek.models.input_rendering_config.InputRenderingConfig(
                        field_name = '', 
                        field_schema = null, 
                        input_type = 'text', 
                        label = '', 
                        placeholder = '', 
                        helper_text = '', 
                        suggestions = [
                            ''
                            ], 
                        required = True, 
                        order = 0.0, )
                    ],
                exposed_fields = [
                    ''
                    ],
        )
        """

    def testDisplayConfigInput(self):
        """Test DisplayConfigInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
