# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mixpeek.models.logical_operator_input import LogicalOperatorInput
from mixpeek.models.stage_performance_input import StagePerformanceInput
from typing import Optional, Set
from typing_extensions import Self

class StageInstanceConfig(BaseModel):
    """
    User-provided configuration for a stage instance in a retriever pipeline.  This model is used when creating a retriever to define the specific parameters for each stage.
    """ # noqa: E501
    stage_name: StrictStr
    stage_id: Optional[StrictStr] = Field(default=None, description="Stage implementation ID (overrides stage_name for lookups)")
    parameters: Optional[Dict[str, Any]] = Field(default=None, description="Stage parameters")
    pre_filters: Optional[LogicalOperatorInput] = Field(default=None, description="Filters to apply to the documents *before* this stage is executed.These filters are combined with any global retriever filters.")
    post_filters: Optional[LogicalOperatorInput] = Field(default=None, description="Filters to apply to the documents *after* this stage is executed.These filters are applied to the results of this stage before passing to the next.")
    stats: Optional[StagePerformanceInput] = Field(default=None, description="Performance statistics for this stage")
    __properties: ClassVar[List[str]] = ["stage_name", "stage_id", "parameters", "pre_filters", "post_filters", "stats"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StageInstanceConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of pre_filters
        if self.pre_filters:
            _dict['pre_filters'] = self.pre_filters.to_dict()
        # override the default output from pydantic by calling `to_dict()` of post_filters
        if self.post_filters:
            _dict['post_filters'] = self.post_filters.to_dict()
        # override the default output from pydantic by calling `to_dict()` of stats
        if self.stats:
            _dict['stats'] = self.stats.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StageInstanceConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "stage_name": obj.get("stage_name"),
            "stage_id": obj.get("stage_id"),
            "parameters": obj.get("parameters"),
            "pre_filters": LogicalOperatorInput.from_dict(obj["pre_filters"]) if obj.get("pre_filters") is not None else None,
            "post_filters": LogicalOperatorInput.from_dict(obj["post_filters"]) if obj.get("post_filters") is not None else None,
            "stats": StagePerformanceInput.from_dict(obj["stats"]) if obj.get("stats") is not None else None
        })
        return _obj


