# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.sync_configuration_model import SyncConfigurationModel

class TestSyncConfigurationModel(unittest.TestCase):
    """SyncConfigurationModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyncConfigurationModel:
        """Test SyncConfigurationModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyncConfigurationModel`
        """
        model = SyncConfigurationModel()
        if include_optional:
            return SyncConfigurationModel(
                sync_config_id = '',
                bucket_id = '',
                connection_id = '',
                internal_id = '',
                namespace_id = '',
                source_path = '',
                file_filters = mixpeek.models.file_filters.FileFilters(
                    include_patterns = [
                        ''
                        ], 
                    exclude_patterns = [
                        ''
                        ], 
                    min_size_bytes = 0.0, 
                    max_size_bytes = 0.0, 
                    modified_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    mime_types = [
                        ''
                        ], ),
                schema_mapping = mixpeek.models.schema_mapping.SchemaMapping(
                    mappings = {
                        'key' : null
                        }, ),
                sync_mode = 'initial_only',
                polling_interval_seconds = 30.0,
                batch_size = 1.0,
                create_object_on_confirm = True,
                skip_duplicates = True,
                skip_batch_submission = True,
                status = 'PENDING',
                is_active = True,
                total_files_discovered = 0.0,
                total_files_synced = 0.0,
                total_files_failed = 0.0,
                total_bytes_synced = 0.0,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_sync_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                next_sync_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by_user_id = '',
                last_error = '',
                consecutive_failures = 0.0,
                metadata = mixpeek.models.metadata.Metadata(),
                locked_by_worker_id = '',
                locked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                lock_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                paused = True,
                pause_reason = '',
                paused_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                paused_by_user_id = '',
                max_objects_per_run = 1.0,
                max_batch_chunk_size = 1.0,
                batch_chunk_size = 1.0,
                current_sync_run_id = '',
                sync_run_counter = 0.0,
                batch_ids = [
                    ''
                    ],
                task_ids = [
                    ''
                    ],
                batches_created = 0.0,
                resume_enabled = True,
                resume_cursor = '',
                resume_last_primary_key = '',
                resume_objects_processed = 0.0,
                resume_checkpoint_frequency = 100.0
            )
        else:
            return SyncConfigurationModel(
                bucket_id = '',
                connection_id = '',
                internal_id = '',
                namespace_id = '',
                source_path = '',
                created_by_user_id = '',
        )
        """

    def testSyncConfigurationModel(self):
        """Test SyncConfigurationModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
