# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.course_content_extractor_params import CourseContentExtractorParams

class TestCourseContentExtractorParams(unittest.TestCase):
    """CourseContentExtractorParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseContentExtractorParams:
        """Test CourseContentExtractorParams
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseContentExtractorParams`
        """
        model = CourseContentExtractorParams()
        if include_optional:
            return CourseContentExtractorParams(
                extractor_type = 'course_content_extractor',
                target_segment_duration_ms = 30000.0,
                min_segment_duration_ms = 10000.0,
                segmentation_method = 'scene',
                scene_detection_threshold = 0.1,
                use_whisper_asr = True,
                expand_to_granular_docs = True,
                ocr_frames_per_segment = 1.0,
                pdf_extraction_mode = 'per_element',
                pdf_render_dpi = 72.0,
                detect_code_in_pdf = True,
                segment_functions = True,
                supported_languages = [
                    ''
                    ],
                run_text_embedding = True,
                run_code_embedding = True,
                run_visual_embedding = True,
                visual_embedding_use_case = 'lecture',
                extract_screen_text = True,
                generate_thumbnails = True,
                use_cdn = True,
                enrich_with_llm = True,
                llm_prompt = 'Summarize this educational content segment, highlighting key concepts.'
            )
        else:
            return CourseContentExtractorParams(
        )
        """

    def testCourseContentExtractorParams(self):
        """Test CourseContentExtractorParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
