# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_params_document_enrich import StageParamsDocumentEnrich

class TestStageParamsDocumentEnrich(unittest.TestCase):
    """StageParamsDocumentEnrich unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StageParamsDocumentEnrich:
        """Test StageParamsDocumentEnrich
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StageParamsDocumentEnrich`
        """
        model = StageParamsDocumentEnrich()
        if include_optional:
            return StageParamsDocumentEnrich(
                cache_behavior = 'auto',
                cache_ttl_seconds = 0,
                retriever_id = 'null',
                retriever_config = mixpeek.models.retriever_config.Retriever Config(),
                retriever_inputs = mixpeek.models.retriever_inputs.Retriever Inputs(),
                target_collection_id = '{{COLLECTION_ID}}',
                source_field = 'source_object_id',
                target_field = 'document_id',
                fields_to_merge = [
                    ''
                    ],
                output_field = 'null',
                strategy = 'enrich',
                when = {
                    'key' : null
                    },
                allow_missing = True
            )
        else:
            return StageParamsDocumentEnrich(
        )
        """

    def testStageParamsDocumentEnrich(self):
        """Test StageParamsDocumentEnrich"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
