# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.collection_feature_descriptor import CollectionFeatureDescriptor

class TestCollectionFeatureDescriptor(unittest.TestCase):
    """CollectionFeatureDescriptor unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CollectionFeatureDescriptor:
        """Test CollectionFeatureDescriptor
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CollectionFeatureDescriptor`
        """
        model = CollectionFeatureDescriptor()
        if include_optional:
            return CollectionFeatureDescriptor(
                feature_address = '',
                feature_extractor_name = '',
                version = '',
                vector_index = mixpeek.models.vector_index.VectorIndex(
                    name = '', 
                    description = '0123456789', 
                    dimensions = 1.0, 
                    type = null, 
                    distance = 'cosine', 
                    datatype = 'float32', 
                    on_disk = True, 
                    supported_inputs = [
                        'string'
                        ], 
                    inference_name = '', 
                    inference_service_id = '', 
                    purpose = 'text', 
                    vector_name_override = '', ),
                primary = True
            )
        else:
            return CollectionFeatureDescriptor(
                feature_address = '',
                feature_extractor_name = '',
                version = '',
                vector_index = mixpeek.models.vector_index.VectorIndex(
                    name = '', 
                    description = '0123456789', 
                    dimensions = 1.0, 
                    type = null, 
                    distance = 'cosine', 
                    datatype = 'float32', 
                    on_disk = True, 
                    supported_inputs = [
                        'string'
                        ], 
                    inference_name = '', 
                    inference_service_id = '', 
                    purpose = 'text', 
                    vector_name_override = '', ),
        )
        """

    def testCollectionFeatureDescriptor(self):
        """Test CollectionFeatureDescriptor"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
