# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.result_card_properties import ResultCardProperties

class TestResultCardProperties(unittest.TestCase):
    """ResultCardProperties unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultCardProperties:
        """Test ResultCardProperties
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultCardProperties`
        """
        model = ResultCardProperties()
        if include_optional:
            return ResultCardProperties(
                layout = 'vertical',
                show_thumbnail = True,
                thumbnail_aspect_ratio = '16/9',
                thumbnail_fit = 'cover',
                show_score = True,
                truncate_title = 1.0,
                truncate_description = 1.0,
                field_order = [
                    ''
                    ],
                show_find_similar = True,
                card_click_action = 'viewDetails',
                thumbnail_field = '',
                title_field = '',
                card_fields = [
                    ''
                    ],
                modal_fields = [
                    ''
                    ],
                card_style = 'default'
            )
        else:
            return ResultCardProperties(
        )
        """

    def testResultCardProperties(self):
        """Test ResultCardProperties"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
