# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.stage_breakdown_response import StageBreakdownResponse

class TestStageBreakdownResponse(unittest.TestCase):
    """StageBreakdownResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StageBreakdownResponse:
        """Test StageBreakdownResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StageBreakdownResponse`
        """
        model = StageBreakdownResponse()
        if include_optional:
            return StageBreakdownResponse(
                retriever_id = '',
                stages = [
                    mixpeek.models.stage_performance_metrics.StagePerformanceMetrics(
                        stage_name = '', 
                        stage_type = '', 
                        execution_count = 56, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, 
                        avg_documents_in = 1.337, 
                        avg_documents_out = 1.337, )
                    ],
                total_latency_ms = 1.337
            )
        else:
            return StageBreakdownResponse(
                retriever_id = '',
                stages = [
                    mixpeek.models.stage_performance_metrics.StagePerformanceMetrics(
                        stage_name = '', 
                        stage_type = '', 
                        execution_count = 56, 
                        avg_latency_ms = 1.337, 
                        p95_latency_ms = 1.337, 
                        avg_documents_in = 1.337, 
                        avg_documents_out = 1.337, )
                    ],
                total_latency_ms = 1.337,
        )
        """

    def testStageBreakdownResponse(self):
        """Test StageBreakdownResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
