# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from mixpeek.models.user_create_request import UserCreateRequest
from typing import Optional, Set
from typing_extensions import Self

class CreateOrganizationRequest(BaseModel):
    """
    Payload for creating a new organization (private/admin endpoint).
    """ # noqa: E501
    organization_name: Annotated[str, Field(min_length=1, strict=True, max_length=100)] = Field(description="Display name for the organization.")
    logo_url: Optional[StrictStr] = Field(default=None, description="Organization logo URL (e.g., from Google Favicon service). If not provided, will be auto-generated from first user's email domain.")
    users: Optional[List[UserCreateRequest]] = Field(default=None, description="Initial users to create with the organization.")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Custom metadata for the organization.")
    credit_count: Optional[StrictInt] = Field(default=None, description="Initial credit count for the organization. Defaults to 1000 if not provided.")
    account_type: Optional[StrictStr] = Field(default=None, description="Account type for the organization (free, pro, team, enterprise). Defaults to 'free'.")
    __properties: ClassVar[List[str]] = ["organization_name", "logo_url", "users", "metadata", "credit_count", "account_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateOrganizationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in users (list)
        _items = []
        if self.users:
            for _item_users in self.users:
                if _item_users:
                    _items.append(_item_users.to_dict())
            _dict['users'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateOrganizationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "organization_name": obj.get("organization_name"),
            "logo_url": obj.get("logo_url"),
            "users": [UserCreateRequest.from_dict(_item) for _item in obj["users"]] if obj.get("users") is not None else None,
            "metadata": obj.get("metadata"),
            "credit_count": obj.get("credit_count"),
            "account_type": obj.get("account_type")
        })
        return _obj


