# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.slow_queries_response import SlowQueriesResponse

class TestSlowQueriesResponse(unittest.TestCase):
    """SlowQueriesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SlowQueriesResponse:
        """Test SlowQueriesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SlowQueriesResponse`
        """
        model = SlowQueriesResponse()
        if include_optional:
            return SlowQueriesResponse(
                namespace_id = '',
                time_range_days = 56,
                latency_threshold_ms = 1.337,
                slow_queries = [
                    mixpeek.models.slow_query_details.SlowQueryDetails(
                        retriever_id = '', 
                        query = '', 
                        latency_ms = 1.337, 
                        results_count = 56, 
                        queried_fields = [
                            ''
                            ], )
                    ],
                total_slow_queries = 56
            )
        else:
            return SlowQueriesResponse(
                namespace_id = '',
                time_range_days = 56,
                latency_threshold_ms = 1.337,
                slow_queries = [
                    mixpeek.models.slow_query_details.SlowQueryDetails(
                        retriever_id = '', 
                        query = '', 
                        latency_ms = 1.337, 
                        results_count = 56, 
                        queried_fields = [
                            ''
                            ], )
                    ],
                total_slow_queries = 56,
        )
        """

    def testSlowQueriesResponse(self):
        """Test SlowQueriesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
