# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SecretResponse(BaseModel):
    """
    Response for secret operations (NEVER includes actual decrypted value).  This response is returned after creating, updating, or deleting a secret. For security, the actual secret value is NEVER included in API responses. Only the secret name and operation status are returned.  **Security**: - Decrypted secret values are NEVER included - Only secret name and operation status returned - Actual value only accessible by internal services  **Fields**: - secret_name: Name of the secret that was operated on - created: True if secret was created (null for other operations) - updated: True if secret was updated (null for other operations) - deleted: True if secret was deleted (null for other operations)
    """ # noqa: E501
    secret_name: StrictStr = Field(description="Name of the secret that was operated on. This is the same name provided in the request. Use this name to reference the secret in api_call stage configuration.")
    created: Optional[StrictBool] = Field(default=None, description="True if this secret was created, null otherwise. Only set for POST /secrets operations.")
    updated: Optional[StrictBool] = Field(default=None, description="True if this secret was updated, null otherwise. Only set for PUT /secrets/{name} operations.")
    deleted: Optional[StrictBool] = Field(default=None, description="True if this secret was deleted, null otherwise. Only set for DELETE /secrets/{name} operations.")
    __properties: ClassVar[List[str]] = ["secret_name", "created", "updated", "deleted"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SecretResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SecretResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "secret_name": obj.get("secret_name"),
            "created": obj.get("created"),
            "updated": obj.get("updated"),
            "deleted": obj.get("deleted")
        })
        return _obj


