# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.explain_stage_plan import ExplainStagePlan

class TestExplainStagePlan(unittest.TestCase):
    """ExplainStagePlan unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExplainStagePlan:
        """Test ExplainStagePlan
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExplainStagePlan`
        """
        model = ExplainStagePlan()
        if include_optional:
            return ExplainStagePlan(
                stage_index = 0.0,
                stage_name = '',
                stage_type = '',
                estimated_input = 0.0,
                estimated_output = 0.0,
                estimated_efficiency = 0.0,
                estimated_cost_credits = 0.0,
                estimated_duration_ms = 0.0,
                cache_likely = True,
                optimization_notes = [
                    ''
                    ],
                warnings = [
                    ''
                    ]
            )
        else:
            return ExplainStagePlan(
                stage_index = 0.0,
                stage_name = '',
                stage_type = '',
                estimated_input = 0.0,
                estimated_output = 0.0,
                estimated_efficiency = 0.0,
                estimated_cost_credits = 0.0,
                estimated_duration_ms = 0.0,
                cache_likely = True,
        )
        """

    def testExplainStagePlan(self):
        """Test ExplainStagePlan"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
