# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.clusters_api import ClustersApi


class TestClustersApi(unittest.TestCase):
    """ClustersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ClustersApi()

    def tearDown(self) -> None:
        pass

    def test_apply_cluster_enrichment_enrich(self) -> None:
        """Test case for apply_cluster_enrichment_enrich

        Apply Cluster Enrichment
        """
        pass

    def test_create_cluster(self) -> None:
        """Test case for create_cluster

        Create Cluster
        """
        pass

    def test_delete_cluster(self) -> None:
        """Test case for delete_cluster

        Delete Cluster
        """
        pass

    def test_execute_clustering_clusters(self) -> None:
        """Test case for execute_clustering_clusters

        Execute Clustering
        """
        pass

    def test_get_cluster(self) -> None:
        """Test case for get_cluster

        Get Cluster
        """
        pass

    def test_list_clusters(self) -> None:
        """Test case for list_clusters

        List Clusters
        """
        pass

    def test_patch_cluster(self) -> None:
        """Test case for patch_cluster

        Partially Update Cluster
        """
        pass


if __name__ == '__main__':
    unittest.main()
