# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.custom_models_api import CustomModelsApi


class TestCustomModelsApi(unittest.TestCase):
    """CustomModelsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomModelsApi()

    def tearDown(self) -> None:
        pass

    def test_delete_model_namespaces(self) -> None:
        """Test case for delete_model_namespaces

        Delete a model
        """
        pass

    def test_deploy_model_namespaces(self) -> None:
        """Test case for deploy_model_namespaces

        Deploy model to Ray object store
        """
        pass

    def test_disable_org_model_namespaces(self) -> None:
        """Test case for disable_org_model_namespaces

        Disable org model for namespace
        """
        pass

    def test_enable_org_model_namespaces(self) -> None:
        """Test case for enable_org_model_namespaces

        Enable org model for namespace
        """
        pass

    def test_get_model_namespaces(self) -> None:
        """Test case for get_model_namespaces

        Get model details
        """
        pass

    def test_list_available_org_models_namespaces(self) -> None:
        """Test case for list_available_org_models_namespaces

        List available org models
        """
        pass

    def test_list_models_namespaces(self) -> None:
        """Test case for list_models_namespaces

        List models in namespace
        """
        pass

    def test_upload_model_namespaces(self) -> None:
        """Test case for upload_model_namespaces

        Upload a custom model
        """
        pass


if __name__ == '__main__':
    unittest.main()
