# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.create_model_upload_request import CreateModelUploadRequest

class TestCreateModelUploadRequest(unittest.TestCase):
    """CreateModelUploadRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateModelUploadRequest:
        """Test CreateModelUploadRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateModelUploadRequest`
        """
        model = CreateModelUploadRequest()
        if include_optional:
            return CreateModelUploadRequest(
                name = 'AqXzyCBw3_uufVP',
                version = '4.072888001528021798096225500850762068629.39333975650685139102691291732729478601482026',
                model_format = 'safetensors',
                description = '',
                file_size_bytes = 56,
                presigned_url_expiration = 60.0,
                resource_requirements = mixpeek.models.model_resource_requirements.ModelResourceRequirements(
                    num_cpus = 0.1, 
                    num_gpus = 0.0, 
                    memory = 56, ),
                framework = '',
                task_type = ''
            )
        else:
            return CreateModelUploadRequest(
                name = 'AqXzyCBw3_uufVP',
                version = '4.072888001528021798096225500850762068629.39333975650685139102691291732729478601482026',
                model_format = 'safetensors',
        )
        """

    def testCreateModelUploadRequest(self):
        """Test CreateModelUploadRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
