# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.interaction_tuning_response import InteractionTuningResponse

class TestInteractionTuningResponse(unittest.TestCase):
    """InteractionTuningResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InteractionTuningResponse:
        """Test InteractionTuningResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InteractionTuningResponse`
        """
        model = InteractionTuningResponse()
        if include_optional:
            return InteractionTuningResponse(
                retriever_id = '',
                analysis_period = mixpeek.models.time_range.TimeRange(
                    start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                recommendations = [
                    mixpeek.models.interaction_tuning_recommendation.InteractionTuningRecommendation(
                        recommendation_type = '', 
                        current_value = null, 
                        recommended_value = null, 
                        expected_impact = '', 
                        confidence = 0.0, 
                        reasoning = '', )
                    ],
                current_performance = mixpeek.models.current_performance.Current Performance()
            )
        else:
            return InteractionTuningResponse(
                retriever_id = '',
                analysis_period = mixpeek.models.time_range.TimeRange(
                    start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                recommendations = [
                    mixpeek.models.interaction_tuning_recommendation.InteractionTuningRecommendation(
                        recommendation_type = '', 
                        current_value = null, 
                        recommended_value = null, 
                        expected_impact = '', 
                        confidence = 0.0, 
                        reasoning = '', )
                    ],
                current_performance = mixpeek.models.current_performance.Current Performance(),
        )
        """

    def testInteractionTuningResponse(self):
        """Test InteractionTuningResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
