# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.models.create_namespace_request import CreateNamespaceRequest

class TestCreateNamespaceRequest(unittest.TestCase):
    """CreateNamespaceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateNamespaceRequest:
        """Test CreateNamespaceRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateNamespaceRequest`
        """
        model = CreateNamespaceRequest()
        if include_optional:
            return CreateNamespaceRequest(
                namespace_name = 'spotify_playlists_dev',
                description = 'This namespace contains playlists from Spotify',
                feature_extractors = [{feature_extractor_id=multimodal_extractor_v1, feature_extractor_name=multimodal_extractor, version=v1}, {feature_extractor_id=image_extractor_v1, feature_extractor_name=image_extractor, params={model=siglip_base}, version=v1}],
                payload_indexes = [{field_name=metadata.title, field_schema={lowercase=true, max_token_len=15, min_token_len=2, tokenizer=word, type=text}, is_protected=false, type=text}, {field_name=metadata.description, field_schema={is_tenant=true, type=keyword}, is_protected=false, type=keyword}],
                auto_create_indexes = True,
                infrastructure = mixpeek.models.namespace_infrastructure.NamespaceInfrastructure(
                    ray_cluster_id = 'ray_HqXzyCBw3_uufVPIPFhB9JcGRYnua_cdyyvLY8IzLpul9', 
                    ray_head_node_url = '', 
                    ray_dashboard_url = '', 
                    qdrant_url = '', 
                    qdrant_api_key = '', 
                    qdrant_collection = '012', 
                    compute_tier = null, 
                    max_concurrent_jobs = 1.0, 
                    autoscaling_enabled = True, 
                    min_workers = 0.0, 
                    max_workers = 1.0, 
                    gpu_type = '', 
                    gpus_per_worker = 0.0, 
                    s3_plugin_bucket = 'mixpeek-plugins', 
                    s3_plugin_prefix = '', 
                    max_custom_plugins = 0.0, 
                    max_custom_models = 0.0, )
            )
        else:
            return CreateNamespaceRequest(
                namespace_name = 'spotify_playlists_dev',
                feature_extractors = [{feature_extractor_id=multimodal_extractor_v1, feature_extractor_name=multimodal_extractor, version=v1}, {feature_extractor_id=image_extractor_v1, feature_extractor_name=image_extractor, params={model=siglip_base}, version=v1}],
        )
        """

    def testCreateNamespaceRequest(self):
        """Test CreateNamespaceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
