# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.custom_plugins_namespace_api import CustomPluginsNamespaceApi


class TestCustomPluginsNamespaceApi(unittest.TestCase):
    """CustomPluginsNamespaceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomPluginsNamespaceApi()

    def tearDown(self) -> None:
        pass

    def test_confirm_upload_namespaces_id_plugins(self) -> None:
        """Test case for confirm_upload_namespaces_id_plugins

        Confirm plugin upload
        """
        pass

    def test_delete_plugin_namespaces(self) -> None:
        """Test case for delete_plugin_namespaces

        Delete a plugin
        """
        pass

    def test_deploy_plugin_namespaces(self) -> None:
        """Test case for deploy_plugin_namespaces

        Deploy or redeploy a plugin
        """
        pass

    def test_disable_org_plugin_namespaces(self) -> None:
        """Test case for disable_org_plugin_namespaces

        Disable org plugin for namespace
        """
        pass

    def test_enable_org_plugin_namespaces(self) -> None:
        """Test case for enable_org_plugin_namespaces

        Enable org plugin for namespace
        """
        pass

    def test_generate_upload_url_namespaces_id_plugins(self) -> None:
        """Test case for generate_upload_url_namespaces_id_plugins

        Generate presigned URL for plugin upload
        """
        pass

    def test_get_deployment_status_namespaces_id_plugins(self) -> None:
        """Test case for get_deployment_status_namespaces_id_plugins

        Get plugin deployment status
        """
        pass

    def test_get_plugin_namespaces(self) -> None:
        """Test case for get_plugin_namespaces

        Get plugin details
        """
        pass

    def test_list_available_org_plugins_namespaces(self) -> None:
        """Test case for list_available_org_plugins_namespaces

        List available org plugins
        """
        pass

    def test_list_plugins_namespaces(self) -> None:
        """Test case for list_plugins_namespaces

        List plugins in namespace
        """
        pass

    def test_undeploy_plugin_namespaces(self) -> None:
        """Test case for undeploy_plugin_namespaces

        Undeploy a plugin
        """
        pass

    def test_upload_plugin_namespaces(self) -> None:
        """Test case for upload_plugin_namespaces

        Upload a custom plugin
        """
        pass


if __name__ == '__main__':
    unittest.main()
