# coding: utf-8

"""
    Mixpeek API

    This is the Mixpeek API, providing access to various endpoints for data processing and retrieval.

    The version of the OpenAPI document: 1.3.0
    Contact: info@mixpeek.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from mixpeek.api.taxonomies_api import TaxonomiesApi


class TestTaxonomiesApi(unittest.TestCase):
    """TaxonomiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TaxonomiesApi()

    def tearDown(self) -> None:
        pass

    def test_clone_taxonomy_taxonomies(self) -> None:
        """Test case for clone_taxonomy_taxonomies

        Clone Taxonomy
        """
        pass

    def test_create_taxonomy_taxonomies(self) -> None:
        """Test case for create_taxonomy_taxonomies

        Create Taxonomy
        """
        pass

    def test_create_taxonomy_version_taxonomies(self) -> None:
        """Test case for create_taxonomy_version_taxonomies

        Create Taxonomy Version
        """
        pass

    def test_delete_taxonomy_taxonomies(self) -> None:
        """Test case for delete_taxonomy_taxonomies

        Delete Taxonomy
        """
        pass

    def test_execute_taxonomy_taxonomies(self) -> None:
        """Test case for execute_taxonomy_taxonomies

        Test taxonomy configuration (validation only)
        """
        pass

    def test_get_taxonomy_taxonomies(self) -> None:
        """Test case for get_taxonomy_taxonomies

        Get Taxonomy
        """
        pass

    def test_list_taxonomies(self) -> None:
        """Test case for list_taxonomies

        List Taxonomies
        """
        pass

    def test_list_taxonomy_versions_taxonomies(self) -> None:
        """Test case for list_taxonomy_versions_taxonomies

        List Taxonomy Versions
        """
        pass

    def test_patch_taxonomy_taxonomies(self) -> None:
        """Test case for patch_taxonomy_taxonomies

        Partially Update Taxonomy
        """
        pass


if __name__ == '__main__':
    unittest.main()
